/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton;

import java.awt.Color;
import java.awt.Dimension;

import javax.swing.ActionMap;
import javax.swing.JOptionPane;
import javax.swing.UIManager;
import javax.swing.plaf.DimensionUIResource;

import com.jgoodies.forms.layout.LayoutMap;
import com.jgoodies.forms.layout.Sizes;
import com.jgoodies.forms.util.DefaultUnitConverter;
import com.jgoodies.looks.Options;
import com.jgoodies.skeleton.model.MainModel;
import com.jgoodies.skeleton.model.help.HelpSets;
import com.jgoodies.skeleton.view.MainFrame;
import com.jgoodies.uif.AbstractFrame;
import com.jgoodies.uif.application.ActionReader;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.builder.PanelBuilder2;
import com.jgoodies.uif.osx.OSXApplicationMenu;
import com.jgoodies.uif.splash.ImageSplash;
import com.jgoodies.uif.splash.Splash;
import com.jgoodies.uifextras.convenience.DefaultUIFApplication;

/**
 * This is the main class of the Skeleton Pro application.
 * It utilizes the default application startup process
 * from the JGoodies UI framework.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.35 $
 *
 * @see MainModel
 * @see MainFrame
 */
public final class SkeletonPro extends DefaultUIFApplication {

    private MainModel mainModel;


    /**
     * Sets the OS X menu name and launches the Skeleton Pro application.
     */
    public static void main(String[] arguments) {
        OSXApplicationMenu.setAboutName("Skeleton Pro");
        Application.launch(SkeletonPro.class, arguments);
    }


    /**
     * Configures the splash to colorize the progress bar.
     */
    @Override
    protected void configureSplash() {
        super.configureSplash();
        ImageSplash splash = (ImageSplash) Splash.getProvider();
        splash.setProgressBarBounds(60);
        splash.setForeground(new Color(64, 64, 64));
        splash.setBackground(Color.WHITE);
        // Uncomment the following line to display note changes
        // splash.setNoteEnabled(true);
    }


	/**
	 * Configures the user interface.
	 */
	@Override
    protected void configureUI() {
		Options.setDefaultIconSize(new Dimension(18, 18));
        Options.setPopupDropShadowEnabled(true);
		UIManager.put("ToolBar.separatorSize",	new DimensionUIResource(6, 18));
        super.configureUI();
        
        // Enable platform-specific resources
        ActionReader.setPlatformResourcesEnabled(true);
        
        // Modern dlu conversion
        DefaultUnitConverter.getInstance().setAverageCharacterWidthTestString(
            "abcdefghijklmnopqrstuvwxyz0123456789");
        // Use DLU as default unit.
        Sizes.setDefaultUnit(null);
        PanelBuilder2.setLabelForFeatureEnabledDefault(true);
        configureLayoutMap();
	}


    protected void configureLayoutMap() {
        LayoutMap map = LayoutMap.getRoot();
        map.columnPut("indent",     "14");
        map.columnPut("label",      "right:[45, pref]");
        map.columnPut("component",  "80");
        map.columnPut("column-gap", "14");
        map.columnPut("colgap",     "${column-gap}");
    }


	/**
	 * Creates and returns the application's main frame.
	 */
	@Override
    protected AbstractFrame createMainFrame() {
		return new MainFrame(mainModel);
	}


	/**
	 * Initializes the actions used in this application.
	 */
	@Override
    protected void initializeActions() {
        ActionMap actionMap = Application.getActionMap(mainModel);
        // Initialize all Actions
        OSXApplicationMenu.register(
                actionMap.get(MainModel.ACTION_OPEN_ABOUT_DIALOG),
                actionMap.get(MainModel.ACTION_OPEN_PREFERENCES),
                actionMap.get(MainModel.ACTION_EXIT));
	}


    /**
     * Brings up the application. It initializes the main frame,
     * checks the setup process, initializes all actions, then builds
     * the main frame, and finally opens it.<p>
     *
     * The texts set in {@link Splash#setNote(String)} may be honored
     * or ignored by the splash provider. For example the ImageSplash
     * ignores note changes by default; you can enable this feature via
     * {@link ImageSplash#setNoteEnabled(boolean)}.
     */
    @Override
    protected void launchApplication() {
        // Now add a more sophisticated handler.
        addMessageHandler();

        // Create the model that provides all high-level models.
        Splash.setNote("Creating Models", 30);
        mainModel = new MainModel();

        // Initialize all Actions
        Splash.setNote("Initializing Actions\u2026", 50);
        initializeActions();

        HelpSets.registerHelpSets(mainModel.getHelpModel());

        // Create and build the main frame.
        AbstractFrame mainFrame = createMainFrame();
        JOptionPane.setRootFrame(mainFrame);

        checkSetup();

        Splash.setNote("Building UI\u2026", 60);
        mainFrame.build();

        Splash.setNote("Finishing\u2026", 90);
        mainFrame.open();
        mainModel.checkForOpenTipOfTheDayDialog();
    }


}
