/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.domain;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;

/**
 * Consists only of static methods that return constant lists of choices
 * used to fill models for comboboxes and list views.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */

public final class Constants {

    private Constants() {
        // Overrides default constructor; prevents instantiation.
    }


    // Arrays ****************************************************************

    /**
     * Holds an array of ice classes.
     *
     * @see #ICE_CLASS_LIST
     */
    public static final String[] ICE_CLASS_ARRAY =
        { "E", "E1", "E2", "E3", "E4" };


    /**
     * Holds an array of locations.
     *
     * @see #LOCATION_LIST
     */
    public static final String[] LOCATION_ARRAY =
        { "Propeller nut thread",
          "Stern tube front area",
          "Shaft taper" };


    /**
     * Holds an array of materials.
     *
     * @see #MATERIAL_LIST
     */
    public static final String[] MATERIAL_ARRAY =
        { "C45E, ReH=600",
          "Bolt Material, ReH=800" };


    // Lists ******************************************************************

    /**
     * Holds an unmodifiable list of ice classes.
     *
     * @see #ICE_CLASS_ARRAY
     */
    public static final List ICE_CLASS_LIST =
        Collections.unmodifiableList(Arrays.asList(ICE_CLASS_ARRAY));


    /**
     * Holds an unmodifiable list of locations.
     *
     * @see #LOCATION_ARRAY
     */
    public static final List LOCATION_LIST =
        Collections.unmodifiableList(Arrays.asList(LOCATION_ARRAY));


    /**
     * Holds an unmodifiable list of materials.
     *
     * @see #MATERIAL_ARRAY
     */
    public static final List MATERIAL_LIST =
        Collections.unmodifiableList(Arrays.asList(MATERIAL_ARRAY));

}