/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.model.node;

import javax.swing.Icon;

import com.jgoodies.skeleton.domain.Description;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;

/**
 * This class represents the project description in the navigation tree.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.11 $
 *
 * @see com.jgoodies.skeleton.domain.Description
 */
public final class DescriptionNode extends AbstractTreeNode {

    private static ResourceMap resourceMap =
        Application.getResourceMap(DescriptionNode.class);

    // Instance Creation ******************************************************

    /**
     * Constructs a <code>DescriptionNode</code> for the given parent and
     * description.
     *
     * @param parent       this node's parent
     * @param description  the associated model, a description instance
     */
    public DescriptionNode(NavigationNode parent, Description description) {
        super(parent, description);
    }


    // Implementing the NavigationNode Interface ******************************

    /**
     * Returns this node's name, a constant requested from the global
     * resource repository.
     *
     * @return this node's name
     */
    @Override
    public String getName() {
        return resourceMap.getString("description.name");
    }


    // ************************************************************************

    /**
     * Returns this node's icon, ignores the selection.
     * The icons is requested from a global resource repository.
     *
     * @return this description node's icon.
     */
    @Override
    public Icon getIcon(boolean sel) {
        return resourceMap.getIcon("description.icon");
    }


    /**
     * Returns this node's associated Description instance.
     *
     * @return this node's associated Description instance.
     * @see NavigationNode#getModel()
     */
    public Description getDescription() {
        return (Description) getModel();
    }

}