/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.view.editor;

import java.awt.Component;

import javax.swing.*;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.skeleton.model.MainModel;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.uifextras.panel.GradientBackgroundPanel;
import com.jgoodies.uifextras.util.ActionLabel;

/**
 * This panel is displayed after a successful application startup to welcome
 * the user. It provides access to actions that are most useful at the
 * application start.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.18 $
 */
public final class WelcomeView extends AbstractView implements Editor {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(WelcomeView.class);


    private final MainModel mainModel;

    private Component welcomeLabel;
    private Component logoLabel;
    private Component selectLabel;
    private Component newProjectButton;
    private Component openProjectButton;


    // Instance Creation ******************************************************

    public WelcomeView(MainModel mainModel) {
        this.mainModel = mainModel;
    }


    // Implementing the Editor Interface ************************************

    public Icon getIcon() {
        return null;
    }

    public String getTitle() {
        return "Welcome";
    }

    public JToolBar getToolBar() {
        return null;
    }

    public void activate() {
        // Nothing to do in this welcome panel.
    }

    public void deactivate() {
        // Nothing to do in this welcome panel.
    }

    public void updateModel(Object model) {
        // Do nothing.
    }

    public void updateView(Object model) {
        // Do nothing.
    }


    // Building *************************************************************

    private void initComponents() {
        ActionMap map = Application.getActionMap(mainModel);
        welcomeLabel = new JLabel("Welcome to");
        logoLabel    = new JLabel(RESOURCES.getIcon("logo.icon"));
        selectLabel  = new JLabel("Select one of the options below.");
        newProjectButton  = createActionComponent(map.get(MainModel.ACTION_NEW_PROJECT));
        openProjectButton = createActionComponent(map.get(MainModel.ACTION_OPEN_PROJECT));
    }


    private JComponent createActionComponent(Action a) {
        ActionLabel label = new ActionLabel(a);
        label.setIcon(RESOURCES.getIcon("arrow.icon"));
        return label;
    }


    /**
     * Builds and returns the panel.
     */
    @Override
    protected JComponent buildPanel() {
        initComponents();

        FormLayout layout = new FormLayout(
                "9dlu, left:pref:grow",
                "b:pref, c:pref, t:pref, 9dlu, pref, 6dlu, pref");
        PanelBuilder builder = new PanelBuilder(layout, new GradientBackgroundPanel(false));
        builder.setOpaque(false);
        builder.setBorder(Borders.DLU14_BORDER);

        CellConstraints cc = new CellConstraints();

        builder.add(welcomeLabel,      cc.xyw(1, 1, 2));
        builder.add(logoLabel,         cc.xyw(1, 2, 2, "left, center"));
        builder.add(selectLabel,       cc.xyw(1, 3, 2));
        builder.add(newProjectButton,  cc.xy (2, 5));
        builder.add(openProjectButton, cc.xy (2, 7));

        return builder.getPanel();
    }


}