/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.animation.extras;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.util.Iterator;
import java.util.List;

import javax.swing.*;

import com.jgoodies.animation.components.BasicTextLabel;
import com.jgoodies.animation.components.GlyphLabel;
import com.jgoodies.uifextras.util.UIFactory;

/**
 * A glass pane that can hide areas using translucency.
 * It may contain arbitrary components, e.g. animation renderers.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.8 $
 */
public final class PrompterGlassPane extends JPanel {

	private static final Color HIDDEN_COLOR = new Color(230, 230, 230, 210);


	private final BasicTextLabel textLabel;
	private final GlyphLabel	 glyphLabel;

	private List hiddenItems;


	/**
	 * Constructs a glass pane used by the prompter.
	 */
	PrompterGlassPane() {
		super(null);
		setOpaque(false);
		JLabel unused = UIFactory.createBoldLabel("karsten", 8);
		textLabel = new BasicTextLabel("");
		textLabel.setFont(unused.getFont());
		//textLabel.setBorder(BorderFactory.createLineBorder(Color.red));

		glyphLabel = new GlyphLabel("", 5000, 100, Color.red);
		glyphLabel.setFont(unused.getFont());
		//glyphLabel.setBorder(BorderFactory.createLineBorder(Color.blue));

		add(textLabel);
		add(glyphLabel);
	}


	/**
	 * Sets the list of hidden areas.
	 */
	public void setHiddenItems(List l) {
		this.hiddenItems = l;
	}


	BasicTextLabel	textLabel()		{ return textLabel;	}
	GlyphLabel		glyphLabel()	{ return glyphLabel;	}


	/**
	 * Paints the component: if the list of hidden areas is not null,
	 * it fills every rectangle in this list with a translucent color.
	 */
    @Override
    public void paintComponent(Graphics g) {
    	if (hiddenItems == null)
    		return;

		Rectangle r = null;
		g.setColor(HIDDEN_COLOR);
    	for (Iterator i = hiddenItems.iterator(); i.hasNext();) {
			Object item = i.next();
			if (item instanceof Rectangle) {
				r = (Rectangle) item;
			} else if (item instanceof Component) {
				r = convertedBounds((Component) item);
			} else {
				throw new IllegalStateException("The list hidden items must contain Rectangles or Components. Can't handle " + item.getClass());
			}
			g.fillRect(r.x, r.y, r.width, r.height);
		}
    }


    private Rectangle convertedBounds(Component c) {
		Rectangle r = new Rectangle(0, 0, c.getWidth(), c.getHeight());
		return SwingUtilities.convertRectangle(c, r, ((JFrame) JOptionPane.getRootFrame()).getRootPane());
    }


}
