/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder;

import java.awt.*;
import java.awt.image.BufferedImage;

import javax.swing.ActionMap;
import javax.swing.ImageIcon;
import javax.swing.JOptionPane;
import javax.swing.UIManager;
import javax.swing.plaf.DimensionUIResource;

import com.jgoodies.bookfinder.model.MainModel;
import com.jgoodies.bookfinder.view.main.MainFrame;
import com.jgoodies.looks.Options;
import com.jgoodies.uif.AbstractFrame;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.osx.OSXApplicationMenu;
import com.jgoodies.uif.splash.ImageSplash;
import com.jgoodies.uif.splash.Splash;
import com.jgoodies.uif.util.SystemUtils;
import com.jgoodies.uifextras.convenience.DefaultUIFApplication;
import com.jgoodies.uifextras.convenience.ResourceIDs;

/**
 * This is the main class of the BookFinder application.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.28 $
 */
public final class BookFinder extends DefaultUIFApplication {


    private MainModel mainModel;


    public static void main(String[] arguments) {
        OSXApplicationMenu.setAboutName("Book Finder");
        Application.launch(BookFinder.class, arguments);
    }


    /**
     * Configures the splash to set a brown progress bar.
     * Uses a plain image on OS X, a translucent image with dropshadow on
     * all other platforms. In the latter case, we try to capture the screen
     * to paint the translucent image on top of the desktop background.
     */
    @Override
    protected void configureSplash() {
        ImageIcon icon;
        BufferedImage background = null;
        if (SystemUtils.IS_OS_MAC) {
            icon = getAppResourceMap().getImageIcon(ResourceIDs.SPLASH_IMAGE);
        } else {
            icon = getAppResourceMap().getImageIcon("splash.shadow.image");
            int iconWidth = icon.getIconWidth();
            int iconHeight = icon.getIconHeight();
            Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
            int originX = (screenSize.width - iconWidth) / 2;
            int originY = (int) ((screenSize.height - iconHeight) * 0.45);
            Rectangle bgRect = new Rectangle(originX, originY, iconWidth, iconHeight);
            try {
                background = new Robot().createScreenCapture(bgRect);
                Graphics graphics = background.getGraphics();
                icon.paintIcon(null, graphics, 0, 0);
            } catch (AWTException e) {
                icon = getAppResourceMap().getImageIcon(ResourceIDs.SPLASH_IMAGE);
                System.out.println("Could not capture screen.");
            }
        }
        Image image = background == null ? icon.getImage() : background;
        Splash.setProvider(new ImageSplash(image, true));
        ImageSplash splash = (ImageSplash) Splash.getProvider();
        splash.setProgressBarBounds(80);
        splash.setForeground(new Color(64, 64, 64));
        splash.setBackground(Color.WHITE);
    }


	/**
	 * Configures the user interface.
	 */
	@Override
    protected void configureUI() {
		Options.setDefaultIconSize(new Dimension(18, 18));
        Options.setPopupDropShadowEnabled(true);
		UIManager.put("ToolBar.separatorSize",	new DimensionUIResource(6, 18));

		// Use fixed colors for the header gradients.
		//UIManager.put("SimpleInternalFrame.activeTitleForeground", Color.white);
		//UIManager.put("SimpleInternalFrame.activeTitleBackground", Resources.AMAZON_ORANGE);
		super.configureUI();
	}


	/**
	 * Creates and returns the application's main frame.
	 */
	@Override
    protected AbstractFrame createMainFrame() {
		return new MainFrame(mainModel);
	}


	/**
	 * Initializes the actions used in this demo.
	 */
	@Override
    protected void initializeActions() {
        ActionMap map = Application.getActionMap(mainModel);
        OSXApplicationMenu.register(
                map.get(MainModel.ACTION_OPEN_ABOUT_DIALOG),
                map.get(MainModel.ACTION_OPEN_PREFERENCES),
                map.get(MainModel.ACTION_EXIT));
	}


    /**
     * Brings up the application, it therefore initializes the main frame,
     * checks the setup process, initializes all actions, then builds
     * the main frame, and finally opens it.
     */
    @Override
    protected void launchApplication() {
        // Now add a more sophisticated handler.
        addMessageHandler();

        // Create the model that provides all high-level models.
        Splash.setNote("Creating Models", 30);
        mainModel = new MainModel();

        // Initialize all Actions
        Splash.setNote("Initializing Actions\u2026", 50);
        initializeActions();

        // Create and build the main frame.
        AbstractFrame mainFrame = createMainFrame();
        JOptionPane.setRootFrame(mainFrame);

        checkSetup();

        Splash.setNote("Building UI\u2026", 60);
        mainFrame.build();

        Splash.setNote("Finishing\u2026", 90);
        mainFrame.open();
	}


}
