/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.domain;

import java.util.ArrayList;
import java.util.List;

/**
 * Describes search results as returned by the Amazon.com web services.
 * The result is either an error message, or a list of items plus
 * the number of total results.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.6 $
 */
public final class SearchResult {

    private long   totalResults;
    private int    totalPages;
    private String errorMsg;
    private final List   books;


    // Instance Creation ****************************************************

    /**
     * Constructs an empty <code>SearchResult</code>.
     */
    public SearchResult() {
        books = new ArrayList(10);
    }


    // Accessors ************************************************************

    /**
     * Returns the list of items that matched the search.
     *
     * @return a List of items
     */
    public List getBooks() {
        return books;
    }


    public void addBook(Book book) {
        getBooks().add(book);
    }


    /**
     * Returns the errorMsg.
     *
     * @return the error message
     */
    public String getErrorMsg() {
        return errorMsg;
    }


    /**
     * Returns the total number of results.
     *
     * @return the total number of results
     */
    public long getTotalResults() {
        return totalResults;
    }


    /**
     * Returns the total number of pages.
     *
     * @return the total number of pages
     */
    public long getTotalPages() {
        return totalPages;
    }


    /**
     * Sets the errorMsg.
     *
     * @param errorMsg The errorMsg to set
     */
    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }


    /**
     * Sets the totalResults.
     *
     * @param totalResults The totalResults to set
     */
    public void setTotalResults(long totalResults) {
        this.totalResults = totalResults;
    }

    /**
     * Sets the total number of pages.
     *
     * @param totalPages The number of pages to set
     */
    public void setTotalPages(long totalPages) {
        this.totalResults = totalPages;
    }

}
