/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.model;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import com.jgoodies.binding.beans.Model;
import com.jgoodies.binding.value.ValueHolder;
import com.jgoodies.binding.value.ValueModel;
import com.jgoodies.uif.application.Action;
import com.jgoodies.uif.application.Application;

/**
 * Provides ValueModel for the Book to show and the Buy Now Action.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.11 $
 */
public final class DetailsModel extends Model {

    // Action Resource Keys ***************************************************

    public static final String ACTION_HIDE_DETAILS = "hideDetails";
    public static final String ACTION_BUY_NOW      = "buyNow";


    // Fields *****************************************************************

    private final MainModel mainModel;

    /**
     * Holds the currently selection book.
     */
    private final ValueModel bookHolder;


    // Instance Creation ******************************************************

    /**
     * Constructs a <code>DetailsModel</code> with the book set to null.
     */
    DetailsModel(MainModel mainModel) {
        this.mainModel = mainModel;
        bookHolder = new ValueHolder();
        bookHolder.addValueChangeListener(new BuyNowEnablementHandler());
    }


    // Accessors **************************************************************

    /**
     * Returns the ValueModel that holds the selected book.
     *
     * @return the ValueModel that holds the selected book.
     */
    public ValueModel getBookHolder() {
        return bookHolder;
    }


    @Action
    public void hideDetails() {
        mainModel.getUISettingsModel().setShowingDetails(false);
    }


    /**
     * Opens a web browser and directs it to the Buy Now page
     * for the currently selected book.
     */
    @Action
    public void buyNow() {
        // Not yet implemented.
    }


    // Action Enablement ******************************************************

    /**
     * Listens to the book holder's contents to update the Buy Now enablement.
     */
    private final class BuyNowEnablementHandler implements PropertyChangeListener {
        /**
         * The book selection has changed. Enable the Buy Now action if the
         * selection is non-empty, disable this action if the selection is empty.
         *
         * @param evt    the event that describes the book selection change
         */
        public void propertyChange(PropertyChangeEvent evt) {
            Object book = getBookHolder().getValue();
            Application.getAction(DetailsModel.this, ACTION_BUY_NOW).setEnabled(
                    book != null);
        }

    }


}