/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.request;

import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;

import org.jdom.Element;
import org.jdom.Namespace;

import com.jgoodies.bookfinder.domain.Book;
import com.jgoodies.bookfinder.domain.EditorialReview;
import com.jgoodies.bookfinder.domain.SearchResult;

/**
 * Converts a JDOM root <code>Element</code> into a <code>SearchResult</code>.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
public final class Unmarshaller {

    private static Namespace namespace;


    private Unmarshaller() {
        // Overrides default constructor; prevents instantiation.
    }

    public static SearchResult searchResult(Element root) {
        namespace = root.getNamespace();
        //System.out.println(root.getChild("Items", namespace));
        SearchResult result = new SearchResult();
        for (Iterator i = root.getChildren().iterator(); i.hasNext();) {
            Element child = (Element) i.next();
            String  name  = child.getName();
            if (name.equals("Items")) {
                setItems(result, child);
            } else if (name.equals("ErrorMsg")) {
                result.setErrorMsg(child.getText());
            }
        }
        return result;
    }


    public static void setItems(SearchResult result, Element itemsElement) {
        result.setTotalResults(getInt(itemsElement.getChild("TotalResults", namespace)));
        result.setTotalPages  (getInt(itemsElement.getChild("TotalPages", namespace)));
        for (Iterator i = itemsElement.getChildren().iterator(); i.hasNext();) {
            Element child = (Element) i.next();
            String  name  = child.getName();
            if (name.equals("Item")) {
                result.addBook(book(child));
            }
        }
    }


    private static long getInt(Element element) {
        try {
            return Integer.parseInt(element.getText());
        } catch (NumberFormatException e) {
            return -1;
        }
    }


    private static Book book(Element element) {
        Book book = new Book();

        book.setISBN         (element.getChildText("Asin", namespace));
        book.setSmallImageURL(getImageURL(element, "SmallImage"));
        book.setMediumImageURL(getImageURL(element, "MediumImage"));
        setItemAttributes(book, element.getChild("ItemAttributes", namespace));
        setReviews(book, element.getChild("EditorialReviews", namespace));

        return book;
    }

    private static void setItemAttributes(Book book, Element element) {
        book.setTitle    (element.getChildText("Title", namespace));
        book.setAuthors  (authors(element.getChildren("Author", namespace)));
        Element listPriceElement = element.getChild("ListPrice", namespace);
        if (listPriceElement != null) {
            book.setListPrice(listPriceElement.getChildText("FormattedPrice", namespace));
        }

        // Details
        book.setBinding  (element.getChildText("Binding", namespace));
        book.setPages    (element.getChildText("NumberOfPages", namespace));
        book.setPublisher(element.getChildText("Publisher", namespace));
        book.setPublicationDate(element.getChildText("PublicationDate", namespace));
        book.setISBN     (element.getChildText("ISBN", namespace));
    }


    private static String getImageURL(Element element, String elementName) {
        Element imageElement = element.getChild(elementName, namespace);
        return imageElement == null
            ? null
            : imageElement.getChildText("URL", namespace);
    }


    private static List authors(List authorElements) {
        List authors = new LinkedList();
        for (Iterator i = authorElements.iterator(); i.hasNext();) {
            Element child = (Element) i.next();
            authors.add(child.getText());
        }
        return authors;
    }


    private static void setReviews(Book book, Element element) {
        if (element == null) {
            return;
        }
        List reviews = new LinkedList();
        for (Iterator i = element.getChildren("EditorialReview", namespace).iterator(); i.hasNext();) {
            Element child = (Element) i.next();
            reviews.add(review(child));
        }
        book.setReviews(reviews);
    }


    private static EditorialReview review(Element element) {
        EditorialReview editorialReview = new EditorialReview();

        editorialReview.setSource(element.getChildText("Source", namespace));
        editorialReview.setContent(element.getChildText("Content", namespace));

        return editorialReview;
    }


}
