/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.request.query;

import java.net.URL;

import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;

/**
 * An implementation of <code>XMLQuery</code> that simulates access a keyword
 * request to the Amazon.com web services. It uses a prebuilt XML files from
 * local resources.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.11 $
 */
public final class SimulatedKeywordQuery extends AbstractXMLQuery {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(SimulatedKeywordQuery.class);

    private static SimulatedKeywordQuery query;

    private final String searchType;
    private final URL    localURL;


    // Instance Creation ******************************************************

    public static XMLQuery getSampleQuery() {
        if (query == null) {
            query = new SimulatedKeywordQuery(
                    "Keyword",
                    "gui",
                    RESOURCES.getURL("sampleResult.path"));
        }
        return query;
    }


    /**
     * Constructs a simulated XML query using the given query type, query data,
     * and the specified path to the prebuilt XML file.
     */
    private SimulatedKeywordQuery(String searchType, String searchData,
                                  URL url) {
        super(null, searchData);
        this.searchType = searchType;
        this.localURL = url;
    }


    // Abstract Behavior ******************************************************

    /**
     * Returns the query's search type, for example: 'author', 'key', or ISBN.
     */
    @Override
    public String getSearchType() {
        return searchType;
    }


    /**
     * Returns the query's search code, as used in the query URL, for example:
     * 'KeywordSearch'.
     */
    @Override
    protected String getOperation() {
        return "unused";
    }


    // Overriding Default Behavior ********************************************

    /**
     * Computes and returns the URL used to execute the query for the specified
     * page no.
     */
    @Override
    protected URL getQueryURL(int page) {
        return localURL;
    }


    // Helper Code ************************************************************

    @Override
    public String toString() {
        return "Simulated Query: searchType=" + searchType + "; searchData="
                + getSearchData();
    }

}