/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.view.dialog;

import javax.swing.JComponent;
import javax.swing.JTextField;

import com.jgoodies.binding.PresentationModel;
import com.jgoodies.binding.adapter.BasicComponentFactory;
import com.jgoodies.bookfinder.request.WebService;
import com.jgoodies.forms.builder.DefaultFormBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.uif.AbstractView;

/**
 * Builds the <i>Web Services</i> tab in the
 * {@link com.jgoodies.bookfinder.view.dialog.PreferencesDialog}.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.9 $
 */
final class WebServiceTabView extends AbstractView {

    private final PresentationModel webServiceModel;


    private JTextField hostField;
    private JTextField pathField;
    private JTextField tagField;
    private JTextField tokenField;


    // Instance Creation ******************************************************

    /**
     * Constructs the <em>Web Services</em> tab of the PreferencesDialog.
     *
     * @param webServiceModel   provides ValueModels for the web service
     *     properties
     */
    WebServiceTabView(PresentationModel webServiceModel) {
        this.webServiceModel = webServiceModel;
    }


    // Initialization *********************************************************

    private void initComponents() {
        hostField = BasicComponentFactory.createTextField(
                webServiceModel.getBufferedModel(WebService.PROPERTYNAME_HOST),
                true);
        hostField.setColumns(20);

        pathField = BasicComponentFactory.createTextField(
                webServiceModel.getBufferedModel(WebService.PROPERTYNAME_PATH),
                true);
        pathField.setColumns(10);

        tagField = BasicComponentFactory.createTextField(
                webServiceModel.getBufferedModel(WebService.PROPERTYNAME_TAG),
                true);
        tagField.setColumns(10);

        tokenField = BasicComponentFactory.createTextField(
                webServiceModel.getBufferedModel(WebService.PROPERTYNAME_ACCESS_KEY),
                true);
        tokenField.setColumns(20);
    }


    // Building ***************************************************************

    /**
     * Builds and returns the web services configuration panel.
     *
     * @return the web services configuration panel.
     */
    @Override
    protected JComponent buildPanel() {
        initComponents();

        FormLayout layout = new FormLayout(
            "pref, $lcgap, pref");

        DefaultFormBuilder builder = new DefaultFormBuilder(layout);
        builder.setBorder(Borders.DLU14_BORDER);
        builder.setOpaque(false);
        builder.append("&Host:",       hostField);
        builder.append("&Path:",       pathField);
        builder.append("&Tag:",        tagField);
//      builder.append("&Access Key:", tokenField);

        return builder.getPanel();
    }


}
