/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.view.main;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.image.ImageObserver;

import javax.swing.*;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;

import com.jgoodies.binding.adapter.BasicComponentFactory;
import com.jgoodies.bookfinder.domain.Book;
import com.jgoodies.bookfinder.model.MainModel;

/**
 * Builds the summary list that displays the search results.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.4 $
 *
 * @see MainModel
 */
final class ResultListSummaryView {

    private JList list;


    /**
     * Builds, binds, configures and returns this overview list.
     *
     * @param mainModel   used to access the result SelectionInList
     * @return the overview list
     */
    JComponent build(MainModel mainModel) {
        list = BasicComponentFactory.createList(
                mainModel.getSelectionInFilteredBook(),
                new OverviewSummaryCellRenderer(list));
        list.setLayoutOrientation(JList.HORIZONTAL_WRAP);
        return list;
    }


    // Helper Class *********************************************************

    /**
     * A renderer that has an icon in the left, and three rows in the right:
     * Product name, authors, price.
     */
    private static final class OverviewSummaryCellRenderer
        extends DefaultListCellRenderer {

        private static final int MINIMUM_WIDTH = 220;
        private static final Border SEPARATOR_BORDER =
            new EmptyBorder(0, 0, 20, 0);

        private final ImageObserver imageObserver;

        private OverviewSummaryCellRenderer(ImageObserver imageObserver) {
            this.imageObserver = imageObserver;
        }

        @Override
        public Component getListCellRendererComponent(
            JList list,
            Object value,
            int index,
            boolean isSelected,
            boolean cellHasFocus) {
            super.getListCellRendererComponent(
                list,
                value,
                index,
                isSelected,
                cellHasFocus);
            Book details = (Book) value;
            setHorizontalTextPosition(JLabel.CENTER);
            setHorizontalAlignment(JLabel.CENTER);
            setVerticalTextPosition(JLabel.BOTTOM);
            setVerticalAlignment(JLabel.BOTTOM);
            setBorder(SEPARATOR_BORDER);
            Icon baseIcon =
                details.getSmallImageURL() == null
                    ? null
                    : Utils.dropIcon(
                            Utils.asynchronousIcon(
                            details.getSmallImageURL(),
                            imageObserver),
                        isSelected);
            setIcon(Utils.minimumSizeIcon(baseIcon, 50, 70));
            setText(details.getAuthorsEtAl());
            // Reset the preferred size, so it will be recomputed.
            setPreferredSize(null);
            Dimension d = getPreferredSize();
            setPreferredSize(
                new Dimension(Math.max(MINIMUM_WIDTH, d.width), d.height));
            return this;
        }
    }

}