/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.view.main;

import javax.swing.JComponent;
import javax.swing.JTextArea;

import com.jgoodies.binding.adapter.Bindings;
import com.jgoodies.binding.beans.PropertyAdapter;
import com.jgoodies.bookfinder.model.SearchResultModel;
import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.uifextras.util.UIFactory;

/**
 * A panel that displays messages related to the search result overview,
 * for example, connection failures.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.3 $
 *
 * @see SearchResultModel
 */

final class ResultMessageView {

    private final SearchResultModel searchResultModel;

    private JTextArea messageArea;


    // Instance Creation ******************************************************

    ResultMessageView(SearchResultModel searchResultModel) {
        this.searchResultModel = searchResultModel;
    }


    // ************************************************************************

    /**
     * Creates, binds and configures the UI components.
     */
    private void initComponents() {
        messageArea = UIFactory.createWrappedMultilineLabel("");
        Bindings.bind(messageArea,
                new PropertyAdapter(
                        searchResultModel,
                        SearchResultModel.PROPERTYNAME_MESSAGE,
                        true));
    }

    /**
     * Builds and returns the message panel.
     */
    JComponent build() {
        initComponents();

        FormLayout layout = new FormLayout(
            "pref, 7dlu, 0:grow",
            "pref");
        PanelBuilder builder = new PanelBuilder(layout);
        builder.setDefaultDialogBorder();
        CellConstraints cc = new CellConstraints();

        builder.add(messageArea, cc.xy(3, 1));
        return builder.getPanel();
    }


}