/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.bookfinder.view.main;

import java.awt.Dimension;

import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.ListModel;

import com.jgoodies.binding.adapter.AbstractTableAdapter;
import com.jgoodies.binding.adapter.SingleListSelectionAdapter;
import com.jgoodies.binding.list.SelectionInList;
import com.jgoodies.bookfinder.domain.Book;
import com.jgoodies.bookfinder.model.MainModel;
import com.jgoodies.uifextras.util.ExtTable;

/**
 * Builds the overview table.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.5 $
 *
 * @see MainModel
 */
final class ResultTableView {

	private static final String[] COLUMN_NAMES = {" Title", " Authors", " Price "};
	private static final int[]	ALIGNMENTS   = {JLabel.LEFT, JLabel.LEFT, JLabel.RIGHT};
	private static final int[]	COLUMN_SIZES = new int[]{300, 150, 55};

	private ExtTable table;


	/**
	 * Creates, configures and returns the overview table.
	 *
     * @param mainModel   used to access the result SelectionInList
	 * @return the configured overview table
	 */
    JTable build(MainModel mainModel) {
        SelectionInList sil = mainModel.getSelectionInFilteredBook();
        table = new ExtTable();
        table.setHeaderAlignments(ALIGNMENTS);
        table.setColumnSizes(COLUMN_SIZES);
        table.setAutoResizeMode(JTable.AUTO_RESIZE_NEXT_COLUMN);
        table.setModel(new OverviewTableModel(sil));
        table.setSelectionModel(new SingleListSelectionAdapter(sil.getSelectionIndexHolder()));
        table.setMinimumSize(new Dimension(200, 200));
        table.setRowSelectionAllowed(true);
        table.setEnabled(true);
        return table;
    }


	// Helper Class *********************************************************

	private static final class OverviewTableModel extends AbstractTableAdapter {

		private OverviewTableModel(ListModel listModel) {
			super(listModel, COLUMN_NAMES);
		}

		public Object	getValueAt(int row, int col) {
			Book details = (Book) getRow(row);
			switch (col) {
				case 0 : return details.getTitle();
				case 1 : return details.getAuthorsEtAl();
				case 2 : return details.getListPrice();
				default: return null;
			}
		}

	}


	// Code that I may use to extend the ExtTable to improve the column resizing.
	/*
    public void sizeColumnsToFit(int resizingColumn) {
        if (resizingColumn != -1) {
        	super.sizeColumnsToFit(resizingColumn);
        	return;
        }
        // An algorithm here that distributes space over the first two columns
	}
	*/




}