/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.forms.demo.domain;


/**
 * Describes an example in the JGoodies Forms Demo.
 *
 * @author Karsten Lentzsch
 */
public final class Example {

    /**
     * The name of the unbound property <em>description</em>.
     */
    public static final String PROPERTYNAME_DESCRIPTION = "description";

    private final String name;
    private final String description;
    private final Object builder;


    // Instance Creation ******************************************************

    /**
     * Constructs an <code>Example</code> for the given name,
     * description and builder.
     *
     * @param name         a string that identifies the example
     * @param description  a text that describes the example
     * @param builder      the instance that builds the example panel
     */
    public Example(String name, String description, Object builder) {
        this.name        = name;
        this.description = description;
        this.builder     = builder;
    }


    // Accessors **************************************************************

    /**
     * Returns the associated design builder.
     *
     * @return the builder
     */
    public Object getBuilder() {
        return builder;
    }

    /**
     * Returns the method name used to build the design.
     *
     * @return the name of the method that builds the panel
     */
    public String getBuildMethodName() {
        return "buildPanel";
    }

    /**
     * Returns this example's text description.
     *
     * @return a text that describes this example
     */
    public String getDescription() {
        return description;
    }

    /**
     * Returns this example's name.
     *
     * @return this example's name
     */
    public String getName() {
        return name;
    }

}
