/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.forms.demo.model;

import java.awt.Frame;
import java.awt.event.ActionEvent;

import com.jgoodies.binding.beans.Model;
import com.jgoodies.binding.list.SelectionInList;
import com.jgoodies.forms.demo.domain.Example;
import com.jgoodies.forms.demo.view.PreferencesDialog;
import com.jgoodies.uif.application.Action;
import com.jgoodies.uif.application.ApplicationContext;
import com.jgoodies.uif.util.WindowUtils;
import com.jgoodies.uifextras.convenience.DefaultAboutDialog;
import com.jgoodies.uifextras.help.HelpBroker;

/**
 * Provides the models and Actions required to build the
 * {@link com.jgoodies.forms.demo.view.MainFrame}, its menu bar and sub views.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.17 $
 */
public final class MainModel extends Model {

    // Names of the Bound Bean Properties *************************************

    public static final String PROPERTY_VIEW_MODE = "viewMode";


    // Action Resource Keys ***************************************************

    public static final String ACTION_SKIP_INTRO          = "skipIntro";
    public static final String ACTION_OPEN_PREFERENCES    = "openPreferences";
    public static final String ACTION_EXIT                = "exit";
    public static final String ACTION_OPEN_HELP_CONTENTS  = "openHelpContents";
    public static final String ACTION_OPEN_ABOUT_DIALOG   = "openAboutDialog";


    // Other Public Static Fields *********************************************

    public static final MainModel INSTANCE =
        new MainModel();

    // Enumerations ***********************************************************

    public enum ViewMode { INTRO, MAIN }

    /**
     * Holds the available examples and the currently selected example.
     */
    private final SelectionInList<Example> examplesModel
        = new SelectionInList<Example>();

    private ViewMode viewMode = ViewMode.INTRO;


    // Instance Creation ******************************************************

    private MainModel() {
        // Overrides default constructor.
    }


    // Accessing Models *******************************************************

    /**
     * Returns the examples model, a selection in a list.
     */
    public SelectionInList<Example> getExamplesModel() {
        return examplesModel;
    }

    public ViewMode getViewMode() {
        return viewMode;
    }

    private void setViewMode(ViewMode newViewMode) {
        ViewMode oldViewMode = getViewMode();
        viewMode = newViewMode;
        firePropertyChange(PROPERTY_VIEW_MODE, oldViewMode, newViewMode);
    }


    // Accessing Actions ******************************************************

    public Runnable getSkipRunnable() {
        return new Runnable() {
            public void run() {
                skipIntro();
            }
        };
    }


    // Action Operations ******************************************************

    /**
     * Sets the {@code MAIN} ViewMode,
     * which in turn lets the main frame switch cards.
     */
    @Action
    public void skipIntro() {
        setViewMode(ViewMode.MAIN);
    }


    @Action
    public void openPreferences(ActionEvent e) {
        new PreferencesDialog((Frame) WindowUtils.getParent(e)).open();
    }


    @Action
    public void exit(ActionEvent e) {
        ApplicationContext.getInstance().getApplication().exit(e);
    }


    @Action
    public void openHelpContents() {
        HelpBroker.openDefault();
    }


    @Action
    public void openAboutDialog(ActionEvent e) {
        new DefaultAboutDialog((Frame) WindowUtils.getParent(e)).open();
    }


}
