/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.forms.demo.view;

import java.awt.Insets;

import javax.swing.JComponent;
import javax.swing.JTextArea;

import com.jgoodies.binding.adapter.Bindings;
import com.jgoodies.binding.beans.BeanAdapter;
import com.jgoodies.binding.value.ValueModel;
import com.jgoodies.forms.demo.domain.Example;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.panel.SimpleInternalFrame;
import com.jgoodies.uifextras.util.UIFactory;

/**
 * A view that displays the description of the current example.
 *
 * @author Karsten Lentzsch
 */
final class DescriptionView extends AbstractView {

    /**
     * This view's presentation model. We use a BeanAdapter instead
     * of a PresentationModel, just because the latter requires beans
     * with bound properties - but the Example bean has unbound properties.
     */
    private final BeanAdapter<Example> model;

    private JTextArea area;


    /**
     * Constructs the DescriptionView for the given ValueModel that
     * holds the currently selected example.
     */
    DescriptionView(ValueModel exampleHolder) {
        this.model = new BeanAdapter<Example>(exampleHolder, false);
    }


    // Building ***************************************************************

    private void initComponents() {
        area = UIFactory.createInfoTextArea();
        area.setColumns(60);
        area.setRows(5);
        area.setMargin(new Insets(6, 10, 4, 6));
        area.setLineWrap(true);
        area.setWrapStyleWord(true);
        Bindings.bind(area, model.getValueModel(Example.PROPERTYNAME_DESCRIPTION));
    }


    @Override
    protected JComponent buildPanel() {
        initComponents();

        SimpleInternalFrame panel = new SimpleInternalFrame(null, "Description");
        panel.setContent(area);
        return panel;
    }


}