/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.forms.demo.view;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.lang.reflect.Method;

import javax.swing.JComponent;
import javax.swing.JPanel;

import com.jgoodies.binding.value.ValueModel;
import com.jgoodies.forms.demo.domain.Example;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.panel.SimpleInternalFrame;

/**
 * Presents the Forms Demo's example layouts.
 *
 * @author Karsten Lentzsch
 */
final class LayoutView extends AbstractView {

    private static final JPanel EMPTY_PANEL = new JPanel(null);


    private final ValueModel exampleModel;


    // Instance Creation ******************************************************

    /**
     * Constructs the layout view for the given ValueModel
     * that holds the current example.
     */
    LayoutView(ValueModel exampleModel) {
        this.exampleModel = exampleModel;
    }


    // Initialization *********************************************************

    private void initEventHandling() {
        exampleModel.addValueChangeListener(new ExampleChangeHandler());
    }


    // Building ***************************************************************

    /**
     * Builds and returns the panel content.
     */
    @Override
    protected JComponent buildPanel() {
        initEventHandling();

        SimpleInternalFrame panel = new SimpleInternalFrame(null, "Layout");
        setExampleContent(panel, (Example) exampleModel.getValue());
        return panel;
    }


    // Helper Code ************************************************************

    private void setExampleContent(SimpleInternalFrame panel, Example example) {
        JComponent content = example == null
            ? EMPTY_PANEL
            : buildExamplePanel(example);
        panel.setContent(content);
//        if (example != null) {
//            panel.setTitle("Layout: " + example.getName());
//        }
        panel.revalidate();
        panel.repaint();
    }


    private JComponent buildExamplePanel(Example example) {
        Object builder = example.getBuilder();
        String methodName = example.getBuildMethodName();

        try {
            Class<?> clazz = builder.getClass();
            Method method  = clazz.getMethod(methodName, (Class[])  null);
            return (JComponent) method.invoke(builder,   (Object[]) null);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return EMPTY_PANEL;

    }


    private final class ExampleChangeHandler implements PropertyChangeListener {

        public void propertyChange(PropertyChangeEvent e) {
            setExampleContent(
                    (SimpleInternalFrame) getPanel(),
                    (Example) e.getNewValue());
        }
    }

}