/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.chart;

import java.awt.Color;

import javax.swing.Icon;
import javax.swing.event.ChangeListener;

/**
 * Describes the model required by charts.
 *
 * @param <T>  the type of the user data
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.3 $
 */
public interface ChartModel<T> {

    /**
     * Returns the number of items in this model.
     *
     * @return the number of items in this model
     */
    int getItemCount();


    /**
     * Returns the user data at the given index.
     *
     * @param index   the index to look at
     * @return the user data object at the given index
     *
     * @throws IndexOutOfBoundsException  if the index is out of bounds
     */
    T getData(int index);


    /**
     * Returns the icon at the given index.
     * Charts may display the icon or not.
     *
     * @param index   the index to look at
     * @return the icon at the given index
     *
     * @throws IndexOutOfBoundsException  if the index is out of bounds
     */
    Icon getIcon(int index);


    /**
     * Returns the text at the given index.
     * Charts may display the text or not.
     *
     * @param index   the index to look at
     * @return the text at the given index
     *
     * @throws IndexOutOfBoundsException  if the index is out of bounds
     */
    String getText(int index);


    /**
     * Returns the mandatory size at the given index.
     *
     * @param index   the index to look at
     * @return the icon at the given index
     *
     * @throws IndexOutOfBoundsException  if the index is out of bounds
     */
    long getSize(int index);


    /**
     * Returns the color of the item at the given index.
     * Some chart models may return {@code null} and leave it
     * to a wrapper chart model to colorize the data.
     *
     * @param index   the index to look at
     * @return the color at the given index
     *
     * @throws IndexOutOfBoundsException  if the index is out of bounds
     */
    Color getColor(int index);


    // Managing Listeners *****************************************************

    /**
     * Adds the given listener to the list of observers.
     *
     * @param listener    the listener to be added
     *
     * @throws NullPointerException if the listener is {@code null}
     */
    void addChangeListener(ChangeListener listener);


    /**
     * Removes the given listener fromthe list of observers.
     * Does nothing if the listener is null.
     *
     * @param listener    the listener to be added
     */
    void removeChangeListener(ChangeListener listener);


}
