/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.chart;

import java.awt.FontMetrics;

/**
 * The abstract superclass of all chart classes; provides
 * caching behavior and code common to all subclasses.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.3 $
 */
final class ChartUtils {

    // Constants **************************************************************

    private static final String ELLIPSIS = "\u2026";


    private ChartUtils() {
        // Overrides default constructor; prevents instantiation.
    }


    // Accessors **************************************************************

    /**
     * Clips and returns a string, so that it fits the given <code>availableWidth</code>.
     */
    static String clipText(String str, FontMetrics fm, int availableWidth) {
        int width = fm.stringWidth(str);
        if (width <= availableWidth) {
            return str;
        }

        int totalWidth = fm.stringWidth(ELLIPSIS);
        int nChars;
        for (nChars = 0; nChars < str.length(); nChars++) {
            totalWidth += fm.charWidth(str.charAt(nChars));
            if (totalWidth > availableWidth) {
                break;
            }
        }
        return str.substring(0, nChars) + ELLIPSIS;
    }



}
