/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.chart;

import javax.swing.event.ChangeListener;


/**
 * Describes the model required by the ring chart and tree map.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.3 $
 */
public interface TreeChartModel<T>  {

    /**
     * Returns this tree's root node.
     *
     * @return the root node
     */
    T getRoot();


    /**
     * Returns the number of children of the given node.
     *
     * @return the number of chilren of the given node
     */
    int getChildCount(T node);


    T getChild(T node, int index);


    /**
     * Returns the size of the given node.
     */
    long getSize(T node);


    /**
     * Used to determine how to color the node in a tree map.
     *
     * @param node  the node to be checked
     * @return true if leaf, false otherwise
     */
    boolean isLeaf(T node);


    // Managing Listeners *****************************************************

    /**
     * Adds the given listener to the list of observers.
     *
     * @param listener    the listener to be added
     *
     * @throws NullPointerException if the listener is {@code null}
     */
    void addChangeListener(ChangeListener listener);


    /**
     * Removes the given listener fromthe list of observers.
     * Does nothing if the listener is null.
     *
     * @param listener    the listener to be added
     */
    void removeChangeListener(ChangeListener listener);


}
