/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.chart;

import java.awt.Color;
import java.awt.Graphics2D;


/**
 * Paints a tree as inner pie chart with outer ring segments.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
public final class TreeMapChart<T> extends AbstractTreeChart<T> {

    // Constants **************************************************************

    private static final int MAX_LEVEL = 35;


    // Instance Creation ******************************************************

    public TreeMapChart(TreeChartModel<T> model) {
        super(model);
    }


    // Painting ***************************************************************

    @Override
    protected void render(Graphics2D g2, T root) {
        int level = 0;
        float startHue = 0f;
        float stopHue = 1f;
        float saturation = 0.5f;
        float brightness = 0.9f;
        render(g2, root, level,
                0, 0, getWidth(), getHeight(),
                startHue, stopHue, saturation, brightness);
    }


    private void render(Graphics2D g2, T node, int level,
            int x, int y, int width, int height,
            float startHue, float stopHue,
            float saturation, float brightness) {
//        System.out.println();
//        System.out.print("Level=" + level);
//        if (node instanceof AbstractNode) {
//            AbstractNode aNode = (AbstractNode) node;
//            System.out.println("; name=" + aNode.getName());
//        }
        //System.out.println("x=" + x + "; y=" + y + "; width=" + width + "; height=" + height);
        int childCount = model.getChildCount(node);
        if (model.isLeaf(node)) {
            Color fillColor = Color.getHSBColor(startHue, saturation, brightness);
            g2.setColor(fillColor);
            g2.fillRect(x, y, width-1, height-1);
        }
        if (level < MAX_LEVEL) {
            boolean isEven = level % 2 == 0;
            int extent = isEven ? width : height;
            int[] extents = computePartitions(node, extent);
            int start = isEven ? x : y;
            double totalHue = stopHue - startHue;
            for (int i = 0; i < childCount; i++) {
                T childNode = model.getChild(node, i);
                int childExtent = extents[i];
                double nextChildStartHue = startHue + (totalHue * (i     / 14f));
                double nextChildStopHue  = startHue + (totalHue * ((i+1) / 14f));
                render(g2, childNode, level+1,
                        isEven ? start : x,
                        isEven ? y : start,
                        isEven ? childExtent : width,
                        isEven ? height : childExtent,
                        (float) nextChildStartHue, (float) nextChildStopHue,
                        saturation*0.9f,
                        brightness);
                start += childExtent;
            }
        }
    }


}
