/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.domain;

import java.io.Serializable;


/**
 * Describes directories.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.6 $
 */
public class Directory implements Serializable {

    private static final long serialVersionUID = 1L;

    private final String name;
    private final Directory[] directories;
    private final FileInfo[] files;
    private final boolean illegalAccess;


    // Instance Creation ******************************************************

    /**
     * Constructs a DirectoryNode for the given name, size,
     * the children, and the size and count of the tree starting at this node.
     * Sets this node as parent for all its children.
     */
    public Directory(String name, Directory[] directories, FileInfo[] files) {
        this.name = name;
        this.directories = directories;
        this.files = files;
        this.illegalAccess = false;
    }


    public Directory(String name) {
        this.name = name;
        this.directories = new Directory[0];
        this.files = new FileInfo[0];
        this.illegalAccess = true;
    }


    // Accessors **************************************************************


    public String getName() {
        return name;
    }


    public Directory[] getDirectories() {
        return directories;
    }


    public FileInfo[] getFiles() {
        return files;
    }


    public boolean getIllegalAccess() {
        return illegalAccess;
    }

}
