/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.domain;

import java.io.File;
import java.io.IOException;



/**
 * Provides only static convenience behavior for Files.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 */
public final class FileUtils {

	private FileUtils() {
        // Overrides default constructur; prevents instantiation.
    }


//    /**
//     * Checks and answers whether the file seems to be a link.
//     * If the operating system supports links, compare the absolute path
//     * with the canonical path.<p>
//     *
//     * This method returns a good guess, however, the result can be wrong.
//     * For example, because a file system implements a link in a way that
//     * is not detected by the Java file abstraction.
//     *
//     * @param file   the file to check
//     * @return true if the file seems to be a link
//     *
//     * @see #isLink(File, String)
//     */
//    private static boolean isLink(File file) {
//        return isLink(file, getCanonicalPath(file));
//    }


    /**
     * Checks and answers whether the file seems to be a link.
     * If the operating system support links,
     * compare the absolute path with the canonical path.<p>
     *
     * This methods gets the file's canonical path, just because this
     * can save a lot of time. Building the canonical path can be a
     * heavy operation on some operating systems.
     *
     * @param file   the file to check
     * @param itsCanonicalPath   the file's canonical path
     * @return true if the file seems to be a link
     */
    public static boolean isLink(File file, String itsCanonicalPath) {
        return !file.getAbsolutePath().equals(itsCanonicalPath);
    }


    /**
     * Guesses and returns the length of a link
     * using the length of the file's canonical path.
     *
     * @param file   the file that represents the link
     * @return the guessed link length in bytes
     */
    public static int linkLength(File file) {
        return getCanonicalPath(file).length();
    }


    /**
     * Looks up and returns the canonical path for the given file.
     * IOExceptions are silently catched and in such a case the
     * absolute path is returned.
     *
     * @param file   the file to build the canonical path for
     * @return the canonical path for the given file
     */
    public static String getCanonicalPath(File file) {
        try {
            return file.getCanonicalPath();
        } catch (IOException e) {
            return file.getAbsolutePath();
        }
    }


}
