/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.domain;

import java.util.logging.Logger;

/**
 * Provides convenience behavior to determine the operating system
 * and a few other odds and ends.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 */

public final class SystemUtils {

    /**
     * The <code>os.name</code> System Property. Operating system name.<p>
     *
     * Defaults to {@code null} if the runtime does not have security
     * access to read this property or the property does not exist.
     */
    private static final String OS_NAME = getSystemProperty("os.name");

    /**
     * Is true if this is the Windows OS.
     */
    public static final boolean IS_OS_WINDOWS = startsWith(OS_NAME, "Windows");


    private SystemUtils() {
        // Override default constructor; prevents instantiation.
    }


    // Private Helper Methods ***********************************************************

    /**
     * Tries to look up the System property for the given key.
     * In untrusted environments this may throw a SecurityException.
     * In this case we catch the exception and answer an empty string.
     *
     * @param key   the name of the system property
     * @return the system property's String value, or {@code null} if there's
     *     no such value, or an empty String when
     *     a SecurityException has been catched
     */
    private static String getSystemProperty(String key) {
        try {
            return System.getProperty(key);
        } catch (SecurityException e) {
            Logger.getLogger(SystemUtils.class.getName()).warning(
                  "Can't access the System property " + key + ".");
            return "";
        }
    }


    private static boolean startsWith(String str, String prefix) {
        return str != null && str.startsWith(prefix);
    }

}