/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model;

import java.awt.event.ActionEvent;

import javax.swing.JOptionPane;

import com.jgoodies.binding.beans.Model;
import com.jgoodies.jdiskreport.model.node.DirectoryNode;
import com.jgoodies.jdiskreport.model.node.RootNode;
import com.jgoodies.jdiskreport.model.settings.GUISettings;
import com.jgoodies.uif.application.Action;
import com.jgoodies.uif.util.WindowUtils;
import com.jgoodies.uifextras.history.History;

/**
 * Provides bound properties, operations and Actions
 * for the navigation tree.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
public final class MainModel extends Model {

    // Names of the Bound Bean Properties *************************************

    public static final String PROPERTYNAME_ROOT_NODE = "rootNode";


    // Action Resource Keys ***************************************************

    public static final String ACTION_UPDATE              = "update";
    public static final String ACTION_SCAN                = "scan";
    public static final String ACTION_EXPORT              = "export";
    public static final String ACTION_PRINT               = "print";
    public static final String ACTION_HELP                = "help";


    // Instance Fields ********************************************************

    /**
     * Holds the model for the navigation tree.
     *
     * @see #navigationModel()
     */
    private final NavigationModel navigationModel;

    private History<DirectoryNode> history;

    private final PresentationModel presentationModel;

    private final GUISettings guiSettings;


    private RootNode rootNode;


    // Instance Creation ******************************************************

    /**
     * Constructs a MainModel for the given root node.
     *
     * @param rootNode  the initial root node
     */
    public MainModel(RootNode rootNode) {
        this.guiSettings = new GUISettings();
        this.rootNode = rootNode;
        this.navigationModel = new NavigationModel(this);
        this.presentationModel = new PresentationModel(this);
    }


    // Submodels **************************************************************

    public NavigationModel navigationModel() {
        return navigationModel;
    }


    public History<DirectoryNode> history() {
        if (history == null) {
            history = new History<DirectoryNode>(10);
        }
        return history;
    }


    public PresentationModel presentationModel() {
        return presentationModel;
    }


    public GUISettings guiSettings() {
        return guiSettings;
    }


    // Accessors **************************************************************

    public RootNode getRootNode() {
        return rootNode;
    }


    /**
     * Sets a new root node.
     *
     * @param newRootNode   the root node to set
     *
     * @see #getRootNode()
     */
    public void setRootNode(RootNode newRootNode) {
        RootNode oldRootNode = getRootNode();
        rootNode = newRootNode;
        firePropertyChange(PROPERTYNAME_ROOT_NODE, oldRootNode, newRootNode);
    }


    // Actions ****************************************************************

    @Action
    public void update(ActionEvent e) {
        notYetImplemented(e);
    }


    @Action
    public void scan(ActionEvent e) {
        notYetImplemented(e);
    }


    @Action
    public void export(ActionEvent e) {
        notYetImplemented(e);
    }


    @Action
    public void print(ActionEvent e) {
        notYetImplemented(e);
    }


    @Action
    public void help(ActionEvent e) {
        notYetImplemented(e);
    }


    // Helper Code ************************************************************

    private void notYetImplemented(ActionEvent e) {
        JOptionPane.showMessageDialog(WindowUtils.getParent(e), "Not yet implemented");
    }

}