/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.node;

import java.io.File;

import javax.swing.Icon;

import com.jgoodies.uifextras.fileaccess.ExtFileSystemView;


/**
 * The abstract superclass for directory and file nodes.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
public abstract class AbstractNode {

    /**
     * Refers to this nodes parent directory node.
     */
    private DirectoryNode parent;

    /**
     * The lazily created file. May be cleared to save memory.
     */
    private File file;


    // Accessors **************************************************************

    public abstract String getName();


    public abstract boolean isFileLeaf();


    public File getFile() {
        if (file == null) {
            //System.out.println("Getting file for " + getName());
            file = new File(getParent().getFile(), getName());
        }
        return file;
    }


    public abstract long getSize();


    public abstract long getFileCount();


    public float getAbsoluteSize() {
        float mySize = getSize();
        long rootSize = getRoot().getSize();
        return rootSize == 0L ? 1f : mySize / rootSize;
    }


    public float getRelativeSize() {
        float mySize = getSize();
        long parentSize = getParent().getSize();
        return parentSize == 0L ? 1f : mySize / parentSize;
    }


    public Icon getIcon(boolean selected) {
        return ExtFileSystemView.getInstance().getIcon(getFile(), selected);
    }


    public RootNode getRoot() {
        return getParent().getRoot();
    }

    /**
     * Returns this node's parent <code>DirectoryNode</code>.
     */
    public DirectoryNode getParent() {
        return parent;
    }


    /**
     * Sets this nodes parent to the given directory node.
     * Invoked by the DirectoryNode constructor for every directory node child.
     */
    void setParent(DirectoryNode parent) {
        this.parent = parent;
    }


    // Caching ****************************************************************

    public void clearCachedFiles() {
        file = null;
    }


}
