/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.node;

import java.io.File;

import javax.swing.Icon;
import javax.swing.UIManager;

import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;


/**
 * A synthetic node that is used to represent all files in a directory.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.10 $
 */
public final class CollapsedFilesNode extends AbstractNode {

    private final static ResourceMap RESOURCES =
        Application.getResourceMap(CollapsedFilesNode.class);


    private final long size;
    private final long count;


    // Instance Creation ******************************************************

    /**
     * Constructs a synthetic node for the given size and count.
     */
    public CollapsedFilesNode(DirectoryNode parent, long size, long count) {
        setParent(parent);
        this.size = size;
        this.count = count;
    }


    // Accessors **************************************************************

    @Override
    public String getName() {
        return RESOURCES.getString("CollapsedFilesNode.name");
    }

    @Override
    public boolean isFileLeaf() {
        return true;
    }

    @Override
    public File getFile() {
        return new File(getName());
    }


    @Override
    public long getSize() {
        return size;
    }


    @Override
    public long getFileCount() {
        return count;
    }


    @Override
    public Icon getIcon(boolean selected) {
        return UIManager.getIcon("FileView.fileIcon");
    }


}
