/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.node;

import javax.swing.Icon;

import com.jgoodies.jdiskreport.domain.FileInfo;
import com.jgoodies.uifextras.fileaccess.ExtFileSystemView;


/**
 * A node for files, not directories.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.10 $
 */
public final class FileNode extends AbstractNode {

    private final FileInfo fileInfo;


    // Instance Creation ******************************************************

    /**
     * Constructs a FileNode for its associated FileInfo.
     */
    public FileNode(FileInfo fileInfo) {
        this.fileInfo = fileInfo;
    }


    // Accessors **************************************************************

    @Override
    public String getName() {
        return fileInfo.getName();
    }


    @Override
    public boolean isFileLeaf() {
        return true;
    }


    @Override
    public long getSize() {
        return fileInfo.getSize();
    }


    @Override
    public long getFileCount() {
        return 1;
    }


    public long getLastModified() {
        return fileInfo.getLastModified();
    }


    @Override
    public Icon getIcon(boolean selected) {
        return ExtFileSystemView.getInstance().getLeafIcon(getFile());
    }


    public String getSuffix() {
        String name = getName();
        int index = name.lastIndexOf('.');
        return index == -1 ? null : name.substring(index + 1).toLowerCase();
    }


}
