/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.node;

import com.jgoodies.chart.AbstractTreeChartModel;
import com.jgoodies.jdiskreport.model.settings.GUISettings.SizeMode;
import com.jgoodies.jdiskreport.model.settings.GUISettings.SortMode;


/**
 * A TreeChartModel build from nodes of a file tree.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.4 $
 */
public final class FileTreeChartModel extends AbstractTreeChartModel<AbstractNode>  {

    private final DirectoryNode root;
    private final SortMode sortMode;
    private final SizeMode sizeMode;
    private final boolean showFiles;


    // Instance Creation ******************************************************

    public FileTreeChartModel(
            DirectoryNode root,
            SortMode sortMode,
            SizeMode sizeMode,
            boolean showFiles) {
        this.root = root;
        this.sortMode = sortMode;
        this.sizeMode = sizeMode;
        this.showFiles = showFiles;
    }


    // TreeChartModel Implementation ******************************************

    public DirectoryNode getRoot() {
        return root;
    }


    /**
     * Returns the number of children of the given node.
     *
     * @return the number of chilren of the given node
     */
    public int getChildCount(AbstractNode node) {
        if (node instanceof DirectoryNode) {
            DirectoryNode directoryNode = (DirectoryNode) node;
            return directoryNode.getSortedChildren(sortMode, sizeMode, showFiles).size();
        }
        return 0;
    }


    public AbstractNode getChild(AbstractNode node, int index) {
        if (!(node instanceof DirectoryNode)) {
            throw new UnsupportedOperationException("In FileTreeChartModel only DirectoryNodes have children.");
        }
        DirectoryNode directoryNode = (DirectoryNode) node;
        return directoryNode.getSortedChildren(sortMode, sizeMode, showFiles).get(index);
    }


    /**
     * Returns the mandatory size of the given node.
     */
    public long getSize(AbstractNode node) {
        return node.getSize();
    }


    public boolean isLeaf(AbstractNode node) {
        return node.isFileLeaf();
    }

}
