/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.node;

import java.io.File;

import com.jgoodies.jdiskreport.domain.Root;
import com.jgoodies.jdiskreport.model.settings.GUISettings.SortMode;


/**
 * Describes directories.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.8 $
 */
public final class RootNode extends DirectoryNode {


    // Instance Creation ******************************************************

    /**
     * Constructs a directory node for the root of the scan.
     */
    private RootNode(
            Root root,
            long size,
            long directoryCount,
            long fileCount,
            DirectoryNode[] childDirectories,
            FileNode[] childFiles) {
        super(root, size, directoryCount, fileCount, childDirectories, childFiles);
    }


    public static RootNode createFrom(Root root) {
        DirectoryNode directoryNode = DirectoryNode.createFrom(root);
        return new RootNode(root,
                directoryNode.getSize(),
                directoryNode.getDirectoryCount(),
                directoryNode.getFileCount(),
                directoryNode.getChildDirectories(),
                directoryNode.getChildFiles());
    }

    // Accessors **************************************************************

    @Override
    public File getFile() {
        return ((Root) getDirectory()).getFile();
    }


    /**
     * Returns the name displayed by directory tree nodes.
     *
     * @return the file name for directories, the path for root nodes
     */
    @Override
    public String getNodeName() {
        return getPath();
    }


    @Override
    public float getAbsoluteSize() {
        return 1.0f;
    }


    @Override
    public float getRelativeSize() {
        return 1.0f;
    }


    @Override
    public RootNode getRoot() {
        return this;
    }


    // Operations *************************************************************

    public void computeAndSetStatistics() {
        computeAndSetStatistics(3);
        getStatistics().getTypeDistribution().replaceMapByArrays();
    }


    // TreeModel **************************************************************

    public FileTreeModel getTreeModel(SortMode sortMode) {
        return new FileTreeModel(this, sortMode);
    }


}
