/*
 * Copyright (c) 2006-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.scan;

import java.io.File;

import com.jgoodies.jdiskreport.domain.ScanConfiguration;
import com.jgoodies.jdiskreport.domain.ScanResult;
import com.jgoodies.jdiskreport.model.scan.Scanner.ScanLog;

public final class ConsoleScanLog implements ScanLog {

    private static final int LOG_INTERVAL_MILLIS = 1000;

    private long lastLogTime;


    // Instance Creation ******************************************************

    public ConsoleScanLog() {
        lastLogTime = System.currentTimeMillis();
    }


    // ScanLog Implementation *************************************************

    public void logConfiguration(ScanConfiguration configuration) {
        System.out.println();
        System.out.println(configuration);
    }


    public void logWarning(String message) {
        System.err.println(message);
    }


    public void logSummary(ScanResult result) {
        System.out.println();
        System.out.println(result);
    }


    public void logDirectory(File directory, int level) {
        if (level < 2) {
            System.out.println();
            System.out.print("Scanning " + directory.getPath());
        } else {
            logProgress();
        }
    }


    // Helper Code ************************************************************

    private void logProgress() {
        long now = System.currentTimeMillis();
        if (now - lastLogTime < LOG_INTERVAL_MILLIS) {
            return;
        }
        System.out.print('.');
        lastLogTime = now;
    }


}