/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.statistic;

import java.util.Comparator;
import java.util.TreeSet;

/**
 * Adds a size limit to its superclass TreeSet, and
 * an operation that indicates whether an item has been added or not.
 * The latter is useful to break loops where it is clear that
 * no further element will be added, because subsequent elements
 * are even smaller than the one that has been rejected before.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 */
final class LimitedTreeSet<T> extends TreeSet<T> {

    private final int sizeLimit;


    // Instance Creation ******************************************************

    LimitedTreeSet(int sizeLimit, Comparator<T> comparator) {
        super(comparator);
        this.sizeLimit = sizeLimit;
    }


    // Operations *************************************************************

    /**
     * Adds the given item to this limited sorted set.
     *
     * @return true if the item was added, false if not added
     */
    boolean addItem(T newItem) {
        if (size() < sizeLimit) {
            add(newItem);
            return true;
        }
        T lastItem = last();
        // Do nothing if the new item is equal or larger than the last one.
        if (comparator().compare(newItem, lastItem) != -1) {
            return false;
        }
        remove(lastItem);
        add(newItem);
        return true;
    }

}
