/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.model.statistic;

import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.FOUR_GB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.FOUR_KB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.FOUR_MB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.ONE_GB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.ONE_KB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.ONE_MB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.SIXTEEN_GB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.SIXTEEN_KB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.SIXTEEN_MB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.SIXTYFOUR_KB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.SIXTYFOUR_MB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.TWO56_KB;
import static com.jgoodies.jdiskreport.model.util.ByteSizeConstants.TWO56_MB;

import com.jgoodies.jdiskreport.model.node.FileNode;


/**
 * Implements the size distributions.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
final class SizeDistribution extends AbstractDistribution {


    // Constants **************************************************************

    private static final long[] ROW_BOUNDS = {
        Long.MAX_VALUE,
        SIXTEEN_GB,
        FOUR_GB,
        ONE_GB,

        TWO56_MB,
        SIXTYFOUR_MB,
        SIXTEEN_MB,
        FOUR_MB,
        ONE_MB,

        TWO56_KB,
        SIXTYFOUR_KB,
        SIXTEEN_KB,
        FOUR_KB,
        ONE_KB};


    // Instance Creation ******************************************************

    /**
     * Constructs an empty SizeDistribution with sizes and counts set to 0.
     */
    SizeDistribution() {
        // Just invoke the super constructor.
    }


    // Implementing Abstract Behavior *****************************************

    @Override
    protected int getRowCount() {
        return ROW_BOUNDS.length;
    }


    @Override
    protected void add(FileNode fileNode) {
        long size = fileNode.getSize();
        int rowCount = getRowCount();
        for (int i = rowCount - 1; i >= 0; i--) {
            if (size < ROW_BOUNDS[i]) {
                add(i, size, 1L);
                return;
            }
        }
    }


}
