/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import javax.swing.JFrame;

import com.jgoodies.jdiskreport.model.MainModel;
import com.jgoodies.jdiskreport.model.NavigationModel;
import com.jgoodies.jdiskreport.model.node.DirectoryNode;

/**
 *
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.4 $
 */
public final class MainFrame extends JFrame {


    private final MainModel mainModel;


    // Instance Creation ******************************************************

    public MainFrame(MainModel mainModel) {
        this.mainModel = mainModel;
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        add(new MainPageView(mainModel).getPanel());
        initEventHandling();
        setSize(800, 600);
        setLocationRelativeTo(null);
    }


    // Event Handling *********************************************************

    private void initEventHandling() {
        mainModel.navigationModel().addPropertyChangeListener(
                NavigationModel.PROPERTYNAME_SELECTION,
                new NavigationSelectionChangeHandler());
        update(mainModel.navigationModel().getSelection());
    }


    private void update(DirectoryNode selection) {
        String titlePrefix = selection.getPath();
        String titleSuffix = " - JDiskReport";
        setTitle(titlePrefix + titleSuffix);
    }


    private final class NavigationSelectionChangeHandler implements PropertyChangeListener {

        public void propertyChange(PropertyChangeEvent evt) {
            update((DirectoryNode) evt.getNewValue());
        }

    }


}
