/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.util.prefs.Preferences;

import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JSplitPane;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.jdiskreport.model.MainModel;
import com.jgoodies.jdiskreport.view.component.ScrollPaneBorder;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.component.GradientSeparator;
import com.jgoodies.uif.component.UIFSplitPane;
import com.jgoodies.uif.util.ScreenUtils;

/**
 * Builds the main page that consists of the toolbar, navigation,
 * presentation chooser, presentation, and details panel.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.10 $
 */
public final class MainPageView extends AbstractView {


    private static final Dimension NAVIGATION_MINIMUM_SIZE =
        new Dimension(150, 90);
    private static final Dimension PRESENTATION_MINIMUM_SIZE =
        new Dimension(190, 90);
    private static final String KEY_MAIN_DIVIDER_LOCATION =
        "main.divider_location";


    private final MainModel mainModel;

    private JSplitPane splitPane;


    // Instance Creation ******************************************************

    public MainPageView(MainModel mainModel) {
        this.mainModel = mainModel;
    }


    // Building ***************************************************************

    @Override
    protected JComponent buildPanel() {
        FormLayout layout = new FormLayout(
                "fill:default:grow",
                "fill:36px, fill:200px:grow, 1px, pref");
        PanelBuilder builder = new PanelBuilder(layout);
        CellConstraints cc = new CellConstraints();

        builder.add(buildHeader(),              cc.xy(1, 1));
        builder.add(buildSplitPane(),           cc.xy(1, 2));
        builder.add(buildHorizontalSeparator(), cc.xy(1, 3));
        builder.add(buildDetails(),             cc.xy(1, 4));
        return builder.getPanel();
    }


    private JComponent buildHeader() {
        return new ToolBarView(mainModel).getPanel();
    }


    private JComponent buildHorizontalSeparator() {
        return GradientSeparator.createHorizontalGradient(Color.DARK_GRAY, Color.LIGHT_GRAY, Color.GRAY);
    }


    private JComponent buildSplitPane() {
        JComponent leftPane  = buildNavigation();
        JComponent rightPane = buildPresentation();
        leftPane. setBorder(new ScrollPaneBorder(false, false, false, true));
        rightPane.setBorder(new ScrollPaneBorder(false, true, false, false));

        leftPane.setMinimumSize(NAVIGATION_MINIMUM_SIZE);
        rightPane.setMinimumSize(PRESENTATION_MINIMUM_SIZE);

        // Split the navigation in the left and presentation in the right.
        splitPane = UIFSplitPane.createStrippedSplitPane(
                JSplitPane.HORIZONTAL_SPLIT,
                leftPane, rightPane);
        return splitPane;
    }


    private JComponent buildNavigation() {
        return new NavigationView(mainModel.navigationModel()).getPanel();
    }


    private JComponent buildPresentation() {
        JPanel panel = new JPanel(new BorderLayout());
        panel.add(
                new PresentationChooserView(mainModel).getPanel(),
                BorderLayout.NORTH);
        panel.add(
                new PresentationView(mainModel).getPanel(),
                BorderLayout.CENTER);
        return panel;
    }


    private JComponent buildDetails() {
        return new DetailsView(mainModel).getPanel();
    }


    // Persisting Screen State ************************************************

//    /**
//     * Set the page's split pane divider location from the Preferences.
//     */
//    private void restoreState(Preferences prefs) {
//        Preferences screenConfigNode =
//            ScreenUtils.screenConfigurationNode(prefs, null);
//        int location = screenConfigNode.getInt(
//                KEY_MAIN_DIVIDER_LOCATION,
//                getDefaultDividerLocation());
//
//        Container parent = getPanel().getParent();
//        int parentWidth = parent == null ? Integer.MAX_VALUE : parent.getWidth();
//        int maxLocation = parentWidth
//                - splitPane.getDividerSize()
//                - PRESENTATION_MINIMUM_SIZE.width;
//
//        splitPane.setDividerLocation(Math.min(location, maxLocation));
//    }


    public void storeState(Preferences prefs) {
        Preferences screenConfigNode =
            ScreenUtils.screenConfigurationNode(prefs);
        screenConfigNode.putInt(
                KEY_MAIN_DIVIDER_LOCATION,
                splitPane.getDividerLocation());
    }


//    /**
//     * The default divider location is a third of the panel width,
//     * but cut at a maximum of 300 pixel.
//     * This default will be overriden by #restoreState.
//     */
//    private int getDefaultDividerLocation() {
//        Container parent = getPanel().getParent();
//        int parentWidth = parent == null ? Integer.MAX_VALUE : parent.getWidth();
//        return (int) Math.min(300, parentWidth * 0.3d);
//    }


}
