/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view;

import java.awt.Component;
import java.awt.Font;

import javax.swing.JComponent;
import javax.swing.JScrollPane;
import javax.swing.JTree;
import javax.swing.tree.DefaultTreeCellRenderer;

import com.jgoodies.forms.factories.Borders;
import com.jgoodies.jdiskreport.model.NavigationModel;
import com.jgoodies.jdiskreport.model.node.DirectoryNode;
import com.jgoodies.uif.AbstractView;



/**
 * Builds a navigation view for a NavigationModel.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.8 $
 */
public final class NavigationView extends AbstractView {

    private final NavigationModel navigationModel;

    private JTree       tree;
    private JScrollPane scrollPane;


    // Instance Creation ******************************************************

    NavigationView(NavigationModel navigationModel) {
        this.navigationModel = navigationModel;
    }


    // GUI ********************************************************************

    private void initComponents() {
        tree = new JTree(navigationModel.getNavigationTreeModel());
        tree.setSelectionModel(navigationModel.getNavigationTreeSelectionModel());
        tree.setBorder(Borders.createEmptyBorder("2dlu, 2dlu, 0, 0"));
        tree.putClientProperty("JTree.lineStyle", "None");
        tree.setCellRenderer(new FileTreeRenderer());

        scrollPane = new JScrollPane(tree);
        scrollPane.getVerticalScrollBar().  putClientProperty("JScrollBar.isFreeStanding", Boolean.FALSE);
        scrollPane.getHorizontalScrollBar().putClientProperty("JScrollBar.isFreeStanding", Boolean.FALSE);
    }

    @Override
    protected JComponent buildPanel() {
        initComponents();
        return scrollPane;
    }


    private static final class FileTreeRenderer extends DefaultTreeCellRenderer {

        private Font cachedOriginalFont;
        private Font boldFont;

        @Override
        public Component getTreeCellRendererComponent(JTree tree, Object value,
                boolean sel, boolean expanded, boolean leaf, int row,
                boolean focus) {
            super.getTreeCellRendererComponent(tree, value, selected, expanded,
                    false, row, focus);
            DirectoryNode node = (DirectoryNode) value;
            this.setForeground(sel
                    ? getTextSelectionColor()
                    : getTextNonSelectionColor());
            selected = sel;
            this.setIcon(node.getIcon(selected));
            this.setText(node.getNodeName());
            // TODO: Get the boldness threshold from the UISettings
            this.setFont(node.getAbsoluteSize() > 0.15f
                    ? getBoldFont(tree.getFont())
                    : tree.getFont());
            return this;
        }

        private Font getBoldFont(Font originalFont) {
            if (originalFont != cachedOriginalFont) {
                boldFont = originalFont.deriveFont(Font.BOLD);
                cachedOriginalFont = originalFont;
            }
            return boldFont;
        }

    }


}
