/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view;

import java.awt.Dimension;

import javax.swing.*;

import com.jgoodies.binding.adapter.RadioButtonAdapter;
import com.jgoodies.binding.beans.PropertyAdapter;
import com.jgoodies.binding.value.ValueModel;
import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.jdiskreport.model.MainModel;
import com.jgoodies.jdiskreport.model.settings.GUISettings;
import com.jgoodies.jdiskreport.model.settings.GUISettings.ViewMode;
import com.jgoodies.jdiskreport.view.component.NavigationButton;
import com.jgoodies.jdiskreport.view.component.ScrollPaneBorder;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;

/**
 * Builds the panel that contains the toggle buttons that are
 * used to choose a presentation.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.11 $
 */
public final class PresentationChooserView extends AbstractView {


    private final static ResourceMap RESOURCES =
        Application.getResourceMap(PresentationChooserView.class);


    private final MainModel mainModel;


    // Instance Creation ******************************************************

    public PresentationChooserView(MainModel mainModel) {
        this.mainModel = mainModel;
    }


    // Building ***************************************************************

    @Override
    protected JComponent buildPanel() {
        ValueModel model = new PropertyAdapter<GUISettings>(
                mainModel.guiSettings(),
                GUISettings.PROPERTYNAME_VIEW_MODE,
                true);

        FormLayout layout = new FormLayout(
                "0:grow, pref, d, pref, d, pref, d, pref, d, pref, d, pref, 0:grow",
                "p, p, p");
        //layout.setColumnGroups(new int[][]{{2, 4, 6, 8, 10, 12}});
        PanelBuilder builder = new PanelBuilder(layout);
        builder.setBackground(
                RESOURCES.getColor("PresentationChooserView.background"));
        builder.setBorder(BorderFactory.createCompoundBorder(
                new ScrollPaneBorder(false, false, true, false),
                Borders.createEmptyBorder("1dlu, 3dlu, 1dlu, 3dlu")));

        CellConstraints cc = new CellConstraints();
        builder.add(button(model, ViewMode.OVERVIEW),                cc.xy( 2, 1));
        builder.add(button(model, ViewMode.SIZE_TREE_PIE),           cc.xy( 2, 2));
        builder.add(button(model, ViewMode.SIZE_TREE_MAP),           cc.xy( 2, 3));
        builder.add(spacer(), cc.xy( 3, 1));

        builder.add(button(model, ViewMode.SIZE_PIE),                cc.xy( 4, 1));
        builder.add(button(model, ViewMode.SIZE_BAR),                cc.xy( 4, 2));
        builder.add(button(model, ViewMode.SIZE_TABLE),              cc.xy( 4, 3));
        builder.add(spacer(), cc.xy( 5, 1));

        builder.add(button(model, ViewMode.TOP50_LARGEST),           cc.xy( 6, 1));
        builder.add(button(model, ViewMode.TOP50_OLDEST),            cc.xy( 6, 2));
        builder.add(button(model, ViewMode.TOP50_NEWEST),            cc.xy( 6, 3));
        builder.add(spacer(), cc.xy( 7, 1));

        builder.add(button(model, ViewMode.SIZE_DISTRIBUTION_PIE),   cc.xy( 8, 1));
        builder.add(button(model, ViewMode.SIZE_DISTRIBUTION_BAR),   cc.xy( 8, 2));
        builder.add(button(model, ViewMode.SIZE_DISTRIBUTION_TABLE), cc.xy( 8, 3));
        builder.add(spacer(), cc.xy( 9, 1));

        builder.add(button(model, ViewMode.TIME_DISTRIBUTION_PIE),   cc.xy(10, 1));
        builder.add(button(model, ViewMode.TIME_DISTRIBUTION_BAR),   cc.xy(10, 2));
        builder.add(button(model, ViewMode.TIME_DISTRIBUTION_TABLE), cc.xy(10, 3));
        builder.add(spacer(), cc.xy(11, 1));

        builder.add(button(model, ViewMode.TYPE_DISTRIBUTION_PIE),   cc.xy(12, 1));
        builder.add(button(model, ViewMode.TYPE_DISTRIBUTION_BAR),   cc.xy(12, 2));
        builder.add(button(model, ViewMode.TYPE_DISTRIBUTION_TABLE), cc.xy(12, 3));

        return builder.getPanel();
    }


    // Helper Code ************************************************************

    private AbstractButton button(ValueModel valueModel, ViewMode viewMode) {
        String keyPrefix = "ViewMode." + viewMode.name();
        String iconKey = keyPrefix + ".icon";
        String textKey = keyPrefix + ".text";
        String iconPath = RESOURCES.getString(iconKey);
        Icon icon = iconPath == null ? null : RESOURCES.getIcon(iconKey);
        String text = RESOURCES.getString(textKey);
        AbstractButton button = new NavigationButton(icon, text);
        button.setModel(new RadioButtonAdapter(valueModel, viewMode));
        return button;
    }


    private JComponent spacer() {
        JPanel panel = new JPanel(null);
        panel.setOpaque(false);
        panel.setMinimumSize(new Dimension(0, 1));
        panel.setPreferredSize(new Dimension(35, 1));
        return panel;
    }


}
