/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view;

import static com.jgoodies.jdiskreport.view.TableCellRenderers.COUNT_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.DATE_TIME_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.DEFAULT_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.DIRECTOY_PATH_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.NODE_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.NUMBER_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.PERCENT_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.RIGHT_ALIGNED_DEFAULT_RENDERER;
import static com.jgoodies.jdiskreport.view.TableCellRenderers.SIZE_RENDERER;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.text.Format;

import javax.swing.*;
import javax.swing.border.Border;
import javax.swing.border.EmptyBorder;
import javax.swing.plaf.UIResource;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableModel;

import com.jgoodies.chart.*;
import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.forms.layout.Sizes;
import com.jgoodies.jdiskreport.model.MainModel;
import com.jgoodies.jdiskreport.model.PresentationModel;
import com.jgoodies.jdiskreport.model.node.AbstractNode;
import com.jgoodies.jdiskreport.model.settings.GUISettings;
import com.jgoodies.jdiskreport.model.settings.GUISettings.SizeMode;
import com.jgoodies.jdiskreport.model.settings.GUISettings.ViewMode;
import com.jgoodies.jdiskreport.model.util.Formats;
import com.jgoodies.looks.LookUtils;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.uif.panel.CardPanel;

/**
 *
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.21 $
 */
public final class PresentationView extends AbstractView {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(PresentationView.class);

    private final MainModel mainModel;
    private final PresentationModel presentationModel;

    private CardPanel cardPanel;

    private PieChart<AbstractNode>  overviewSizePieChart;
    private BarChart<Object>  overviewSizeDistributionBarChart;
    private BarChart<Object>  overviewTimeDistributionBarChart;

    private PieChart<AbstractNode>  sizePieChart;
    private ChartView<AbstractNode> sizePieView;
    private BarChart<AbstractNode>  sizeBarChart;
    private ChartView<AbstractNode> sizeBarView;

    private PieChart<Object>  sizeDistributionPieChart;
    private ChartView<Object> sizeDistributionPieView;
    private BarChart<Object>  sizeDistributionBarChart;
    private ChartView<Object> sizeDistributionBarView;

    private PieChart<Object>  timeDistributionPieChart;
    private ChartView<Object> timeDistributionPieView;
    private BarChart<Object>  timeDistributionBarChart;
    private ChartView<Object> timeDistributionBarView;

    private PieChart<Object>  typeDistributionPieChart;
    private ChartView<Object> typeDistributionPieView;
    private BarChart<Object>  typeDistributionBarChart;
    private ChartView<Object> typeDistributionBarView;


    // Instance Creation ******************************************************

    public PresentationView(MainModel mainModel) {
        this.mainModel = mainModel;
        this.presentationModel = mainModel.presentationModel();
    }


    // Building ***************************************************************

    private void initComponents() {
        cardPanel = new CardPanel();
        cardPanel.setBackground(Color.WHITE);
        //cardPanel.setBackground(Color.decode("0xEEF3FA"));

        Format kbFormat = Formats.KILOBYTE_FORMAT;
        String totalSizeText = RESOURCES.getString("PresentationView.pieChart.total.size");
        Font tableFont = UIManager.getFont("Table.font");
        Font smallFont = tableFont.deriveFont(tableFont.getSize2D() - 4f);

        overviewSizePieChart = new PieChart<AbstractNode>(kbFormat, totalSizeText);
        overviewSizePieChart.setShowSize(false);
        overviewSizePieChart.setShowTotal(false);
        overviewSizePieChart.setFont(smallFont);
        overviewSizePieChart.setModel(mainModel.presentationModel().getSizeChartModel());
        overviewSizeDistributionBarChart = new BarChart<Object>(kbFormat, false);
        overviewSizeDistributionBarChart.setShowSize(false);
        overviewSizeDistributionBarChart.setFont(smallFont);
        overviewSizeDistributionBarChart.setModel(mainModel.presentationModel().getSizeDistributionChartModel());
        overviewTimeDistributionBarChart = new BarChart<Object>(kbFormat, false);
        overviewTimeDistributionBarChart.setShowSize(false);
        overviewTimeDistributionBarChart.setFont(smallFont);
        overviewTimeDistributionBarChart.setModel(mainModel.presentationModel().getTimeDistributionChartModel());

        sizePieChart = new PieChart<AbstractNode>(kbFormat, totalSizeText);
        sizePieChart.setModel(mainModel.presentationModel().getSizeChartModel());
        sizePieView = new ChartView<AbstractNode>(sizePieChart);

        sizeBarChart = new BarChart<AbstractNode>(kbFormat);
        sizeBarChart.setModel(mainModel.presentationModel().getSizeChartModel());
        sizeBarView = new ChartView<AbstractNode>(sizeBarChart);
        sizeBarView.setBorder(Borders.DLU14_BORDER);

        sizeDistributionPieChart = new PieChart<Object>(kbFormat, totalSizeText);
        sizeDistributionPieChart.setShowSize(false);
        sizeDistributionPieChart.setModel(mainModel.presentationModel().getSizeDistributionChartModel());
        sizeDistributionPieView = new ChartView<Object>(sizeDistributionPieChart);

        sizeDistributionBarChart = new BarChart<Object>(kbFormat, false);
        sizeDistributionBarChart.setModel(mainModel.presentationModel().getSizeDistributionChartModel());
        sizeDistributionBarView = new ChartView<Object>(sizeDistributionBarChart);
        sizeDistributionBarView.setBorder(Borders.DLU14_BORDER);

        timeDistributionPieChart = new PieChart<Object>(kbFormat, totalSizeText);
        timeDistributionPieChart.setModel(mainModel.presentationModel().getTimeDistributionChartModel());
        timeDistributionPieView = new ChartView<Object>(timeDistributionPieChart);

        timeDistributionBarChart = new BarChart<Object>(kbFormat, false);
        timeDistributionBarChart.setModel(mainModel.presentationModel().getTimeDistributionChartModel());
        timeDistributionBarView = new ChartView<Object>(timeDistributionBarChart);
        timeDistributionBarView.setBorder(Borders.DLU14_BORDER);

        typeDistributionPieChart = new PieChart<Object>(kbFormat, totalSizeText);
        typeDistributionPieChart.setModel(mainModel.presentationModel().getTypeDistributionChartModel());
        typeDistributionPieView = new ChartView<Object>(typeDistributionPieChart);

        typeDistributionBarChart = new BarChart<Object>(kbFormat, false);
        typeDistributionBarChart.setModel(mainModel.presentationModel().getTypeDistributionChartModel());
        typeDistributionBarView = new ChartView<Object>(typeDistributionBarChart);
        typeDistributionBarView.setBorder(Borders.DLU14_BORDER);
    }

    @Override
    protected JComponent buildPanel() {
        initComponents();

        cardPanel.add(buildOverview(),              ViewMode.OVERVIEW.name());
        cardPanel.add(buildTreePieChart(),          ViewMode.SIZE_TREE_PIE.name());
        cardPanel.add(buildTreeMapChart(),          ViewMode.SIZE_TREE_MAP.name());

        cardPanel.add(sizePieView,                  ViewMode.SIZE_PIE.name());
        cardPanel.add(sizeBarView,                  ViewMode.SIZE_BAR.name());
        cardPanel.add(buildSizeTable(),             ViewMode.SIZE_TABLE.name());

        cardPanel.add(buildTop50LargestTable(),     ViewMode.TOP50_LARGEST.name());
        cardPanel.add(buildTop50OldestTable(),      ViewMode.TOP50_OLDEST.name());
        cardPanel.add(buildTop50NewestTable(),      ViewMode.TOP50_NEWEST.name());

        cardPanel.add(sizeDistributionPieView,      ViewMode.SIZE_DISTRIBUTION_PIE.name());
        cardPanel.add(sizeDistributionBarView,      ViewMode.SIZE_DISTRIBUTION_BAR.name());
        cardPanel.add(buildSizeDistributionTable(), ViewMode.SIZE_DISTRIBUTION_TABLE.name());

        cardPanel.add(timeDistributionPieView,      ViewMode.TIME_DISTRIBUTION_PIE.name());
        cardPanel.add(timeDistributionBarView,      ViewMode.TIME_DISTRIBUTION_BAR.name());
        cardPanel.add(buildTimeDistributionTable(), ViewMode.TIME_DISTRIBUTION_TABLE.name());

        cardPanel.add(typeDistributionPieView,      ViewMode.TYPE_DISTRIBUTION_PIE.name());
        cardPanel.add(typeDistributionBarView,      ViewMode.TYPE_DISTRIBUTION_BAR.name());
        cardPanel.add(buildTypeDistributionTable(), ViewMode.TYPE_DISTRIBUTION_TABLE.name());

        initEventHandling();
        return cardPanel;
    }


//    private JComponent buildNotAvailable() {
//        JPanel panel = new JPanel(new BorderLayout());
//        panel.add(new JLabel("Not available"));
//        return panel;
//    }


    private JComponent buildOverview() {
        FormLayout layout = new FormLayout(
                "pref:grow, 9dlu, pref:grow, 9dlu, pref:grow",
                "fill:130dlu");
        PanelBuilder builder = new PanelBuilder(layout);
        builder.setBorder(Borders.createEmptyBorder("4dlu, 0, 4dlu, 0"));
        builder.setBackground(Color.WHITE);
        CellConstraints cc = new CellConstraints();
        builder.add(overviewSizePieChart,             cc.xy(1, 1));
        builder.add(overviewSizeDistributionBarChart, cc.xy(3, 1));
        builder.add(overviewTimeDistributionBarChart, cc.xy(5, 1));
        return builder.getPanel();
    }


    private JComponent buildTreePieChart() {
        return new TreePieChart<AbstractNode>(presentationModel.getTreeChartModel());
    }


    private JComponent buildTreeMapChart() {
        return new TreeMapChart<AbstractNode>(presentationModel.getTreeChartModel());
    }


    private JComponent buildSizeTable() {
        JTable table = buildTable(presentationModel.getSizeTableModel());
        configureSizeTable(table);
        return scrolllable(table);
    }



    private JComponent buildTop50LargestTable() {
        JTable table = buildTable(presentationModel.getLargestFilesTableModel());
        configureTop50Table(table);
        return scrolllable(table);
    }


    private JComponent buildTop50OldestTable() {
        JTable table = buildTable(presentationModel.getOldestFilesTableModel());
        configureTop50Table(table);
        return scrolllable(table);
    }


    private JComponent buildTop50NewestTable() {
        JTable table = buildTable(presentationModel.getNewestFilesTableModel());
        configureTop50Table(table);
        return scrolllable(table);
    }


    private JComponent buildSizeDistributionTable() {
        JTable table = buildTable(presentationModel.getSizeDistributionTableModel());
        configureDistributionTable(table);
        return scrolllable(table);
    }


    private JComponent buildTimeDistributionTable() {
        JTable table = buildTable(presentationModel.getTimeDistributionTableModel());
        configureDistributionTable(table);
        return scrolllable(table);
    }


    private JComponent buildTypeDistributionTable() {
        JTable table = buildTable(presentationModel.getTypeDistributionTableModel());
        configureDistributionTable(table);
        return scrolllable(table);
    }


    private JTable buildTable(TableModel tableModel) {
        JTable table = new JTable(tableModel);
        table.setShowGrid(false);
        table.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        table.getTableHeader().setReorderingAllowed(false);
        table.setDefaultRenderer(Object.class, DEFAULT_RENDERER);
        table.setDefaultRenderer(Number.class, NUMBER_RENDERER);
        //table.setFillsViewportHeight(true);
        table.setRowHeight(18); // TODO: Consider looking up the height from the tree
        if (LookUtils.IS_OS_WINDOWS_VISTA && LookUtils.IS_LAF_WINDOWS_XP_ENABLED) {
            table.getTableHeader().setDefaultRenderer(
                    new CustomTableCellRenderer(table.getTableHeader().getDefaultRenderer()));
        }
        return table;
    }


    private void configureSizeTable(JTable table) {
        table.getColumnModel().getColumn(0).setCellRenderer(NODE_RENDERER);
        table.getColumnModel().getColumn(1).setCellRenderer(SIZE_RENDERER);
        table.getColumnModel().getColumn(2).setCellRenderer(COUNT_RENDERER);
        table.getColumnModel().getColumn(3).setCellRenderer(PERCENT_RENDERER);
        table.getColumnModel().getColumn(4).setCellRenderer(PERCENT_RENDERER);
        configurePreferredColumnWidths(table, new int[]{110, 70, 70, 60, 60});
    }


    private void configureTop50Table(JTable table) {
        table.getColumnModel().getColumn(0).setCellRenderer(NODE_RENDERER);
        table.getColumnModel().getColumn(1).setCellRenderer(SIZE_RENDERER);
        table.getColumnModel().getColumn(2).setCellRenderer(DATE_TIME_RENDERER);
        table.getColumnModel().getColumn(3).setCellRenderer(DIRECTOY_PATH_RENDERER);
        configurePreferredColumnWidths(table, new int[]{110, 70, 70, 500});
    }


    private void configureDistributionTable(JTable table) {
        table.setRowSelectionAllowed(false);
        table.getColumnModel().getColumn(0).setCellRenderer(RIGHT_ALIGNED_DEFAULT_RENDERER);
        table.getColumnModel().getColumn(1).setCellRenderer(SIZE_RENDERER);
        table.getColumnModel().getColumn(2).setCellRenderer(PERCENT_RENDERER);
        table.getColumnModel().getColumn(3).setCellRenderer(COUNT_RENDERER);
        table.getColumnModel().getColumn(4).setCellRenderer(PERCENT_RENDERER);
        configurePreferredColumnWidths(table, new int[]{110, 70, 60, 70, 60});
    }


    private void configurePreferredColumnWidths(JTable table, int[] preferredWidthsDLU) {
        for (int i = 0; i < preferredWidthsDLU.length; i++) {
            int dlu = preferredWidthsDLU[i];
            if (dlu > 0) {
                int preferredWidth = Sizes.dialogUnitXAsPixel(dlu, table);
                table.getColumnModel().getColumn(i).setPreferredWidth(preferredWidth);
            }
        }
    }


    private JComponent scrolllable(JTable table) {
        JScrollPane scrollPane = new JScrollPane(table);
        scrollPane.setBorder(new EmptyBorder(0, 0, 0, 0));
        scrollPane.getViewport().setBackground(Color.WHITE);
        return scrollPane;
    }


    // Event Handling *********************************************************

    private void initEventHandling() {
        mainModel.guiSettings().addPropertyChangeListener(
                new GUISettingsChangeHandler());
        updatePresentation(mainModel.guiSettings().getViewMode());
    }


    private void updatePresentation(ViewMode viewMode) {
        cardPanel.showCard(viewMode.name());
    }


    private void updateChartSettings() {
        SizeMode sizeMode = mainModel.guiSettings().getSizeMode();
        Format pieFormat = sizeMode == SizeMode.SIZE
            ? Formats.KILOBYTE_FORMAT
            : Formats.COUNT_FORMAT_LONG;
        Format barFormat = sizeMode == SizeMode.SIZE
            ? Formats.KILOBYTE_FORMAT
            : Formats.FILE_COUNT_FORMAT;
        String totalTextKeySuffix = sizeMode == SizeMode.SIZE
            ? "size"
            : "count";
        String totalText = RESOURCES.getString(
                "PresentationView.pieChart.total." + totalTextKeySuffix);

        overviewSizeDistributionBarChart.setFormat(barFormat);
        overviewTimeDistributionBarChart.setFormat(barFormat);
        sizePieChart.setFormat(pieFormat);
        sizePieChart.setTotalText(totalText);
        sizeBarChart.setFormat(barFormat);

        sizeDistributionPieChart.setFormat(pieFormat);
        sizeDistributionPieChart.setTotalText(totalText);
        sizeDistributionBarChart.setFormat(barFormat);

        timeDistributionPieChart.setFormat(pieFormat);
        timeDistributionPieChart.setTotalText(totalText);
        timeDistributionBarChart.setFormat(barFormat);
    }


    private final class GUISettingsChangeHandler implements PropertyChangeListener {

        public void propertyChange(PropertyChangeEvent evt) {
            String propertyName = evt.getPropertyName();
            if (GUISettings.PROPERTYNAME_VIEW_MODE.equals(propertyName)) {
                updatePresentation((ViewMode) evt.getNewValue());
            } else if (GUISettings.PROPERTYNAME_SIZE_MODE.equals(propertyName)) {
                updateChartSettings();
            }
        }

    }


    static class CustomTableCellRenderer implements TableCellRenderer, UIResource {
        private static final Border EMPTY_BORDER =
            BorderFactory.createEmptyBorder(4, 4, 5, 4);

        private final TableCellRenderer delegate;

        CustomTableCellRenderer(TableCellRenderer orig) {
            this.delegate = orig;
        }

        public Component getTableCellRendererComponent(JTable table, Object value,
                boolean isSelected, boolean hasFocus, int row, int column) {
            JComponent component = (JComponent) delegate
                    .getTableCellRendererComponent(table, value, isSelected,
                            hasFocus, row, column);
            component.setBorder(EMPTY_BORDER);
            return component;
        }
    }


}
