/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view;

import java.awt.*;

import javax.swing.*;
import javax.swing.border.AbstractBorder;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.jdiskreport.model.MainModel;
import com.jgoodies.jdiskreport.model.node.DirectoryNode;
import com.jgoodies.jdiskreport.model.settings.GUISettings;
import com.jgoodies.jdiskreport.view.component.ImageBackgroundPanel;
import com.jgoodies.jdiskreport.view.component.ToolBarButton;
import com.jgoodies.jdiskreport.view.component.ToolBarToggleButton;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.action.ToggleAction;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.uifextras.history.History;

/**
 *
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.13 $
 */
public final class ToolBarView extends AbstractView {


    private final static ResourceMap RESOURCES =
        Application.getResourceMap(ToolBarView.class);


    private final MainModel mainModel;

    private JButton backButton;
    private JButton nextButton;
    private JComponent updateButton;

    private JComponent scanButton;
    private JComponent exportButton;
    private JComponent printButton;

    private JComponent sizeSortButton;
    private JComponent alphabSortButton;

    private JComponent sizeModeButton;
    private JComponent countModeButton;

    private JCheckBox showFilesBox;

    private JComponent helpButton;


    // Instance Creation ******************************************************

    public ToolBarView(MainModel mainModel) {
        this.mainModel = mainModel;
    }


    // Building ***************************************************************

    private void initComponents() {
        History<DirectoryNode> history = mainModel.history();
        backButton = new ToolBarButton(history.getGoBackAction());
        backButton.setPreferredSize(new Dimension(28, 29));
        backButton.setContentAreaFilled(false);
        backButton.setBorder(null);
        backButton.setEnabled(true);
        backButton.setDisabledIcon(RESOURCES.getIcon("history.goBack.icon.disabled"));
        backButton.setRolloverIcon(RESOURCES.getIcon("history.goBack.icon.rollover"));
        nextButton = new ToolBarButton(history.getGoNextAction());
        nextButton.setContentAreaFilled(false);
        nextButton.setPreferredSize(new Dimension(27, 29));
        nextButton.setBorder(null);
        nextButton.setEnabled(false);
        nextButton.setDisabledIcon(RESOURCES.getIcon("history.goNext.icon.disabled"));
        nextButton.setRolloverIcon(RESOURCES.getIcon("history.goNext.icon.rollover"));

        ActionMap mainMap = Application.getActionMap(mainModel);

        updateButton = new ToolBarButton(mainMap.get(MainModel.ACTION_UPDATE));
        scanButton   = new ToolBarButton(mainMap.get(MainModel.ACTION_SCAN));
        exportButton = new ToolBarButton(mainMap.get(MainModel.ACTION_EXPORT));
        printButton  = new ToolBarButton(mainMap.get(MainModel.ACTION_PRINT));
        helpButton   = new ToolBarButton(mainMap.get(MainModel.ACTION_HELP));

        GUISettings settings = mainModel.guiSettings();
        sizeSortButton   = createToggleButton(settings.getSortModeSizeAction());
        alphabSortButton = createToggleButton(settings.getSortModeNameAction());
        sizeModeButton   = createToggleButton(settings.getSizeModeSizeAction());
        countModeButton  = createToggleButton(settings.getSizeModeCountAction());

        showFilesBox = new JCheckBox(settings.getShowFilesAction());
        showFilesBox.setForeground(Color.WHITE);
        showFilesBox.setContentAreaFilled(false);
        showFilesBox.setFocusPainted(false);
    }


    @Override
    protected JComponent buildPanel() {
        initComponents();

        FormLayout layout = new FormLayout(
                "fill:0:grow",
                "fill:0:grow");
        PanelBuilder builder = new PanelBuilder(layout, createToolBarPanel());
        CellConstraints cc = new CellConstraints();
        builder.add(buildToolBarContent(), cc.xy(1, 1));
        return builder.getPanel();
    }


    private JComponent buildToolBarContent() {
        FormLayout layout = new FormLayout(
                "p, 0, p, 9dlu, p, 21dlu:grow, " +
                "p, 1dlu, p, 1dlu, p, 21dlu, " +
                "p, 0, p, 21dlu, p, 0, p, 0, p, " +
                "21dlu:grow, p",
                "fill:pref:grow");
        PanelBuilder builder = new PanelBuilder(layout);
        builder.setBorder(Borders.createEmptyBorder("1px, 4dlu, 2px, 3px"));
        builder.setOpaque(false);
        CellConstraints cc = new CellConstraints();
        builder.add(backButton,          cc.xy( 1, 1));
        builder.add(nextButton,          cc.xy( 3, 1));
        builder.add(updateButton,        cc.xy( 5, 1));

        builder.add(scanButton,          cc.xy( 7, 1));
        builder.add(exportButton,        cc.xy( 9, 1));
        builder.add(printButton,         cc.xy(11, 1));

        builder.add(sizeSortButton,      cc.xy(13, 1));
        builder.add(alphabSortButton,    cc.xy(15, 1));

        builder.add(sizeModeButton,      cc.xy(17, 1));
        builder.add(countModeButton,     cc.xy(19, 1));

        // TODO: Consider adding the show files feature
        //builder.add(showFilesBox,        cc.xy(21, 1));

        builder.add(helpButton,          cc.xy(23, 1));
        return builder.getPanel();
    }


    private JPanel createToolBarPanel() {
        JPanel panel = ImageBackgroundPanel.createFrom(
                RESOURCES.getImage("header.background"));
        panel.setBorder(new HeaderBorder());
        return panel;
    }


    // Helper Code ************************************************************

    private JComponent createToggleButton(ToggleAction action) {
        return new ToolBarToggleButton(action);
    }


    // Painting Helper Code ***************************************************

    static final class HeaderBorder extends AbstractBorder  {

        static final Insets INSETS = new Insets(1, 1, 2, 1);

        private final Color outerS;
        private final Color innerWuNuE;
        private final Color innerS;
        private final Color innerNWuNE;
        private final Color innerSWuSE;

        public HeaderBorder() {
            outerS     = RESOURCES.getColor("header.border.outerS");
            innerWuNuE = RESOURCES.getColor("header.border.innerWuNuE");
            innerS     = RESOURCES.getColor("header.border.innerS");
            innerNWuNE = RESOURCES.getColor("header.border.innerNWuNE");
            innerSWuSE = RESOURCES.getColor("header.border.innerSWuSE");
        }

        @Override
        public void paintBorder(Component c, Graphics g, int x, int y, int w, int h) {
            g.translate(x, y);

            g.setColor(outerS);
            g.fillRect(1,   h-1, w-2, 1);

            g.setColor(innerWuNuE);
            g.fillRect(1,   0,   w-2, 1);
            g.fillRect(0,   1,   1,   h-2);
            g.fillRect(w-1, 1,   1,   h-2);

            g.setColor(innerS);
            g.fillRect(1,   h-2, w-2, 1);

            // Inner Corners
            g.setColor(innerNWuNE);
            g.fillRect(0, 0, 1, 1);
            g.fillRect(w-1, 0, 1, 1);

            g.setColor(innerSWuSE);
            g.fillRect(0,   h-1, 1, 1);
            g.fillRect(w-1, h-1, 1, 1);

            g.translate(-x, -y);
        }

        @Override
        public Insets getBorderInsets(Component c) { return INSETS; }

        @Override
        public Insets getBorderInsets(Component c, Insets newInsets) {
            newInsets.top    = INSETS.top;
            newInsets.left   = INSETS.left;
            newInsets.bottom = INSETS.bottom;
            newInsets.right  = INSETS.right;
            return newInsets;
        }
    }


}
