/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view.component;

import java.awt.Color;
import java.awt.Graphics;
import java.awt.Image;

import javax.swing.ButtonModel;
import javax.swing.JButton;
import javax.swing.border.Border;
import javax.swing.border.CompoundBorder;
import javax.swing.border.EmptyBorder;
import javax.swing.event.ChangeEvent;
import javax.swing.event.ChangeListener;

import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;

/**
 * The abstract superclass for toolbar buttons with a pseudo light effect.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.5 $
 */
abstract class AbstractToolBarButton extends JButton {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(AbstractToolBarButton.class);


    // Instance Fields ********************************************************

    private final Image rolloverBackground;
    private final Image pressedBackground;


    // Instance Creation ******************************************************

    AbstractToolBarButton() {
        setFocusPainted(false);
        setContentAreaFilled(false);
        rolloverBackground = RESOURCES.getImage("ToolBarButton.rollover");
        pressedBackground  = RESOURCES.getImage("ToolBarButton.pressed");
        setBorder(new CompoundBorder(
                new ToolBarButtonBorder(
                        rolloverBackground,
                        pressedBackground),
                getInsetsBorder()));
        setForeground(getCurrentColor());
        getModel().addChangeListener(new ChangeListener() {
            public void stateChanged(ChangeEvent e) {
                setForeground(getCurrentColor());
            }
        });
    }


    // Misc *******************************************************************

    protected Border getInsetsBorder() {
        return new EmptyBorder(2, 4, 2, 4);
    }


    @Override
    protected void paintComponent(Graphics g) {
        if (model.isArmed() && model.isPressed()) {
            paintPressed(g);
        } else if (model.isSelected()) {
            paintSelected(g);
        } else if (model.isRollover()) {
            paintRollover(g);
        }
        super.paintComponent(g);
    }


    protected void paintPressed(Graphics g) {
        int width = getWidth();
        int height = getHeight();
        g.drawImage(pressedBackground, 4, 4, width-4, height-4, 4, 4, 22, 26, null);
    }


    protected void paintSelected(Graphics g) {
        paintPressed(g);
    }


    protected void paintRollover(Graphics g) {
        int width = getWidth();
        int height = getHeight();
        g.drawImage(rolloverBackground, 4, 4, width-4, height-4, 4, 4, 32, 26, null);
    }


    private Color getCurrentColor() {
        ButtonModel m = getModel();
        String foregroundKey = m.isEnabled()
            ? "ToolBarButton.foreground"
            : "ToolBarButton.disabledForeground";
        return RESOURCES.getColor(foregroundKey);
    }


}
