/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.view.component;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Insets;

import javax.swing.UIManager;
import javax.swing.border.AbstractBorder;

/**
 * A border that uses the standard shadow color and can paint
 * on the top, left, bottom, and right.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.3 $
 */
public final class ScrollPaneBorder extends AbstractBorder {

    private final boolean top;
    private final boolean left;
    private final boolean bottom;
    private final boolean right;
    private final Insets insets;

    public ScrollPaneBorder(boolean top, boolean left, boolean bottom, boolean right) {
        this.top = top;
        this.left = left;
        this.bottom = bottom;
        this.right = right;
        this.insets = new Insets(
                top ? 1 : 0,
                left ? 1 : 0,
                bottom ? 1 : 0,
                right ? 1 : 0);
    }


    @Override
    public Insets getBorderInsets(Component c) { return insets; }

    private Color getShadowColor() {
        Color unifiedShadow = UIManager.getColor("unifiedControlShadow");
        return unifiedShadow != null ? unifiedShadow : UIManager.getColor("controlShadow");
    }


    @Override
    public void paintBorder(Component c, Graphics g, int x, int y, int width, int height) {
        int w = width;
        int h = height;

        Color shadow = getShadowColor();
        g.translate(x, y);
        g.setColor(shadow);
        if (top) {
            g.drawLine(0, 0, w-1, 0);
        }
        if (left) {
            g.drawLine(0, 0, 0, h-1);
        }
        if (right) {
            g.drawLine(w-1, 0, w-1, h-1);
        }
        if (bottom) {
            g.drawLine(0, h-1, w-1, h-1);
        }
        g.translate(-x, -y);
    }
}