/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.sandbox.domain;

import java.io.File;
import java.util.List;


/**
 * Describes a file system directory or shell folder.
 *
 * @author Karsten Lentzsch
 */
public final class Directory extends File {

    // private static final short CLUSTER_SIZE = 4096;

    /**
     * Refers to this file's parent directory.
     */
    private final Directory parent;

    private long size;
    private long wastedSize;
    private long sizeSum;
    private long wastedSizeSum;
    private long countSum;
    private Directory[] directories;
    //public FastFile[]  files;


    // Instance Creation ******************************************************

    /**
     * Constructs a Directory with the given parent Directory and name.
     */
    public Directory(Directory parent, String name) {
        super(parent, name);
        this.parent = parent;
    }

    public long getSizeSum() {
        return sizeSum;
    }

    public long getWastedSizeSum() {
        return wastedSizeSum;
    }

    public long getOccupiedSizeSum() {
        return sizeSum + wastedSizeSum;
    }

    public void setSizeSum(long sizeSum) {
        this.sizeSum = sizeSum;
    }

    public long getCountSum() {
        return countSum;
    }

    public void setCountSum(long countSum) {
        this.countSum = countSum;
    }

    long getSize() {
        return size;
    }

    void setSizes(long size, int wastedSize) {
        this.size = size;
        this.wastedSize = wastedSize;
        addSize(size, wastedSize);
    }

    private void addSize(long aSize, long aWastedSize) {
        sizeSum += aSize;
        wastedSizeSum += aWastedSize;
        if (parent != null) {
            parent.addSize(aSize, aWastedSize);
        }
    }

    void setDirectories(List<Directory> directories) {
        this.directories = directories.toArray(new Directory[directories.size()]);
    }


    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder(getClass().getName());
        builder.append("; wastedSize=" + wastedSize + "; child dirs=");
        for (Directory directory : directories) {
            builder.append(directory);
            builder.append(", ");
        }
        return builder.toString();
    }

}