/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport.sandbox.domain;

import java.io.FilenameFilter;
import java.util.LinkedList;
import java.util.List;

import com.jgoodies.jdiskreport.domain.FileUtils;
import com.jgoodies.jdiskreport.domain.SystemUtils;


/**
 * This class provides behavior for a directory scan. Therefore
 * it recursively traverses a file tree and counts and measures
 * file and directories. It builds up a tree of statistical data.<p>
 *
 * To better guess the duration of the complete scan, the scanner
 * firstly performs a prescan to count the number of toplevel folders.
 *
 * @author Karsten Lentzsch
 */

public final class DirectoryScanner  {

    public static void main(String[] args) {
        SecurityManager security = System.getSecurityManager();
        System.out.println("Security manager=" + security);
        System.out.println("Launched...");
        String rootPath = args[0];
        Directory rootDir = new Directory(null, rootPath);
        new DirectoryScanner().scan(rootDir, null);
        System.out.println();
        System.out.println("Root dir=" + rootDir);
//        for (int i = 0; i < rootDir.directories.length; i++) {
//            Directory dir = rootDir.directories[i];
//            System.out.println("Total Size(" + dir + ")=" + dir.getSizeSum());
//        }
        System.out.println("Total Size(" + rootDir + ")=" + rootDir.getSizeSum());
        System.out.println("Occupied Size(" + rootDir + ")=" + rootDir.getOccupiedSizeSum());
        System.out.println("Wasted Size(" + rootDir + ")=" + rootDir.getWastedSizeSum());
        System.out.println("Size(" + rootDir + ")=" + rootDir.getSize());
    }

	private static final boolean CHECK_LINKS = !SystemUtils.IS_OS_WINDOWS;


    private long totalSize;
    private long totalDirSize;
    private long usedSpace;
	private long allFilesCount;
	private long allDirectoriesCount;
    private long allFilePathLengths;
    private long allFileNameLengths;


	/**
	 * Recursively scans and analyses the specified directory
	 * using the specified statistics depth and exclusions.
	 */
	public Directory scan(Directory rootDirectory, FilenameFilter filter) {
        allFilesCount = 0;
        allDirectoriesCount = 0;
        allFilePathLengths = 0;
        allFileNameLengths = 0;
        totalSize = 0;
        totalDirSize = 0;
        long totalSpace = 0; // TODO: Activate rootDirectory.getTotalSpace();
        long freeSpace = 0; // TODO: Activate rootDirectory.getFreeSpace();
        usedSpace = totalSpace - freeSpace;
        System.out.println("Total Space=" + totalSpace);
        System.out.println("Free Space=" + freeSpace);
        System.out.println("Used Space=" + usedSpace);
        System.out.println("Usable Space=" + 0); // TODO: Activate rootDirectory.getUsableSpace());
        System.out.println("Yeah");
        List<Directory> directories = new LinkedList<Directory>();
        directories.add(rootDirectory);
        int level = 0;
        while (!directories.isEmpty()) {
            System.out.println("Scanning level " + level);
            System.out.println("Progress=" + (110 * totalSize / usedSpace) + "%");
            System.out.println("Directories to scan " + directories.size());
            List<Directory> nextLevelDirectories = new LinkedList<Directory>();
            for (Directory directory : directories) {
                //System.out.print(directory.getPath() + "; ");
                scan(directory, filter, nextLevelDirectories);
            }
            System.out.println("Total size in level " + level + " :" + totalSize);
            //System.out.println();
            //System.out.println();
            directories = nextLevelDirectories;
            level++;
        }
        long wastedSpace = usedSpace - totalSize;
        long wastedPerFile = wastedSpace / Math.max(1, allFilesCount);
        long averageFileSize = totalSize / allFilesCount;
        System.out.println();
        System.out.println("Used space=" + usedSpace);
        System.out.println("Total size=" + totalSize);
        System.out.println("Total dir size=" + totalDirSize);
        System.out.println("Wasted space=" + wastedSpace);
        System.out.println("Wasted per file=" + wastedPerFile);
        System.out.println("Average file size=" + averageFileSize);
        System.out.println("Total dirs=" + allDirectoriesCount);
        System.out.println("Total files=" + allFilesCount);
        System.out.println("Total file path lengths=" + allFilePathLengths);
        System.out.println("Total file name lengths=" + allFileNameLengths);
        return null;
    }


    private void scan(Directory directory, FilenameFilter filter, List<Directory> nextLevelDirs) {
		String[] fileList = directory.list();
		if (null == fileList) {
			System.out.println("Access denied: " + directory);
			return;
		}

		// Create Directory and FileNode
		//FileNode node = null == parent ? new FileRoot(directory) : new FileNode(directory, parent);

		// Iterate over the directory's content. Recurse into child directories.
		int  childCount	= fileList.length;
		long fileLengthSum	= 0;
        int wastedSizeSum = 0;
		long fileLength;
        List<Directory> childDirs  = new LinkedList<Directory>();
		for (int i = 0; i < childCount; i++) {
//			if (shouldStop)
//				break;

			String filename = fileList[i];
			Directory file = new Directory(directory, filename);
			boolean link;
			boolean accepted;
			if (CHECK_LINKS) {
				String canonicalPath = FileUtils.getCanonicalPath(file);
				link = FileUtils.isLink(file, canonicalPath);
				accepted = (filter == null)
                        || filter.accept(directory, canonicalPath);
			} else {
				link = false;
                accepted = (filter == null)
                         || filter.accept(directory, FileUtils.getCanonicalPath(file));
			}

			if (accepted) {
				if (!link && file.isDirectory()) {
					//statistics.addDirectory();
                    childDirs.add(file);
                    totalDirSize += file.getPath().length();
                    allDirectoriesCount++;
				} else {
					// TODO: Add a little sanity check, e.g. if file size is > 0.
					fileLength = link
                                     ? FileUtils.linkLength(file)
                                     : file.length();
                    long clusterOverlap = fileLength % 4096;
                    long wastedSize = clusterOverlap == 0 ? 0 : (4096 - clusterOverlap);
                    //childFiles.add(new FastFile(directory, file.getName(), fileLength));
					//lastModified = file.lastModified();
					fileLengthSum += fileLength;
                    wastedSizeSum += wastedSize;
					//statistics.updateOn(file, fileLength, lastModified);
					allFilesCount++;
                    allFilePathLengths += file.getPath().length();
                    allFileNameLengths += file.getName().length();
//					if (fileCount % 100 == 99)
//						setNoteAndContent(directory.toString());
				}
			}
		}
        if (directory.getParent() == null) {
            System.out.println("FileLengthSum=" + fileLengthSum);
        }
        totalSize += fileLengthSum;
        directory.setDirectories(childDirs);
        directory.setSizes(fileLengthSum, wastedSizeSum);
        nextLevelDirs.addAll(childDirs);
	}




}