/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.jdiskreport;



/**
 * Tests AbstractTreeChart#computePartitions.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.3 $
 */
public final class PartitionTest {

    public static void main(String[] args) {
        new PartitionTest().test();
    }


    private void test() {
        long[] sizes1 = {1l, 2l, 3l};
        long totalSize1 = 6l;
        for(int totalWidth = 10; totalWidth < 11; totalWidth++) {
            int[] partition = computePartitions(sizes1, totalSize1, totalWidth);
            System.out.print("Partition width=" + totalWidth + ": ");
            printPartition(partition);
        }
    }

    public static int[] computePartitions(long[] sizes, long totalSize, int totalWidth) {
        int elements = sizes.length;
        int[] result = new int[elements];
        if (elements == 1) {
            result[0] = totalWidth;
            return result;
        }
        double lastRoundingRest = 0;
        int usedWidth = 0;
        for (int i=0; i < elements; i++) {
            double size = sizes[i];
            double fraction = totalSize == 0 ? 1d : size / totalSize;
            double width = fraction * totalWidth;
            int roundedWidth = (int) Math.round(width + lastRoundingRest);
            double roundingRest = width - roundedWidth;
            lastRoundingRest = roundingRest;
            //System.out.println("i=" + i + "; fraction=" + fraction + "; width=" + width + "; roundingRest=" + roundingRest + "; usedWidth=" + usedWidth);
            result[i] = (i < elements - 1)
                ? roundedWidth
                : totalWidth - usedWidth;
            usedWidth += roundedWidth;
        }
        return result;
    }


    private void printPartition(int[] partition) {
        System.out.print("[");
        for (int i = 0; i < partition.length; i++) {
            System.out.print(partition[i]);
            if (i < partition.length-1) {
                System.out.print(", ");
            }
        }
        System.out.println("]");
    }
}
