/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.looks.demo;

import java.awt.Frame;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.UIManager;

import com.jgoodies.forms.util.DefaultUnitConverter;
import com.jgoodies.looks.launcher.Launcher;
import com.jgoodies.uif.AbstractFrame;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.builder.PanelBuilder2;
import com.jgoodies.uif.osx.OSXApplicationMenu;
import com.jgoodies.uif.splash.ImageSplash;
import com.jgoodies.uif.splash.Splash;
import com.jgoodies.uifextras.convenience.DefaultUIFApplication;
import com.jgoodies.uifextras.convenience.ResourceIDs;

/**
 * The main class of the JGoodies Looks Demo. Configures the splash,
 * UI, creates the main frame and defines several global values.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.12 $
 */

public final class LooksDemo extends DefaultUIFApplication {


    public static void main(String[] arguments) {
        OSXApplicationMenu.setAboutName("Looks Demo");
        Application.launch(LooksDemo.class, arguments);
    }


    @Override
    protected void configureSplash() {
        Image image = getAppResourceMap().getImage(ResourceIDs.SPLASH_IMAGE);
        ImageSplash splash = new ImageSplash(new Frame(), image, "", false);
        splash.setProgressVisible(false);
        Splash.setProvider(splash);
    }

    /**
     * Configures the user interface: sets the mixed font size hint,
     * and enables auditory feedback.
     */
    @Override
    protected void configureUI() {
        super.configureUI();
        UIManager.put("AuditoryCues.playList",
                UIManager.get("AuditoryCues.allAuditoryCues"));
        // Modern dlu conversion
        DefaultUnitConverter.getInstance().setAverageCharacterWidthTestString(
            "abcdefghijklmnopqrstuvwxyz0123456789");
        PanelBuilder2.setLabelForFeatureEnabledDefault(true);
    }

    /**
     * Writes several font desktop properties to the console.
     */
    /*
    private void logDesktopFontProperties() {
    	Toolkit toolkit = Toolkit.getDefaultToolkit();
    	System.out.println("Menu font      =" + toolkit.getDesktopProperty("win.menu.font"));
    	System.out.println("Fixed ctrl.font=" + toolkit.getDesktopProperty("win.ansi.font"));
    	System.out.println("Control font   =" + toolkit.getDesktopProperty("win.ansiVar.font"));
    	System.out.println("Messagebox font=" + toolkit.getDesktopProperty("win.messagebox.font"));
    }
    */

    /**
     * Creates and returns the application's main frame.
     */
    @Override
    protected AbstractFrame createMainFrame() {
        return new Launcher();
    }

    /**
     * Initializes the actions used in this demo.
     * Just registers an about and quit handler with the
     * Mac OS X application menu.
     */
    @Override
    protected void initializeActions() {
        OSXApplicationMenu.register(
            new DemoFrameUIF.AboutActionHandler(),
            null,
            new QuitActionHandler());
    }


    // *************************************************************

    private static final class QuitActionHandler implements ActionListener {

        public void actionPerformed(ActionEvent evt) {
            System.exit(0);
        }
    }

}