/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.looks.demo;

import javax.swing.*;

import com.jgoodies.uif.component.UIFCheckBoxMenuItem;
import com.jgoodies.uif.component.UIFMenuItem;
import com.jgoodies.uif.component.UIFRadioButtonMenuItem;
import com.jgoodies.uif.osx.OSXApplicationMenu;
import com.jgoodies.uif.util.SystemUtils;

/**
 * Builds the menu bar and pull-down menus in the full JGoodies Looks Demo.
 * Demonstrates and tests different multi-platform issues.<p>
 *
 * This class overrides the factory methods provided by its
 * superclass <code>MenuBuilder</code> to vend components from
 * the JGoodies UI framework that better handle different platforms.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.6 $
 *
 * @see com.jgoodies.uif.component.UIFMenuItem
 * @see com.jgoodies.uif.component.UIFCheckBoxMenuItem
 * @see com.jgoodies.uif.component.UIFRadioButtonMenuItem
 */

final class MenuBarViewUIF extends MenuBarView {

    // Factory Methods ********************************************************

    @Override
    protected JMenu createMenu(String text, char mnemonic) {
        return new com.jgoodies.uif.builder.MenuBuilder(text, mnemonic).getMenu();
    }

    @Override
    protected JMenuItem createMenuItem(String text) {
        return new UIFMenuItem(text);
    }

    @Override
    protected JMenuItem createMenuItem(String text, char mnemonic) {
        return new UIFMenuItem(text, mnemonic);
    }

    @Override
    protected JMenuItem createMenuItem(String text, char mnemonic, KeyStroke key) {
        JMenuItem menuItem = new UIFMenuItem(text, mnemonic);
        menuItem.setAccelerator(key);
        return menuItem;
    }

    @Override
    protected JMenuItem createMenuItem(String text, Icon icon) {
        return new UIFMenuItem(text, icon);
    }

    @Override
    protected JMenuItem createMenuItem(String text, Icon icon, char mnemonic) {
        JMenuItem menuItem = new UIFMenuItem(text, icon);
        menuItem.setMnemonic(mnemonic);
        return menuItem;
    }

    @Override
    protected JMenuItem createMenuItem(String text, Icon icon, char mnemonic, KeyStroke key) {
        JMenuItem menuItem = createMenuItem(text, icon, mnemonic);
        menuItem.setAccelerator(key);
        return menuItem;
    }

    @Override
    protected JRadioButtonMenuItem createRadioButtonMenuItem(String text, boolean selected) {
        return new UIFRadioButtonMenuItem(text, selected);
    }

    @Override
    protected JCheckBoxMenuItem createCheckBoxMenuItem(String text, boolean selected) {
        return new UIFCheckBoxMenuItem(text, selected);
    }


    // Overriding Superclass Behavior *****************************************

    /**
     * Checks and answers whether the quit action has been moved to an
     * operating system specific menu, e.g. the OS X application menu.<p>
     *
     * This is the case if and only if we're running on the Mac OS X.
     *
     * @return true if the quit action is in an OS-specific menu
     */
    @Override
    protected boolean isQuitInOSMenu() {
        return SystemUtils.IS_OS_MAC;
    }


    /**
     * Checks and answers whether the about action has been moved to an
     * operating system specific menu, e.g. the OS X application menu.<p>
     *
     * This is the case if and only if an about handler could be successfully
     * registered with the Mac OS X application menu.
     *
     * @return true if the about action is in an OS-specific menu
     */
    @Override
    protected boolean isAboutInOSMenu() {
        return OSXApplicationMenu.isRegisteredAbout();
    }


}
