/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.metamorphosis;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Insets;

import javax.swing.UIManager;
import javax.swing.border.AbstractBorder;
import javax.swing.plaf.UIResource;

/**
 * Provides borders used in Fakeclipse.
 *
 * @author Karsten Lentzsch
 */
final class Borders {


	static class ThinStatusBorder extends AbstractBorder implements UIResource {

		private static final Insets INSETS = new Insets(1, 1, 1, 1);

		@Override
        public void paintBorder(Component c, Graphics g, int x, int y, int w, int h) {
			g.translate(x, y);
			g.setColor(UIManager.getColor("controlShadow"));
			g.drawLine(0, 0, w - 2, 0);
			g.drawLine(0, 0, 0, h - 2);
			g.setColor(UIManager.getColor("controlLtHighlight"));
			g.drawLine(w - 1, 0, w - 1, h - 1);
			g.drawLine(0, h - 1, w - 1, h - 1);
			g.translate(-x, -y);
		}
		@Override
        public Insets getBorderInsets(Component c) {
			return INSETS;
		}
	}


	static class FlatHeaderBorder extends AbstractBorder implements UIResource {

		private static final Insets INSETS = new Insets(1, 1, 0, 1);

		@Override
        public void paintBorder(Component c, Graphics g, int x, int y, int w, int h) {
			g.translate(x, y);
			g.setColor(UIManager.getColor("controlShadow"));
			g.drawLine(0, 0, w - 1, 0);
			g.drawLine(0, 0, 0, h - 1);
			//g.drawLine(0, h - 1, w - 1, h - 1);
			g.setColor(UIManager.getColor("controlLtHighlight"));
			g.drawLine(w-1, 0, w - 1, h - 1);
			g.translate(-x, -y);
		}
		@Override
        public Insets getBorderInsets(Component c) {
			return INSETS;
		}
	}


	static class EclipseHeaderBorder extends AbstractBorder implements UIResource {

		private static final Insets INSETS = new Insets(1, 1, 1, 0);

		@Override
        public void paintBorder(Component c, Graphics g, int x, int y, int w, int h) {
			g.translate(x, y);
			g.setColor(UIManager.getColor("controlLtHighlight"));
			g.drawLine(0, 0, w - 1, 0);
			g.drawLine(0, 0, 0, h - 2);
			g.setColor(UIManager.getColor("controlShadow"));
			g.drawLine(0, h - 1, w - 1, h - 1);
			g.translate(-x, -y);
		}
		@Override
        public Insets getBorderInsets(Component c) {
			return INSETS;
		}
	}


	static class EclipseTabHeaderBorder extends AbstractBorder implements UIResource {

		private static final Insets INSETS = new Insets(0, 0, 1, 0);

		@Override
        public void paintBorder(Component c, Graphics g, int x, int y, int w, int h) {
			g.translate(x, y);
			g.setColor(UIManager.getColor("controlShadow"));
			g.drawLine(0, h - 1, w - 1, h - 1);
			g.translate(-x, -y);
		}
		@Override
        public Insets getBorderInsets(Component c) {
			return INSETS;
		}
	}


	static class EclipseTabBorder extends AbstractBorder implements UIResource {

		private static final Insets INSETS = new Insets(0, 0, 0, 2);

		@Override
        public void paintBorder(Component c, Graphics g, int x, int y, int w, int h) {
			g.translate(x, y);
			g.setColor(UIManager.getColor("controlShadow"));
			g.drawLine(w - 2, 0, w - 2, 1);
			g.drawLine(w - 1, 1, w - 1, h - 1);
			g.setColor(UIManager.getColor("control"));
			g.drawLine(w - 1, 0, w - 1, 0);
			g.setColor(UIManager.getColor("controlLtHighlight"));
			g.drawLine(w - 2, 1, w - 2, h - 1);
			g.translate(-x, -y);
		}
		@Override
        public Insets getBorderInsets(Component c) {
			return INSETS;
		}
	}


	static class EclipsePanelBorder extends AbstractBorder implements UIResource {

        private static final Insets INSETS = new Insets(1, 1, 3, 3);

        @Override
        public Insets getBorderInsets(Component c) { return INSETS; }

        @Override
        public void paintBorder(Component c, Graphics g,
            int x, int y, int w, int h) {

            Color shadow        = UIManager.getColor("controlShadow");
            Color lightShadow   = new Color(shadow.getRed(),
                                            shadow.getGreen(),
                                            shadow.getBlue(),
                                            170);
            Color lighterShadow = new Color(shadow.getRed(),
                                            shadow.getGreen(),
                                            shadow.getBlue(),
                                            70);
            g.translate(x, y);

            g.setColor(shadow);
            g.fillRect(0, 0, w - 3, 1);
            g.fillRect(0, 0, 1, h - 3);
            g.fillRect(w - 3, 1, 1, h - 3);
            g.fillRect(1, h - 3, w - 3, 1);
            // Shadow line 1
            g.setColor(lightShadow);
            g.fillRect(w - 3, 0, 1, 1);
            g.fillRect(0, h - 3, 1, 1);
            g.fillRect(w - 2, 1, 1, h - 3);
            g.fillRect(1, h - 2, w - 3, 1);
            // Shadow line2
            g.setColor(lighterShadow);
            g.fillRect(w - 2, 0, 1, 1);
            g.fillRect(0, h - 2, 1, 1);
            g.fillRect(w-2, h-2, 1, 1);
            g.fillRect(w - 1, 1, 1, h - 2);
            g.fillRect(1, h - 1, w - 2, 1);
            g.translate(-x, -y);
        }
    }



}