/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.metamorphosis;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;

import javax.swing.*;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeCellRenderer;
import javax.swing.tree.TreeNode;

/**
 * This class provides the model and layout for an emulation
 * of an Eclipse JDT project/packages tree and panel.
 *
 * @author Karsten Lentzsch
 */
final class PackagesPanel {

    Component build() {
        JPanel panel = UIFactory.createEclipsePanel(
                Utils.getIcon("package.gif"),
                "Packages",
                Utils.getIcon("package_tools.gif"),
                false);
        JTree tree = new JTree(createProjectTree());
        tree.setRootVisible(false);
        tree.setShowsRootHandles(true);
        tree.expandRow(4);
        tree.expandRow(5);
        tree.expandRow(0);

        if (Style.getCurrent().iconStyle() == Style.IconStyle.WIN) {
            tree.setCellRenderer(new LabeledNodeRenderer());
        }

        JScrollPane scrollPane = UIFactory.createScrollPane(tree);
        panel.add(scrollPane, BorderLayout.CENTER);
        panel.setMinimumSize(new Dimension(140, 200));
        panel.setPreferredSize(new Dimension(140, 200));
        return panel;
    }

    private TreeNode createProjectTree() {
        Icon projectIcon = Utils.getIcon("project.gif");
        Icon folderIcon = Utils.getIcon("fldr_obj.gif");
        Icon packageFolderIcon = Utils.getIcon("packagefolder_obj.gif");
        Icon packageIcon = Utils.getIcon("package.gif");
        Icon javaIcon = Utils.getIcon("javasrc.gif");
        Icon textIcon = Utils.getIcon("file_obj.gif");
        DefaultMutableTreeNode root = new LabeledNode(null, null);
        DefaultMutableTreeNode project;
        DefaultMutableTreeNode folder0;
        DefaultMutableTreeNode folder1;

        project = new LabeledNode(projectIcon, "Chartster");
        folder0 = new LabeledNode(packageFolderIcon, "src");
        project.add(folder0);
        folder0.add(new LabeledNode(packageIcon, "com.jgoodies.chartster"));
        folder0 = new LabeledNode(folderIcon, "build");
        folder0.add(new LabeledNode(textIcon, "manifest.txt"));
        project.add(folder0);
        root.add(project);

        project = new LabeledNode(projectIcon, "JDiskReport");
        folder0 = new LabeledNode(packageFolderIcon, "src");
        project.add(folder0);
        folder0.add(new LabeledNode(packageIcon, "com.jgoodies.jdiskreport"));
        folder0 = new LabeledNode(folderIcon, "build");
        project.add(folder0);
        root.add(project);

        project = new LabeledNode(projectIcon, "JGoodies Animations");
        folder0 = new LabeledNode(packageFolderIcon, "src");
        project.add(folder0);
        folder0 = new LabeledNode(folderIcon, "build");
        project.add(folder0);
        root.add(project);

        project = new LabeledNode(projectIcon, "JGoodies Charts");
        folder0 = new LabeledNode(packageFolderIcon, "src");
        project.add(folder0);
        folder0 = new LabeledNode(folderIcon, "build");
        project.add(folder0);
        root.add(project);

        project = new LabeledNode(projectIcon, "JGoodies Looks");
        folder0 = new LabeledNode(packageFolderIcon, "src");
        project.add(folder0);
        folder1 = new LabeledNode(packageIcon, "com.jgoodies.looks.plastic");
        folder1.add(new LabeledNode(javaIcon, "PlasticLookAndFeel.java"));
        folder0.add(folder1);
        folder1 = new LabeledNode(packageIcon, "com.jgoodies.looks.windows");
        folder1.add(new LabeledNode(javaIcon, "WindowsLookAndFeel.java"));
        folder0.add(folder1);
        folder1 =
            new LabeledNode(folderIcon, "com.jgoodies.looks.plastic.icons");
        folder1.add(new LabeledNode(textIcon, "resource.properties"));
        folder0.add(folder1);
        folder1 =
            new LabeledNode(folderIcon, "com.jgoodies.looks.windows.icons");
        folder1.add(new LabeledNode(textIcon, "resource.properties"));
        folder0.add(folder1);
        folder0 = new LabeledNode(folderIcon, "build");
        folder0.add(new LabeledNode(textIcon, "manifest.txt"));
        project.add(folder0);
        root.add(project);

        project = new LabeledNode(projectIcon, "JGoodies Looks Demo");
        folder0 = new LabeledNode(packageFolderIcon, "src");
        project.add(folder0);
        folder0 = new LabeledNode(folderIcon, "build");
        project.add(folder0);
        root.add(project);

        project = new LabeledNode(projectIcon, "JGoodies Swing Suite");
        folder0 = new LabeledNode(packageFolderIcon, "src");
        project.add(folder0);
        folder0 = new LabeledNode(folderIcon, "build");
        project.add(folder0);
        root.add(project);

        return root;
    }

    /*
     * A simple TreeNode implementation that provides an Icon and String label.
     */
    private static class LabeledNode extends DefaultMutableTreeNode {

        private final Icon   icon;
        private final String label;

        public LabeledNode(Icon icon, String label) {
            super(label);
            this.icon  = icon;
            this.label = label;
        }

        public Icon icon() {
            return icon;
        }

        public String label() {
            return label;
        }
    }

    /*
     * A renderer that renders instances of class LabeledNode.
     */
    private static class LabeledNodeRenderer
        extends DefaultTreeCellRenderer {
        @Override
        public Component getTreeCellRendererComponent(
            JTree tree,
            Object value,
            boolean sel,
            boolean expanded,
            boolean leaf,
            int row,
            boolean focused) {
            Component comp =
                super.getTreeCellRendererComponent(
                    tree,
                    value,
                    sel,
                    expanded,
                    leaf,
                    row,
                    focused);
            JLabel label = (JLabel) comp;
            LabeledNode node = (LabeledNode) value;
            label.setIcon(node.icon());
            label.setText(node.label());
            return label;
        }
    }


}