/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.metamorphosis;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Dimension;

import javax.swing.*;
import javax.swing.border.Border;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.DefaultTableCellRenderer;
import javax.swing.table.TableModel;

/**
 * This class provides the model and layout for an emulation
 * of an Eclipse JDT project/packages tree and panel.
 *
 * @author Karsten Lentzsch
 */
final class TasksPanel {

    /**
     * Builds and answers the task panel component.
     */
    Component build() {
        final int[] ALIGNMENTS =
            {
                SwingConstants.CENTER,
                SwingConstants.CENTER,
                SwingConstants.CENTER,
                SwingConstants.LEFT,
                SwingConstants.LEFT,
                SwingConstants.LEFT,
                SwingConstants.LEFT,
                SwingConstants.LEFT };
        final int[] COLUMN_SIZES =
            new int[] { 19, 19, 19, 195, 87, 135, 60, 10 };
        JPanel panel =
            UIFactory.createEclipsePanel(
                Utils.getIcon("tasks.gif"),
                "Tasks (2 items)",
                Utils.getIcon("tasks_tools.gif"),
                true);
        SpecialReadOnlyTable table = new SpecialReadOnlyTable();
        // Modify the cell renderer.
        table.setDefaultRenderer(
            Object.class,
            new MyDefaultTableCellRenderer());

        table.setHeaderAlignments(ALIGNMENTS);
        table.setColumnSizes(COLUMN_SIZES);
        table.setModel(createTasksTableModel());
        table.setMinimumSize(new Dimension(200, 100));

        if (Style.getCurrent().useExtendedLookAndFeel()
            && Style.getCurrent().forceSystemLookAndFeel()) {
            table.setGridColor(UIManager.getColor("controlHighlight"));
        }

        JScrollPane scrollPane = UIFactory.createScrollPane(table);
        panel.add(scrollPane, BorderLayout.CENTER);
        panel.setPreferredSize(new Dimension(360, 115));
        return panel;
    }

    /**
     * Creates and answers the model for the tasks table.
     */
    private TableModel createTasksTableModel() {
        final Icon warningIcon = Utils.getIcon("error_tsk.gif");
        final String[] COLUMN_NAMES =
            {
                "",
                "C.",
                "!",
                "Description",
                "Resource",
                "In Folder",
                "Location",
                "" };
        final String[][] TASKS =
            {
                {
                    "org.cdc.Channel cannot be resolved",
                    "Launcher.java",
                    "Peek-a-Booty Client/src/com/jgoodies/peekaboo/",
                    "line 42 in Launcher.java",
                    "" },
                {
                "org.cdc.Broadcast cannot be resolved",
                    "Launcher.java",
                    "Peek-a-Booty Client/src/com/jgoodies/peekaboo/",
                    "line 44 in MainModel.registerListeners()",
                    "" },
                    {
                "", "", "", "", "" }
        };

        return new AbstractTableModel() {
            public int getColumnCount() {
                return COLUMN_NAMES.length;
            }
            @Override
            public String getColumnName(int col) {
                return COLUMN_NAMES[col];
            }
            public int getRowCount() {
                return TASKS.length;
            }
            public Object getValueAt(int row, int col) {
                if (col == 0 && row < 2) {
                    return warningIcon;
                } else if (col < 3) {
                    return "";
                } else
                    return TASKS[row][col - 3];
            }
        };
    }

    // Helper Class *********************************************************************

    // A table cell renderer that emulates the eclipse JDT task table cells.
    private static class MyDefaultTableCellRenderer
        extends DefaultTableCellRenderer {

        private static final Border HPAD_BORDER =
            BorderFactory.createEmptyBorder(0, 4, 0, 4);
        private static final Border EMPTY_BORDER =
            BorderFactory.createEmptyBorder(0, 0, 0, 0);

        @Override
        public Component getTableCellRendererComponent(
            JTable table,
            Object value,
            boolean isSelected,
            boolean hasFocus,
            int row,
            int column) {
            JLabel label =
                (JLabel) super.getTableCellRendererComponent(
                    table,
                    value,
                    isSelected,
                    false,
                    row,
                    column);
            if (value instanceof Icon) {
                label.setIcon((Icon) value);
                label.setText("");
                label.setBorder(EMPTY_BORDER);
            } else {
                label.setIcon(null);
                label.setBorder(HPAD_BORDER);
            }
            return label;
        }
    }

}