/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.metamorphosis;

import java.net.URL;

import javax.swing.ImageIcon;

/**
 * A helper class for accessing icon resources, etc..
 *
 * @author Karsten Lentzsch
 */
final class Utils {

    private Utils() {
        // Overrides default constructor; prevents instantiation.
    }

    static ImageIcon getIcon(String filename) {
        String pathPrefix;
        Style.IconStyle iconStyle = Style.getCurrent().iconStyle();
        if (iconStyle == Style.IconStyle.MIXED)
            pathPrefix = "resources/icons/mixed/";
        else if (iconStyle == Style.IconStyle.JFA)
            pathPrefix = "resources/icons/jfa/";
        else if (iconStyle == Style.IconStyle.WIN)
            pathPrefix = "resources/icons/win/";
        else
            throw new IllegalStateException("unknown IconStyle " + iconStyle);

        URL url = Utils.class.getResource(pathPrefix + filename);
        if (url == null)
            url = Utils.class.getResource("resources/icons/" + filename);

        if (url == null)
            return null;

        return new ImageIcon(url);
    }

    static boolean isWindowsPlatform() {
        return System.getProperty("os.name").startsWith("Windows");
    }

}