/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of JGoodies Karsten Lentzsch nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jgoodies.skeleton.model.node;

import javax.swing.Icon;

import com.jgoodies.skeleton.domain.Description;
import com.jgoodies.skeleton.model.Resources;

/**
 * This class represents the project description in the navigation tree.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.5 $
 *
 * @see com.jgoodies.skeleton.domain.Description
 */
public final class DescriptionNode extends AbstractTreeNode {


    // Instance Creation ******************************************************

    /**
     * Constructs a <code>DescriptionNode</code> for the given parent and
     * description.
     *
     * @param parent       this node's parent
     * @param description  the associated model, a description instance
     */
    public DescriptionNode(NavigationNode parent, Description description) {
        super(parent, description);
    }


    // Implementing the NavigationNode Interface ******************************

    /**
     * Returns this node's name, a constant requested from the global
     * resource repository.
     *
     * @return this node's name
     */
    @Override
    public String getName() {
        return Resources.DESCRIPTION_NAME;
    }


    // ************************************************************************

    /**
     * Returns this node's icon, ignores the selection.
     * The icons is requested from a global resource repository.
     *
     * @return this description node's icon.
     */
    @Override
    public Icon getIcon(boolean sel) {
        return Resources.DESCRIPTION_ICON;
    }


    /**
     * Returns this node's associated Description instance.
     *
     * @return this node's associated Description instance.
     * @see NavigationNode#getModel()
     */
    public Description getDescription() {
        return (Description) getModel();
    }

}