/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.view;

import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JComponent;

import com.jgoodies.skeleton.model.MainModel;
import com.jgoodies.uif_lite.AbstractFrame;

/**
 * The main frame of the skeleton application.
 * It creates the menus, toolbar and all subpanels.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.12 $
 *
 * @see MainModel
 */
public final class MainFrame extends AbstractFrame {

    /**
     * Refers to the mainModel that provides all high-level models.
     * Used to build this frame's main page.
     *
     * @see #buildContentPane()
     */
    private final MainModel mainModel;


    // Instance Creation ****************************************************

    /**
     * Constructs an instance of the Skeleton app's main frame.
     *
     * @param mainModel   provides bound properties and high-level models
     */
    public MainFrame(String title, MainModel mainModel) {
        super(title);
        this.mainModel = mainModel;
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
    }


    // Building *************************************************************

    /**
     * Builds this MainFrame. In addition to the superclass behavior,
     * this method builds and sets the menu bar.
     */
    @Override
    public void build() {
        super.build();
        setJMenuBar(new MenuBarView(mainModel).getMenuBar());
    }

    /**
     * Builds this frame's content pane.
     */
    @Override
    protected JComponent buildContentPane() {
        return new MainPageView(mainModel).getPanel();
    }


    // Closing Window and Exiting the Application ***************************

    /**
     * Configures the behavior that will happen
     * when the user initiates a "close" on this frame.
     */
    @Override
    protected void configureCloseOperation() {
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowClosingHandler());
    }


    // Helper Class *********************************************************

    private class WindowClosingHandler extends WindowAdapter {
        @Override
        public void windowClosing(WindowEvent e) {
            mainModel.aboutToExitApplication(MainFrame.this);
        }
    }

}