/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.view.editor;

import java.awt.Color;
import java.awt.Component;
import java.awt.GridLayout;

import javax.swing.*;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.looks.LookUtils;
import com.jgoodies.skeleton.Skeleton;
import com.jgoodies.skeleton.model.MainModel;
import com.jgoodies.skeleton.model.Resources;
import com.jgoodies.uif_lite.AbstractView;
import com.jgoodies.uif_lite.application.ResourceMap;

/**
 * This panel is displayed after a successful application startup
 * to welcome the user. It provides access to actions that are
 * most useful at the application start.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.13 $
 */
public final class WelcomeView extends AbstractView implements Editor {

    private static final ResourceMap RESOURCES =
        new ResourceMap(null, Skeleton.class);

    private final MainModel mainModel;

    private Component logoLabel;
    private Component whatLabel;
    private Component gradientLabel;
    private Component newProjectButton;
    private Component openProjectButton;


    // Instance Creation ******************************************************

    public WelcomeView(MainModel mainModel) {
        this.mainModel = mainModel;
    }


    // Implementing the Editor Interface **************************************

    public Icon getIcon() {
        return null;
    }

    public String getTitle() {
        return "Welcome";
    }

    public JToolBar getToolBar() {
        return null;
    }

    public void activate() {
        // Nothing to do in this welcome panel.
    }

    public void deactivate() {
        // Nothing to do in this welcome panel.
    }


    public void updateModel(Object model) {
        // Do nothing.
    }

    public void updateView(Object model) {
        // Do nothing.
    }


    // Building ***************************************************************

    private void initComponents() {
        logoLabel     = new JLabel(RESOURCES.getIcon(Resources.LOGO_ICON_ID));
        whatLabel     = new JLabel("What do you want to do?");
        gradientLabel = new JLabel(RESOURCES.getIcon(Resources.GRADIENT_ICON_ID));
        newProjectButton  = createActionComponent(mainModel.getNewProjectAction());
        openProjectButton = createActionComponent(mainModel.getOpenProjectAction());
    }

    /**
     * Creates and returns a component for the specified Action.
     */
    private JComponent createActionComponent(Action a) {
        JButton button = new JButton(a);
        button.setIcon(RESOURCES.getIcon(Resources.ITEM_ICON_ID));
        button.setHorizontalTextPosition(SwingConstants.RIGHT);
        button.setVerticalTextPosition(SwingConstants.CENTER);
        button.setHorizontalAlignment(SwingConstants.LEFT);
        button.setBorderPainted(false);
        button.setFocusPainted(false);
        button.setContentAreaFilled(false);
        button.setForeground(Color.BLACK);
        if (LookUtils.IS_OS_MAC) {
            button.setBackground(Color.WHITE);
        }
        button.setText((String) a.getValue(Action.LONG_DESCRIPTION));
        return button;
    }

    /**
     * Builds and returns this view's panel.
     */
    @Override
    protected JComponent buildPanel() {
        initComponents();

        FormLayout layout = new FormLayout(
                "left:pref:grow",
                "c:pref, 12dlu, t:pref, 3dlu, top:pref:grow");
        PanelBuilder builder = new PanelBuilder(layout);
        builder.setBackground(Color.WHITE);
        builder.setBorder(Borders.createEmptyBorder("16dlu, 14dlu, 0, 0"));

        CellConstraints cc = new CellConstraints();
        builder.add(logoLabel,          cc.xy(1, 1));
        builder.add(whatLabel,          cc.xy(1, 3));
        builder.add(buildActionPanel(), cc.xy(1, 5));
        builder.add(gradientLabel,      cc.xy(1, 5, "r, b"));
        return builder.getPanel();
    }

    /**
     * Builds and returns the action panel.
     */
    private JComponent buildActionPanel() {
        JPanel panel = new JPanel(new GridLayout(2, 1));
        panel.add(newProjectButton);
        panel.add(openProjectButton);
        panel.setOpaque(false);
        return panel;
    }

}