/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.domain;

import com.jgoodies.binding.beans.Model;


/**
 * Describes a project and provides bound bean properties for the
 * manufacturer, inspector and ship data.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */

public class Description extends Model {

    // Names of the Bound Bean Properties *************************************

    public static final String PROPERTYNAME_STATUS         = "status";
    public static final String PROPERTYNAME_COMPANY_NAME   = "companyName";
    public static final String PROPERTYNAME_CONTACT_PERSON = "contactPerson";
    public static final String PROPERTYNAME_HULL_NUMBERS   = "hullNumbers";
    public static final String PROPERTYNAME_INSPECTOR      = "inspector";
    public static final String PROPERTYNAME_NAME           = "name";
    public static final String PROPERTYNAME_ORDER_NO       = "orderNo";
    public static final String PROPERTYNAME_PROJECT_TYPE   = "projectType";
    public static final String PROPERTYNAME_REFERENCE_NO   = "referenceNo";
    public static final String PROPERTYNAME_REGISTER_NO    = "registerNo";
    public static final String PROPERTYNAME_SHIPYARD       = "shipyard";


    // Enumerations ***********************************************************

    public static final String STATUS_UNASSIGNED  = "Unassigned";
    public static final String STATUS_ASSIGNED    = "Assigned";
    public static final String STATUS_IN_PROGRESS = "In Progress";
    public static final String STATUS_FINISHED    = "Finished";
    public static final String STATUS_RELEASED    = "Released";

    /**
     * Holds the status array.
     */
    public static final String[] STATUS_ARRAY =
        { STATUS_UNASSIGNED, STATUS_ASSIGNED, STATUS_IN_PROGRESS,
          STATUS_FINISHED, STATUS_RELEASED };


    public static final String TYPE_NEW_BUILDING  = "New";
    public static final String TYPE_CONVERSION    = "Conversion";
    public static final String TYPE_REPAIR        = "Repair";


    // Instance Fields ********************************************************

    private String name;
    private String companyName;
    private String orderNo;
    private String contactPerson;

    private String referenceNo;
    private String inspector;
    private String status;

    private String registerNo;
    private String shipyard;
    private String hullNumbers;
    private String projectType;


    // Instance Creation ******************************************************

    /**
     * Constructs a project <code>Description</code> with the given name.
     *
     * @param name   the project's name
     */
    public Description(String name) {
        this.name = name;
    }


    // Property Accessors *****************************************************

    /**
     * @return the current approval status: in progress, finished, released
     */
    public String getStatus() {
        return status;
    }

    /**
     * @return the company's name
     */
    public String getCompanyName() {
        return companyName;
    }

    /**
     * @return the name of the client's contact person
     */
    public String getContactPerson() {
        return contactPerson;
    }

    /**
     * @return the hull numbers on sheet #456-IH
     */
    public String getHullNumbers() {
        return hullNumbers;
    }

    /**
     * @return the name of the inspector
     */
    public String getInspector() {
        return inspector;
    }

    /**
     * @return the project's name
     */
    public String getName() {
        return name;
    }

    /**
     * @return the project's order number
     */
    public String getOrderNo() {
        return orderNo;
    }

    /**
     * @return the type of the project: new building, conversion, repair
     */
    public String getProjectType() {
        return projectType;
    }

    /**
     * @return the project's reference number
     */
    public String getReferenceNo() {
        return referenceNo;
    }

    /**
     * @return the ship's international register number
     */
    public String getRegisterNo() {
        return registerNo;
    }

    /**
     * @return the ship yard
     */
    public String getShipyard() {
        return shipyard;
    }

    /**
     * @param newStatus   the status to set
     */
    public void setStatus(String newStatus) {
        String oldStatus = getStatus();
        status = newStatus;
        firePropertyChange(PROPERTYNAME_STATUS, oldStatus, newStatus);
    }

    /**
     * @param newCompanyName    the name to set
     */
    public void setCompanyName(String newCompanyName) {
        String oldCompanyName = getCompanyName();
        companyName = newCompanyName;
        firePropertyChange(PROPERTYNAME_COMPANY_NAME, oldCompanyName, newCompanyName);
    }

    /**
     * @param newContactPerson  the contact name to set
     */
    public void setContactPerson(String newContactPerson) {
        String oldContactPerson = getContactPerson();
        contactPerson = newContactPerson;
        firePropertyChange(PROPERTYNAME_CONTACT_PERSON, oldContactPerson, newContactPerson);
    }

    /**
     * @param newHullNumbers    the hull numbers to set
     */
    public void setHullNumbers(String newHullNumbers) {
        String oldHullNumbers = getHullNumbers();
        hullNumbers = newHullNumbers;
        firePropertyChange(PROPERTYNAME_HULL_NUMBERS, oldHullNumbers, newHullNumbers);
    }

    /**
     * @param newInspector  the inspector to set
     */
    public void setInspector(String newInspector) {
        String oldInspector = getInspector();
        inspector = newInspector;
        firePropertyChange(PROPERTYNAME_INSPECTOR, oldInspector, newInspector);
    }

    /**
     * @param newName   the name to set
     */
    public void setName(String newName) {
        String oldName = getName();
        name = newName;
        firePropertyChange(PROPERTYNAME_NAME, oldName, newName);
    }

    /**
     * @param newOrderNo    the order number to set
     */
    public void setOrderNo(String newOrderNo) {
        String oldOrderNo = getOrderNo();
        orderNo = newOrderNo;
        firePropertyChange(PROPERTYNAME_ORDER_NO, oldOrderNo, newOrderNo);
    }

    /**
     * @param newProjectType    the project type to set
     */
    public void setProjectType(String newProjectType) {
        String oldProjectType = getProjectType();
        projectType = newProjectType;
        firePropertyChange(PROPERTYNAME_PROJECT_TYPE, oldProjectType, newProjectType);
    }

    /**
     * @param newReferenceNo    the reference number to set
     */
    public void setReferenceNo(String newReferenceNo) {
        String oldReferenceNo = getReferenceNo();
        referenceNo = newReferenceNo;
        firePropertyChange(PROPERTYNAME_REFERENCE_NO, oldReferenceNo, newReferenceNo);
    }

    /**
     * @param newRegisterNo     the register no to set
     */
    public void setRegisterNo(String newRegisterNo) {
        String oldRegisterNo = getRegisterNo();
        registerNo = newRegisterNo;
        firePropertyChange(PROPERTYNAME_REGISTER_NO, oldRegisterNo, newRegisterNo);
    }

    /**
     * @param newShipyard   the ship yard to set
     */
    public void setShipyard(String newShipyard) {
        String oldShipyard = getShipyard();
        shipyard = newShipyard;
        firePropertyChange(PROPERTYNAME_SHIPYARD, oldShipyard, newShipyard);
    }


    // Misc *******************************************************************

    /**
     * Returns a string representation for this description.
     * Currently it prints the class info and name.
     *
     * @return a string representation of this project description
     */
    @Override
    public String toString() {
        return super.toString() + ':' + getName();
    }


}