/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.domain;

import com.jgoodies.binding.beans.Model;

/**
 * Describes flanges and provides bound bean properties for the flange
 * description, diameters, criteria and bolts.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */

public class Flange extends Model {

    // Names of the Bound Bean Properties *************************************

    public static final String PROPERTYNAME_IDENTIFIER = "identifier";
    public static final String PROPERTYNAME_PTI = "pti";
    public static final String PROPERTYNAME_POWER = "power";
    public static final String PROPERTYNAME_S = "s";
    public static final String PROPERTYNAME_DA = "da";
    public static final String PROPERTYNAME_DI = "di";
    public static final String PROPERTYNAME_DA2 = "da2";
    public static final String PROPERTYNAME_DI2 = "di2";
    public static final String PROPERTYNAME_RADIUS = "radius";
    public static final String PROPERTYNAME_DIAMETER = "diameter";
    public static final String PROPERTYNAME_LOCATION = "location";
    public static final String PROPERTYNAME_K_FACTOR = "kFactor";
    public static final String PROPERTYNAME_MATERIAL = "material";
    public static final String PROPERTYNAME_NUMBERS = "numbers";
    public static final String PROPERTYNAME_DS = "ds";


    // Instance Fields ********************************************************

    private String  identifier;
    private double  pti;
    private double  power;
    private int     s;

    private int     da;
    private int     di;
    private int     da2;
    private int     di2;
    private int     radius;
    private int     diameter;

    private String  location;
    private String  kFactor;
    private String  material;
    private String  numbers;
    private int     ds;


    // Instance Creation ******************************************************

    /**
     * Constructs a <code>Flange</code> with the given identifier.
     *
     * @param identifier    the initial name
     */
    public Flange(String identifier) {
        this.identifier = identifier;
    }


    // Property Accessors *****************************************************

    /**
     * @return the da.
     */
    public int getDa() {
        return da;
    }


    /**
     * @return the da2.
     */
    public int getDa2() {
        return da2;
    }


    /**
     * @return the di.
     */
    public int getDi() {
        return di;
    }


    /**
     * @return the di2.
     */
    public int getDi2() {
        return di2;
    }


    /**
     * @return the diameter.
     */
    public int getDiameter() {
        return diameter;
    }


    /**
     * @return the ds.
     */
    public int getDs() {
        return ds;
    }


    /**
     * Returns this flange's identifier.
     *
     * @return the identifier.
     */
    public String getIdentifier() {
        return identifier;
    }


    /**
     * @return the kFactor.
     */
    public String getKFactor() {
        return kFactor;
    }


    /**
     * @return the location.
     */
    public String getLocation() {
        return location;
    }


    /**
     * @return the material.
     */
    public String getMaterial() {
        return material;
    }


    /**
     * @return the numbers.
     */
    public String getNumbers() {
        return numbers;
    }


    /**
     * @return the power.
     */
    public double getPower() {
        return power;
    }


    /**
     * @return the pti.
     */
    public double getPti() {
        return pti;
    }


    /**
     * @return the radius.
     */
    public int getRadius() {
        return radius;
    }


    /**
     * @return the s.
     */
    public int getS() {
        return s;
    }


    /**
     * @param newDa The da to set.
     */
    public void setDa(int newDa) {
        int oldDa = getDa();
        da = newDa;
        firePropertyChange(PROPERTYNAME_DA, oldDa, newDa);
    }


    /**
     * @param newDa2 The da2 to set.
     */
    public void setDa2(int newDa2) {
        int oldDa2 = getDa2();
        da2 = newDa2;
        firePropertyChange(PROPERTYNAME_DA2, oldDa2, newDa2);
    }

    /**
     * @param newDi The di to set.
     */
    public void setDi(int newDi) {
        int oldDi = getDi();
        di = newDi;
        firePropertyChange(PROPERTYNAME_DI, oldDi, newDi);
    }


    /**
     * @param newDi2 The di2 to set.
     */
    public void setDi2(int newDi2) {
        int oldDi2 = getDi2();
        di2 = newDi2;
        firePropertyChange(PROPERTYNAME_DI2, oldDi2, newDi2);
    }


    /**
     * @param newDiameter The diameter to set.
     */
    public void setDiameter(int newDiameter) {
        int oldDiameter = getDiameter();
        diameter = newDiameter;
        firePropertyChange(PROPERTYNAME_DIAMETER, oldDiameter, newDiameter);
    }


    /**
     * @param newDs The ds to set.
     */
    public void setDs(int newDs) {
        int oldDs = getDs();
        ds = newDs;
        firePropertyChange(PROPERTYNAME_DS, oldDs, newDs);
    }


    /**
     * @param newIdentifier the identifier to set
     */
    public void setIdentifier(String newIdentifier) {
        String oldIdentifier = getIdentifier();
        identifier = newIdentifier;
        firePropertyChange(PROPERTYNAME_IDENTIFIER, oldIdentifier, newIdentifier);
    }


    /**
     * @param newKFactor The kFactor to set.
     */
    public void setKFactor(String newKFactor) {
        String oldKFactor = getKFactor();
        kFactor = newKFactor;
        firePropertyChange(PROPERTYNAME_K_FACTOR, oldKFactor, newKFactor);
    }


    /**
     * @param newLocation The location to set.
     */
    public void setLocation(String newLocation) {
        String oldLocation = getLocation();
        location = newLocation;
        firePropertyChange(PROPERTYNAME_LOCATION, oldLocation, newLocation);
    }


    /**
     * @param newMaterial The material to set.
     */
    public void setMaterial(String newMaterial) {
        String oldMaterial = getMaterial();
        material = newMaterial;
        firePropertyChange(PROPERTYNAME_MATERIAL, oldMaterial, newMaterial);
    }


    /**
     * @param newNumbers The numbers to set.
     */
    public void setNumbers(String newNumbers) {
        String oldNumbers = getNumbers();
        numbers = newNumbers;
        firePropertyChange(PROPERTYNAME_NUMBERS, oldNumbers, newNumbers);
    }


    /**
     * @param newPower The power to set.
     */
    public void setPower(double newPower) {
        double oldPower = getPower();
        power = newPower;
        firePropertyChange(PROPERTYNAME_POWER, oldPower, newPower);
    }


    /**
     * @param newPti The pti to set.
     */
    public void setPti(double newPti) {
        double oldPti = getPti();
        pti = newPti;
        firePropertyChange(PROPERTYNAME_PTI, oldPti, newPti);
    }


    /**
     * @param newRadius The radius to set.
     */
    public void setRadius(int newRadius) {
        int oldRadius = getRadius();
        radius = newRadius;
        firePropertyChange(PROPERTYNAME_RADIUS, oldRadius, newRadius);
    }


    /**
     * @param newS The s to set.
     */
    public void setS(int newS) {
        int oldS = getS();
        s = newS;
        firePropertyChange(PROPERTYNAME_S, oldS, newS);
    }


    // Misc *******************************************************************

    /**
     * Returns a string representation for this flange. Currently it prints the
     * class info and identifier.
     *
     * @return a string representation for this flange
     */
    @Override
    public String toString() {
        return super.toString() + ':' + getIdentifier();
    }

}