/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.domain;

import com.jgoodies.binding.beans.Model;


/**
 * Describes shaft segments and provides bound bean properties for
 * the segment description, diameters, and criteria.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */

public class Segment extends Model {

    // Names of the Bound Bean Properties *************************************

    public static final String PROPERTYNAME_IDENTIFIER = "identifier";
    public static final String PROPERTYNAME_PTI = "pti";
    public static final String PROPERTYNAME_POWER = "power";
    public static final String PROPERTYNAME_LEN = "len";
    public static final String PROPERTYNAME_DA = "da";
    public static final String PROPERTYNAME_DI = "di";
    public static final String PROPERTYNAME_DA2 = "da2";
    public static final String PROPERTYNAME_DI2 = "di2";
    public static final String PROPERTYNAME_RADIUS = "radius";
    public static final String PROPERTYNAME_DIAMETER = "diameter";
    public static final String PROPERTYNAME_LOCATION = "location";
    public static final String PROPERTYNAME_K_FACTOR = "kFactor";
    public static final String PROPERTYNAME_CONNECTION = "connection";
    public static final String PROPERTYNAME_RADIAL_HOLES = "radialHoles";
    public static final String PROPERTYNAME_LONGITUDINAL_SLOTS = "longitudinalSlots";


    // Instance Fields ********************************************************

    private String  identifier;
    private double  pti;
    private double  power;
    private int     len;

    private int     da;
    private int     di;
    private int     da2;
    private int     di2;
    private int     radius;
    private int     diameter;

    private String  location;
    private String  kFactor;
    private String  connection;
    private boolean radialHoles;
    private boolean longitudinalSlots;


    // Instance Creation ******************************************************

    /**
     * Constructs a <code>Segment</code> with the given identifier.
     *
     * @param identifier    the initial name
     */
    public Segment(String identifier) {
        this.identifier = identifier;
    }


    // Property Accessors *****************************************************

    /**
     * @return the connection.
     */
    public String getConnection() {
        return connection;
    }


    /**
     * @return the da.
     */
    public int getDa() {
        return da;
    }


    /**
     * @return the da2.
     */
    public int getDa2() {
        return da2;
    }


    /**
     * @return the di.
     */
    public int getDi() {
        return di;
    }


    /**
     * @return the di2.
     */
    public int getDi2() {
        return di2;
    }


    /**
     * @return the diameter.
     */
    public int getDiameter() {
        return diameter;
    }


    /**
     * Returns this segment's identifier.
     *
     * @return the identifier.
     */
    public String getIdentifier() {
        return identifier;
    }


    /**
     * @return the k-factor.
     */
    public String getKFactor() {
        return kFactor;
    }


    /**
     * @return the len.
     */
    public int getLen() {
        return len;
    }


    /**
     * @return the location.
     */
    public String getLocation() {
        return location;
    }


    /**
     * @return true if this segment has longitudinal slots.
     */
    public boolean getLongitudinalSlots() {
        return longitudinalSlots;
    }


    /**
     * @return the power.
     */
    public double getPower() {
        return power;
    }


    /**
     * @return the pti.
     */
    public double getPti() {
        return pti;
    }


    /**
     * @return true if this segment has radial holes.
     */
    public boolean getRadialHoles() {
        return radialHoles;
    }


    /**
     * @return the radius.
     */
    public int getRadius() {
        return radius;
    }


    /**
     * @param newConnection The connection to set.
     */
    public void setConnection(String newConnection) {
        String oldConnection = getConnection();
        connection = newConnection;
        firePropertyChange(PROPERTYNAME_CONNECTION, oldConnection, newConnection);
    }


    /**
     * @param newDa The da to set.
     */
    public void setDa(int newDa) {
        int oldDa = getDa();
        da = newDa;
        firePropertyChange(PROPERTYNAME_DA, oldDa, newDa);
    }


    /**
     * @param newDa2 The da2 to set.
     */
    public void setDa2(int newDa2) {
        int oldDa2 = getDa2();
        da2 = newDa2;
        firePropertyChange(PROPERTYNAME_DA2, oldDa2, newDa2);
    }

    /**
     * @param newDi The di to set.
     */
    public void setDi(int newDi) {
        int oldDi = getDi();
        di = newDi;
        firePropertyChange(PROPERTYNAME_DI, oldDi, newDi);
    }


    /**
     * @param newDi2 The di2 to set.
     */
    public void setDi2(int newDi2) {
        int oldDi2 = getDi2();
        di2 = newDi2;
        firePropertyChange(PROPERTYNAME_DI2, oldDi2, newDi2);
    }


    /**
     * @param newDiameter The diameter to set.
     */
    public void setDiameter(int newDiameter) {
        int oldDiameter = getDiameter();
        diameter = newDiameter;
        firePropertyChange(PROPERTYNAME_DIAMETER, oldDiameter, newDiameter);
    }


    /**
     * @param newIdentifier the identifier to set
     */
    public void setIdentifier(String newIdentifier) {
        String oldIdentifier = getIdentifier();
        identifier = newIdentifier;
        firePropertyChange(PROPERTYNAME_IDENTIFIER, oldIdentifier, newIdentifier);
    }


    /**
     * @param newKFactor The kFactor to set.
     */
    public void setKFactor(String newKFactor) {
        String oldKFactor = getKFactor();
        kFactor = newKFactor;
        firePropertyChange(PROPERTYNAME_K_FACTOR, oldKFactor, newKFactor);
    }


    /**
     * @param newLen The len to set.
     */
    public void setLen(int newLen) {
        int oldLen = getLen();
        len = newLen;
        firePropertyChange(PROPERTYNAME_LEN, oldLen, newLen);
    }


    /**
     * @param newLocation The location to set.
     */
    public void setLocation(String newLocation) {
        String oldLocation = getLocation();
        location = newLocation;
        firePropertyChange(PROPERTYNAME_LOCATION, oldLocation, newLocation);
    }


    /**
     * @param newLongitudinalSlots true if this segment has longitudinal slots.
     */
    public void setLongitudinalSlots(boolean newLongitudinalSlots) {
        boolean oldLongitudinalSlots = getLongitudinalSlots();
        longitudinalSlots = newLongitudinalSlots;
        firePropertyChange(PROPERTYNAME_LONGITUDINAL_SLOTS, oldLongitudinalSlots, newLongitudinalSlots);
    }


    /**
     * @param newPower The power to set.
     */
    public void setPower(double newPower) {
        double oldPower = getPower();
        power = newPower;
        firePropertyChange(PROPERTYNAME_POWER, oldPower, newPower);
    }


    /**
     * @param newPti The pti to set.
     */
    public void setPti(double newPti) {
        double oldPti = getPti();
        pti = newPti;
        firePropertyChange(PROPERTYNAME_PTI, oldPti, newPti);
    }


    /**
     * @param newRadialHoles true if this segment has radial holes.
     */
    public void setRadialHoles(boolean newRadialHoles) {
        boolean oldRadialHoles = getRadialHoles();
        radialHoles = newRadialHoles;
        firePropertyChange(PROPERTYNAME_RADIAL_HOLES, oldRadialHoles, newRadialHoles);
    }


    /**
     * @param newRadius The radius to set.
     */
    public void setRadius(int newRadius) {
        int oldRadius = getRadius();
        radius = newRadius;
        firePropertyChange(PROPERTYNAME_RADIUS, oldRadius, newRadius);
    }


    // Misc *******************************************************************

    /**
     * Returns a string representation for this segment.
     * Currently it prints the class info and identifier.
     *
     * @return a string representation for this segment
     */
    @Override
    public String toString() {
        return super.toString() + ':' + getIdentifier();
    }


}