/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.model.node;

import javax.swing.Icon;

import com.jgoodies.skeleton.domain.Flange;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;

/**
 * This class represents flanges in the navigation tree.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.12 $
 *
 * @see com.jgoodies.skeleton.domain.Flange
 */

public final class FlangeNode extends AbstractTreeNode {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(FlangeNode.class);


    // Instance Creation ******************************************************

    /**
     * Constructs a <code>FlangeNode</code> for the specified parent and
     * flange.
     *
     * @param parent  this node's parent
     * @param flange  the associated model, an instance of Flange
     */
    public FlangeNode(NavigationNode parent, Flange flange) {
        super(parent, flange);
    }


    // Implementing the NavigationNode Interface ******************************

    /**
     * Returns this node's name, the identifier of the associated flange.
     *
     * @return this node's name
     */
    @Override
    public String getName() {
        return getFlange().getIdentifier();
    }


    // ************************************************************************

    /**
     * Returns this node's icon, ignores the selection.
     * The icons is requested from a global resource repository.
     *
     * @return this node's icon.
     */
    @Override
    public Icon getIcon(boolean sel) {
        return RESOURCES.getIcon("flange.icon");
    }


    /**
     * Returns this node's associated Flange instance.
     *
     * @return this node's associated Flange instance.
     * @see NavigationNode#getModel()
     */
    public Flange getFlange() {
        return (Flange) getModel();
    }

}