/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.model.node;


import javax.swing.Icon;

import com.jgoodies.skeleton.domain.Flange;
import com.jgoodies.skeleton.domain.Project;
import com.jgoodies.skeleton.domain.Segment;
import com.jgoodies.skeleton.domain.Shaft;

/**
 * Describes the root node in the Skeleton (Pro) navigation tree.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.9 $
 */

public final class RootNode extends AbstractTreeNode {


    // Instance Creation ******************************************************

    /**
     * Creates a root node for the specified project.
     *
     * @param project    the associated project
     */
    public RootNode(Project project) {
        super(null, project);
        buildNodesFrom(project);
    }


    // Building the Tree ******************************************************

    /**
     * Builds nodes from the specified <code>Project</code>.
     *
     * @param project    the project to build the tree from
     */
    private void buildNodesFrom(Project project) {
        add(new DescriptionNode(this, project.getDescription()));

        for (Object element : project.getShafts()) {
            Shaft shaft = (Shaft) element;
            ShaftNode node = new ShaftNode(this, shaft);
            add(node);

            for (Object component : shaft.getComponents()) {
                if (component instanceof Segment) {
                    node.add(new SegmentNode(node, (Segment) component));
                } else if (component instanceof Flange) {
                    node.add(new FlangeNode(node, (Flange) component));
                } else
                    throw new IllegalStateException("Unknown node type.");

            }
        }
    }


    // ************************************************************************

    /**
     * Returns this node's associated Description instance.
     *
     * @return this node's associated Description instance.
     * @see NavigationNode#getModel()
     */
    public Project getProject() {
        return (Project) getModel();
    }


    /**
     * Returns this node's icon. Since the root node will be hidden
     * by the tree, we can return {@code null}.
     *
     * @return null
     */
    @Override
    public Icon getIcon(boolean sel) {
        return null;
    }


    /**
     * Returns this node's name. Since the root node will be hidden
     * by the tree, we can return {@code null}.
     *
     * @return null
     */
    @Override
    public String getName() {
        return null;
    }


    /**
     * Returns a string representation for this node.
     * Currently it prints the class info and node name.
     *
     * @return a string representation for this node
     */
    @Override
    public String toString() {
        return super.toString() + ':' + getProject().toString();
    }

}