/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.model.node;

import javax.swing.Icon;

import com.jgoodies.skeleton.domain.Segment;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;

/**
 * This class represents segments in the navigation tree.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.12 $
 *
 * @see com.jgoodies.skeleton.domain.Segment
 */

public final class SegmentNode extends AbstractTreeNode {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(SegmentNode.class);



    // Instance Creation ******************************************************

    /**
     * Constructs a <code>SegmentNode</code> for the specified parent and
     * segment.
     *
     * @param parent    this node's parent
     * @param segment   the associated model, an instance of Segment
     */
    public SegmentNode(NavigationNode parent, Segment segment) {
        super(parent, segment);
    }


    // Implementing the NavigationNode Interface ******************************

    /**
     * Returns this node's name, the identifier of the associated segment.
     *
     * @return this node's name
     */
    @Override
    public String getName() {
        return getSegment().getIdentifier();
    }


    // ************************************************************************

    /**
     * Returns this node's icon, ignores the selection.
     * The icons is requested from a global resource repository.
     *
     * @return this node's icon.
     */
    @Override
    public Icon getIcon(boolean sel) {
        return RESOURCES.getIcon("segment.icon");
    }


    /**
     * Returns this node's associated Segment instance.
     *
     * @return this node's associated Segment instance.
     * @see NavigationNode#getModel()
     */
    public Segment getSegment() {
        return (Segment) getModel();
    }

}