/*
 * Copyright (c) 2002-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.skeleton.model.node;

import javax.swing.Icon;

import com.jgoodies.skeleton.domain.Shaft;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;

/**
 * This class represents shafts in the navigation tree.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.12 $
 *
 * @see com.jgoodies.skeleton.domain.Shaft
 */

public final class ShaftNode extends AbstractTreeNode {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(ShaftNode.class);


    // Instance Creation ******************************************************

    /**
     * Constructs a <code>ShaftNode</code> for the given parent and shaft.
     *
     * @param parent  this node's parent
     * @param shaft   the associated model, an instance of Shaft
     */
    public ShaftNode(NavigationNode parent, Shaft shaft) {
        super(parent, shaft);
    }


    // Implementing the NavigationNode Interface ******************************

    /**
     * Returns this node's name, the identifier of the associated shaft.
     *
     * @return this node's name
     */
    @Override
    public String getName() {
        return getShaft().getIdentifier();
    }


    // ************************************************************************

    /**
     * Returns this node's icon, ignores the selection.
     * The icons is requested from a global resource repository.
     *
     * @return this node's icon.
     */
    @Override
    public Icon getIcon(boolean sel) {
        return RESOURCES.getIcon("shaft.icon");
    }


    /**
     * Returns this node's associated Shaft instance.
     *
     * @return this node's associated Shaft instance.
     * @see NavigationNode#getModel()
     */
    public Shaft getShaft() {
        return (Shaft) getModel();
    }

}