/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.Image;

import javax.swing.ActionMap;
import javax.swing.JOptionPane;
import javax.swing.UIManager;
import javax.swing.plaf.DimensionUIResource;

import com.jgoodies.forms.layout.LayoutMap;
import com.jgoodies.looks.Options;
import com.jgoodies.uif.AbstractFrame;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.osx.OSXApplicationMenu;
import com.jgoodies.uif.splash.ImageSplash;
import com.jgoodies.uif.splash.Splash;
import com.jgoodies.uifextras.convenience.DefaultUIFApplication;
import com.jgoodies.uifextras.convenience.ResourceIDs;
import com.jgoodies.validation.demo.domain.ExampleFactory;
import com.jgoodies.validation.demo.model.MainModel;
import com.jgoodies.validation.demo.view.MainFrame;

/**
 * This is the main class of the JGoodies Validation Demo.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.31 $
 */
public final class ValidationDemo extends DefaultUIFApplication {


    public static void main(String[] arguments) {
        OSXApplicationMenu.setAboutName("Validation Demo");
        Application.launch(ValidationDemo.class, arguments);
    }


	/**
	 * Configures the splash to set a blue progress bar.
	 */
	@Override
    protected void configureSplash() {
		Image image = getAppResourceMap().getImage(ResourceIDs.SPLASH_IMAGE);
		ImageSplash splash = new ImageSplash(new Frame(), image, "", false);
		Splash.setProvider(splash);
        splash.setProgressBarBounds(56);
		splash.setForeground(new Color(64, 64, 64));
		splash.setBackground(Color.WHITE);
	}


	/**
	 * Configures the user interface.
	 */
	@Override
    protected void configureUI() {
		Options.setDefaultIconSize(new Dimension(18, 18));
		UIManager.put("ToolBar.separatorSize",	new DimensionUIResource(6, 18));
		LayoutMap.getRoot().columnPut("label", "[65dlu,pref]");
		super.configureUI();
	}



	/**
	 * Creates and returns the application's main frame.
	 */
	@Override
    protected AbstractFrame createMainFrame() {
		return new MainFrame(MainModel.INSTANCE);
	}


	/**
	 * Initializes the actions used in this demo.
	 */
    @Override
    protected void initializeActions() {
        ActionMap map = Application.getActionMap(MainModel.INSTANCE);
        OSXApplicationMenu.register(
                map.get(MainModel.ACTION_OPEN_ABOUT_DIALOG),
                map.get(MainModel.ACTION_OPEN_PREFERENCES),
                map.get(MainModel.ACTION_EXIT));
    }


	/**
	 * Brings up the application, it therefore initializes the main frame,
	 * checks the setup process, initializes all actions, then builds
	 * the main frame, and finally opens it.
	 */
	@Override
    protected void launchApplication() {
        addMessageHandler();

        Splash.setNote("Preparing Examples", 30);
        // Set the example list and preselect the first example.
        MainModel.INSTANCE.getExamplesModel().setList(ExampleFactory.createExampleList());
        MainModel.INSTANCE.getExamplesModel().setSelectionIndex(0);

        Splash.setNote("Creating Main Frame", 40);
        AbstractFrame mainFrame = createMainFrame();
        JOptionPane.setRootFrame(mainFrame);

        Splash.setNote("Initializing Actions\u2026", 50);
        initializeActions();

        checkSetup();

        Splash.setNote("Building Main Frame\u2026", 60);
        mainFrame.build();

        Splash.setNote("Finishing\u2026", 95);

        mainFrame.open();
	}


}
