/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo.domain;

import java.util.ArrayList;
import java.util.List;

import com.jgoodies.validation.tutorial.basics.*;
import com.jgoodies.validation.tutorial.formatted.DateExample;
import com.jgoodies.validation.tutorial.formatted.FocusLostBehaviorExample;
import com.jgoodies.validation.tutorial.formatted.NumberExample;
import com.jgoodies.validation.tutorial.performance.PerformanceExample;

/**
 * Creates the list of examples that is used in the Examples bar.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.9 $
 */

public final class ExampleFactory {

    private ExampleFactory() {
        // Override the default constructor; prevents instantiability.
    }

    // Public API ***********************************************************

    /**
     * Creates sample instances. These instance are made persistent to be
     * accessible through the object brokers.
     */
    public static List<Example> createExampleList() {
        List<Example> examples = new ArrayList<Example>();


        // Basics -------------------------------------------------------------

        examples.add(
            new Example(
                "Basics - Validation Time",
                "Demonstrates different validation times: " +
                " key typed, focus lost, commit (OK pressed).\n\n" +
                "Type, change the focus, or press OK to experiment.",
                new ValidationTimeExample()));


        examples.add(
            new Example(
                "Basics - Validation Result View",
                "Demonstrates the different validation result views " +
                "created and returned by the ValidationResultViewFactory.\n\n" +
                "Click the buttons to test different validation results.",
                new ValidationResultViewExample()));


        examples.add(
            new Example(
                "Basics - Mandatory Marker",
                "Demonstrates different styles how to mark mandatory fields.\n\n" +
                "The fields in this demo are not bound and not validated.",
                new MandatoryMarkerExample()));


        examples.add(
            new Example(
                "Basics - Component Feedback",
                "Demonstrates different styles how to indicate that a component " +
                "contains invalid data: " +
                "background changes if empty, " +
                "background reflects the severity, " +
                "icons show the severity.\n\n" +
                "The state changes as you type.",
                new ComponentFeedbackExample()));


        examples.add(
                new Example(
                    "Basics - Validation Message Keys",
                    "Demonstrates the n-to-m relation between messages and components. " +
                    "Each message has a key, and each component has 0..n keys. " +
                    "A component can have no, one, or more messages;" +
                    "a message can be associated with no, one, or more components.\n\n" +
                    "You can see a component's messages by moving the mouse over " +
                    "the small overlay icon.",
                    new ValidationMessageKeysExample()));


        examples.add(
                new Example(
                    "Basics - Hints on Focus",
                    "The focused components provides a hint for valid data.",
                    new InfoOnFocusExample()));


//        examples.add(
//                new Example(
//                    "Feedback - Subvalidation",
//                    "Validation is splitted and is and can be displayed collapsed or expanded.",
//                    new ValidationResultContainerExample()));


        // How to work with formatted input?

        examples.add(
                new Example(
                    "Formatted - Number",
                    "Demonstrates the JFormattedTextField editing numbers. " +
                    "Shows how to use a custom Format, a custom Formatter, " +
                    "a custom FormatterFactory, how to map empty strings to null " +
                    "or a special value (-1), and how to set the value's class.",
                    new NumberExample()));

        examples.add(
                new Example(
                    "Formatted - Date",
                    "Demonstrates the JFormattedTextField editing dates. " +
                    "Shows how to use a custom Format, a custom Formatter, " +
                    "a custom FormatterFactory, how to map empty strings to null, " +
                    "or Today, and how to enter a date specifying a day offset.",
                    new DateExample()));

        examples.add(
                new Example(
                    "Formatted - Focus Lost Behavior",
                    "Demonstrates the JFormattedTextField focus lost behavior " +
                    "on Integers (default is 'Commit or Revert'). " +
                    "The 3rd field locks down focus while the text is invalid." +
                    "\n\nTo test the modes enter valid and invalid data, change focus and " +
                    "observe the text, editValid and value.",
                    new FocusLostBehaviorExample()));


        examples.add(
                new Example(
                    "Performance",
                    "Demonstrates approaches to improving validation performance. " +
                    "Simulates a back-end validation that costs 1 second. " +
                    "Valid values are: 12345, 23456, 34567, 45678, 56789. " +
                    "\nDelay validates after 250ms, " +
                    "Background uses a Worker thread, " +
                    "Pre-Validation checks the length on the client, " +
                    "Cache stores back-end validations.",
                    new PerformanceExample()));


        return examples;
    }

}
