/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo.model;

import java.awt.Frame;
import java.awt.event.ActionEvent;

import com.jgoodies.binding.list.SelectionInList;
import com.jgoodies.uif.application.Action;
import com.jgoodies.uif.application.ApplicationContext;
import com.jgoodies.uif.util.WindowUtils;
import com.jgoodies.uifextras.convenience.DefaultAboutDialog;
import com.jgoodies.uifextras.help.HelpBroker;
import com.jgoodies.validation.demo.domain.Example;
import com.jgoodies.validation.demo.view.PreferencesDialog;

/**
 * Provides the models and Actions required to build the
 * {@link com.jgoodies.validation.demo.view.MainFrame}, its menu bar and subviews.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.17 $
 */
public final class MainModel {

    // Action Resource Keys ***************************************************

    public static final String ACTION_OPEN_PREFERENCES    = "openPreferences";
    public static final String ACTION_EXIT                = "exit";
    public static final String ACTION_OPEN_HELP_CONTENTS  = "openHelpContents";
    public static final String ACTION_OPEN_ABOUT_DIALOG   = "openAboutDialog";


    // Other Public Static Fields *********************************************

    /**
     * This model's sole instance.
     */
    public static final MainModel INSTANCE =
        new MainModel();

    /**
     * Holds the available examples and the currently selected example.
     */
    private final SelectionInList<Example> examplesModel
        = new SelectionInList<Example>();


    // Instance Creation ******************************************************

    private MainModel() {
        // Overrides default constructor.
    }


    // Accessing Models *******************************************************

    /**
     * Returns the examples model, a selection in a list.
     */
    public SelectionInList<Example> getExamplesModel() {
        return examplesModel;
    }


    // Action Operations ******************************************************

    @Action
    public void openPreferences(ActionEvent e) {
        new PreferencesDialog((Frame) WindowUtils.getParent(e)).open();
    }


    @Action
    public void exit(ActionEvent e) {
        ApplicationContext.getInstance().getApplication().exit(e);
    }


    @Action
    public void openHelpContents(ActionEvent e) {
        HelpBroker.openDefault();
    }


    @Action
    public void openAboutDialog(ActionEvent e) {
        new DefaultAboutDialog((Frame) WindowUtils.getParent(e)).open();
    }


}
