/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo.view;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.lang.reflect.Method;

import javax.swing.JComponent;
import javax.swing.JPanel;

import com.jgoodies.binding.value.ValueModel;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.panel.SimpleInternalFrame;
import com.jgoodies.validation.demo.domain.Example;

/**
 * The validation demo's editor panel.
 *
 * @author Karsten Lentzsch
 */

final class EditorView extends AbstractView {

    private static final JPanel EMPTY_PANEL = new JPanel(null);

    private final ValueModel exampleModel;

    // Instance Creation ****************************************************

    /**
     * Constructs the <code>EditorView</code>.
     */
    EditorView(ValueModel exampleModel) {
        this.exampleModel = exampleModel;
    }

    private void initEventHandling() {
        exampleModel.addValueChangeListener(new ExampleChangeHandler());
    }

    @Override
    protected JComponent buildPanel() {
        initEventHandling();

        SimpleInternalFrame panel = new SimpleInternalFrame(null, "Editor");
        setExampleContent(panel, (Example) exampleModel.getValue());
        return panel;
    }


    // Helper Code **********************************************************

    private JComponent buildExamplePanel(Example example) {
        Object builder = example.getBuilder();
        String methodName = example.getBuildMethodName();

        try {
            Class<?> clazz = builder.getClass();
            Method method  = clazz.getMethod(methodName, (Class[]) null);
            return (JComponent) method.invoke(builder, (Object[]) null);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return EMPTY_PANEL;

    }

    private void setExampleContent(SimpleInternalFrame panel, Example example) {
        JComponent content = example == null
            ? EMPTY_PANEL
            : buildExamplePanel(example);
        panel.setContent(content);
        panel.revalidate();
        panel.repaint();
    }


    /**
     * Updates this view whenever the selected example has changed.
     */
    private final class ExampleChangeHandler implements PropertyChangeListener {

        public void propertyChange(PropertyChangeEvent e) {
            setExampleContent(
                    (SimpleInternalFrame) getPanel(),
                    (Example) e.getNewValue());
        }
    }

}