/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo.view;

import java.awt.Component;
import java.awt.Dimension;

import javax.swing.DefaultListCellRenderer;
import javax.swing.JComponent;
import javax.swing.JList;

import com.jgoodies.binding.adapter.BasicComponentFactory;
import com.jgoodies.binding.list.SelectionInList;
import com.jgoodies.looks.LookUtils;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.panel.SimpleInternalFrame;
import com.jgoodies.uifextras.util.UIFactory;
import com.jgoodies.validation.demo.domain.Example;

/**
 * Provides the navigator view using a <code>SimpleInternalFrame</code>.
 * The contents is a scrollable list of {@link Example}s.
 *
 * @author Karsten Lentzsch
 */
final class ExamplesView extends AbstractView {

    /**
     * This view's presentation model: the list of examples with selection.
     */
    private final SelectionInList<Example> examplesModel;

    private JList examplesList;


    // Instance Creation ****************************************************

    /**
     * Constructs the examples view and stores its simple presentation model
     * that just consists of the example list with selection.
     */
    ExamplesView(SelectionInList<Example> examplesModel) {
        this.examplesModel = examplesModel;
    }


    // Building *************************************************************

    /**
     * Creates, configures and binds the UI components.
     */
    private void initComponents() {
        examplesList = BasicComponentFactory.createList(
                examplesModel, new TopicsListCellRenderer());
    }

    /**
     * Builds and returns the panel content.
     */
    @Override
    protected JComponent buildPanel() {
        initComponents();

        SimpleInternalFrame panel = new SimpleInternalFrame(null, "Examples");
        panel.setContent(UIFactory.createStrippedScrollPane(examplesList));
        panel.setMinimumSize(getMinimumSize());
        return panel;
    }


    private Dimension getMinimumSize() {
        return LookUtils.IS_LOW_RESOLUTION
            ? new Dimension(160, 200)
            : new Dimension(180, 230);
    }


    // Helper Classes *******************************************************

    /**
     * A ListCellRenderer implementation that renders labels
     * for the <code>Examples</code>.
     */
    private static class TopicsListCellRenderer
        extends DefaultListCellRenderer {

        @Override
        public Component getListCellRendererComponent(
            JList list,
            Object value,
            int index,
            boolean isSelected,
            boolean cellHasFocus) {
            super.getListCellRendererComponent(
                list,
                value,
                index,
                isSelected,
                cellHasFocus);
            Example topic = (Example) value;
            this.setText(" " + topic.getName());
            return this;
        }
    }

}
