/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo.view;

import java.awt.Dimension;

import javax.swing.JComponent;

import com.jgoodies.uif.AbstractFrame;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ApplicationContext;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.validation.demo.model.MainModel;

/**
 * The main frame of the JGoodies Validation Demo.
 * It eagerly creates the menus, menu bar, tool bar and all pages.
 *
 * @author Karsten Lentzsch
 */

public final class MainFrame extends AbstractFrame {

    private static final Dimension MINIMUM_SIZE = new Dimension(525, 425);

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(MainFrame.class);

    private final MainModel model;

    private MainPageView mainPageView;


    // Instance Creation ****************************************************

    /**
     * Constructs the application's main frame.
     */
    public MainFrame(MainModel model) {
        super(RESOURCES.getString("application.title"));
        setName("main");
        this.model = model;
    }


    // Overriding Default Behavior ******************************************

    /**
     * Builds the frame's content pane, packs it, locates it on the screen,
     * sets the icon, restores the saved state, and registers listeners.
     * It then is ready to be opened.<p>
     *
     * In addition to the superclass behavior, we set the backed menu bar.
     */
    @Override
    public void build() {
        super.build();
        setJMenuBar(new MenuBarView(model).getMenuBar());
    }


    // Building *************************************************************

    /**
     * Creates and configures the main menu view and the main page view.
     */
    private void initComponents() {
        mainPageView = new MainPageView(model);
    }

    /**
     * Builds and returns the content pane.
     */
    @Override
    protected JComponent buildContentPane() {
        initComponents();

        return mainPageView.getPanel();
    }


    // Implementing Abstract Behavior ****************************************

    /**
     * Returns the frame's minimum size. It is used by the WindowUtils
     * to resize the window if the user has shrinked the window below
     * this given size.
     *
     * @return the frame's minimum size
     */
    public Dimension getWindowMinimumSize() {
        return MINIMUM_SIZE;
    }


    @Override
    protected void configureCloseOperation() {
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(
                ApplicationContext.getInstance().getApplication().getApplicationExitOnWindowClosingHandler());
    }


}