/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo.view;

import java.awt.Dimension;

import javax.swing.JComponent;

import com.jgoodies.binding.list.SelectionInList;
import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.looks.LookUtils;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.util.SystemUtils;
import com.jgoodies.validation.demo.domain.Example;
import com.jgoodies.validation.demo.model.MainModel;

/**
 * Builds the main page that consists of subpanels for the navigation,
 * description and layout.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.10 $
 */
final class MainPageView extends AbstractView {

    private final SelectionInList<Example> exampleModel;

    private ExamplesView    examplesView;
    private DescriptionView descriptionView;
    private EditorView      editorView;


    MainPageView(MainModel model) {
        this.exampleModel = model.getExamplesModel();
    }


    // Building *************************************************************

    private void initComponents() {
        examplesView    = new ExamplesView(exampleModel);
        descriptionView = new DescriptionView(exampleModel.getSelectionHolder());
        editorView      = new EditorView(exampleModel.getSelectionHolder());
    }


    /**
     * Initializes components, then builds and returns this view's panel.
     * The panel has the navigation on the left side and description and
     * sample layout stacked on the right-hand side.
     *
     * @return this view's panel
     */
    @Override
    protected JComponent buildPanel() {
        initComponents();

        FormLayout layout = new FormLayout(
                "fill:pref,  4dlu, fill:100dlu:grow",
                "fill:75dlu, 5dlu, fill:50dlu:grow");

        PanelBuilder builder = new PanelBuilder(layout);
        builder.setBorder(Borders.createEmptyBorder(
        		SystemUtils.IS_OS_MAC
				    ? "6dlu, 5dlu, 9dlu, 5dlu"  // honor the Mac intrusion box
					: "6dlu, 4dlu, 6dlu, 5dlu"));

        CellConstraints cc = new CellConstraints();

        builder.add(examplesView.getPanel(),    cc.xywh(1, 1, 1, 3));
        builder.add(descriptionView.getPanel(), cc.xy  (3, 1));
        builder.add(editorView.getPanel(),      cc.xy  (3, 3));

        builder.getPanel().setPreferredSize(getPreferredSize());
        return builder.getPanel();
    }


    private Dimension getPreferredSize() {
        return LookUtils.IS_LOW_RESOLUTION
                ? new Dimension(640, 540)
                : new Dimension(700, 580);
    }


}
