/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.validation.demo.view;

import java.awt.BorderLayout;
import java.awt.Frame;

import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JTabbedPane;

import com.jgoodies.uif.AbstractDialog;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.uif.util.Resizer;
import com.jgoodies.uifextras.convenience.ResourceIDs;
import com.jgoodies.uifextras.laf.LafChoiceModel;
import com.jgoodies.uifextras.laf.LafChoiceView;
import com.jgoodies.uifextras.panel.HeaderPanel;

/**
 * Provides the preferences dialog.
 *
 * @author Karsten Lentzsch
 */
public final class PreferencesDialog extends AbstractDialog {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(PreferencesDialog.class);


    public PreferencesDialog(Frame owner) {
        super(owner);
    }


    // Building *************************************************************

    /**
     * Builds and returns the dialog's header panel.
     */
    @Override
    protected JComponent buildHeader() {
        return new HeaderPanel(
            "Preferences",
            "You can see and edit the tool's persistent preferences."
                + "\nClick on a tab to select a different category.",
            RESOURCES.getIcon(ResourceIDs.PREFERENCES_ICON));
    }

    /**
     * Builds and returns the preference dialog's content panel.
     */
    @Override
    protected JComponent buildContent() {
        JPanel content = new JPanel(new BorderLayout());
        content.add(buildTabbedPane(),            BorderLayout.CENTER);
        content.add(buildButtonBarWithOKCancel(), BorderLayout.SOUTH);
        return content;
    }

    /**
     * Builds and returns the tabbed pane.
     */
    private JTabbedPane buildTabbedPane() {
        LafChoiceView lafChoiceView = new LafChoiceView(new LafChoiceModel(getTriggerChannel()));

        JTabbedPane pane = new JTabbedPane();
        pane.addTab("Look & Feel", lafChoiceView.getPanel());
        return pane;
    }


    // Misc *****************************************************************************

    @Override
    protected void doCloseWindow() {
        doCancel();
    }

    @Override
    protected void resizeHook(JComponent component) {
        Resizer.ONE2ONE.resizeDialogContent(component);
    }

}
