/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of JGoodies Karsten Lentzsch nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jgoodies.validation.tutorial.performance;

import com.jgoodies.binding.beans.Model;


/**
 * Describes a container with container number and label.
 * Provides the following bound properties:
 * <em>containerNo, label</em>.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.5 $
 */
public class Container extends Model {

    // Names of the Bound Bean Properties *************************************

    public static final String PROPERTYNAME_CONTAINER_NO  = "containerNo";
    public static final String PROPERTYNAME_LABEL         = "label";


    // Instance Fields ********************************************************

    /**
     * Holds a number that identifies the container.
     *
     * @see #getContainerNo()
     * @see #setContainerNo(String)
     *
     * validation-constraints:
     *     mandatory
     *     min-length: 5
     *     max-length: 5
     *     numeric
     */
    private String containerNo;

    /**
     * Holds this container's label.
     *
     * @see #getLabel()
     */
    private String label;



    // Instance Creation ******************************************************

    /**
     * Constructs an empty <code>Container</code>.
     */
    public Container() {
        containerNo = "";
        label = "";
    }


    // Access to Bound Properties *********************************************

    /**
     * Returns this container's unique id.
     *
     * @return this container's no, a system wide unique id
     *
     * @see #setContainerNo(String)
     */
    public String getContainerNo() {
        return containerNo;
    }

    /**
     * Sets a new unique container number.
     *
     * @param newContainerNo the container number to be set
     *
     * @see #getContainerNo()
     */
    public void setContainerNo(String newContainerNo) {
        String oldValue = getContainerNo();
        containerNo = newContainerNo;
        firePropertyChange(PROPERTYNAME_CONTAINER_NO, oldValue, newContainerNo);
    }


    /**
     * Returns this container's label.
     *
     * @return the container date
     *
     * @see #setLabel(String)
     */
    public String getLabel() {
        return label;
    }

    /**
     * Sets this container's label.
     *
     * @param newLabel  the label to set
     *
     * @see #getLabel()
     */
    public void setLabel(String newLabel) {
        String oldLabel = getLabel();
        label = newLabel;
        firePropertyChange(PROPERTYNAME_LABEL, oldLabel, newLabel);
    }


}
