/*
 * Copyright (c) 2006-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.application;

import java.lang.annotation.*;

/**
 * A method annotation to specify Action method bodies
 * with their name, and initial enablement.
 * Actions can be requested using {@code Application.getActionMap(Object)}
 * that returns an ActionMap that in turn maps action names to Actions.<p>
 *
 * Methods annotated with this Annotation can have two signatures:
 * with or without an ActionEvent parameter. E.g.<pre>
 * &#x40;Action
 * public void doOK(ActionEvent e) {
 *     // Do something; may use the action event, for example when
 *     // opening a dialog to request the event sources root windows
 * }
 *
 * &#x40;Action
 * public void doCancel() {
 *     // Do something. Has no action event available.
 * }
 * </pre>
 *
 * By default the action name is the method name. This can be changed
 * by setting the optional annotation value <code>name</code>, e.g.<pre>
 * &#x40;Action(name="saveInvoice")
 * public void save() {
 *     // Saves the invoice
 * }
 * </pre>
 *
 * The action's initial enablement can be set with an option.
 * Actions are enabled by default.<pre>
 * &#x40;Action(enabled=false)
 * public void openSelectedItem(ActionEvent e) {
 *     // Should be enabled if and only if there's a selection.
 * }
 * </pre>
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.3 $
 *
 * @see ApplicationContext#getActionMap(Object)
 * @see javax.swing.Action
 * @see javax.swing.ActionMap
 */
@Documented
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
public @interface Action {

    String  name()    default "";
    boolean enabled() default true;

}
