/*
 * Copyright (c) 2006-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.application;

import java.util.EventListener;
import java.util.EventObject;


/**
 * Describes listeners that hook into the application shutdown process.
 * Implementors can veto against an application shutdown, for example
 * if there are unsaved documents. And implementors can perform operations
 * on application shutdown, for example persist data.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.5 $
 *
 * @see Application#exit(EventObject)
 * @see Application#addExitListener(ExitListener)
 * @see Application#removeExitListener(ExitListener)
 *
 * @since 1.8
 */
public interface ExitListener extends EventListener {

    /**
     * Checks and answers whether the application may exit or not.
     * Useful to veto against the application exit.
     * The given event has a source which can be used to determine
     * where to open dialogs in case you veto against a shutdown.
     *
     * @param event    the event that caused the application to exit
     * @return true if this listener does not veto against the exit,
     *    false if it vetoes
     */
    boolean applicationExitAllowed(EventObject event);


    /**
     * Invoked if the application is exiting.
     */
    void applicationExiting();


}
