/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.component;

import java.awt.Font;

import javax.swing.JList;
import javax.swing.JTree;
import javax.swing.tree.TreeModel;
import javax.swing.tree.TreeNode;
import javax.swing.tree.TreePath;

import com.jgoodies.uif.util.Modes;

/**
 * A <code>JTree</code> subclass that adds support for a bold font
 * and an improvement for the Mac OS X.<p>
 *
 * TODO: Consider moving the support for the bold font to a
 * TreeCellRenderer subclass that holds and updates a bold version
 * of the tree's font. Such a renderer can cache the bold font
 * and shall update it whenever the tree's font instance changes.
 * (Typically after an #updateUI).
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.4 $
 *
 * @see com.jgoodies.uif.util.TreeUtils
 */
public class UIFTree extends JTree {

    /**
     * Holds a bold version of the tree's default font.
     * Refreshed everytime the UI delegate is updated.
     *
     * @see #updateUI()
     */
    private Font boldFont;


    // Instance Creation *****************************************************

    /**
     * Constructs a <code>UIFTree</code> on a sample <code>TreeModel</code>.
     */
    public UIFTree() {
        // Just provide an empty constructor for subclassing.
    }

    /**
     * Constructs a <code>UIFTree</code> for the given <code>TreeModel</code>.
     *
     * @param model   the TreeModel to be used
     */
    public UIFTree(TreeModel model) {
        super(model);
    }

    /**
     * Constructs a <code>UIFTree</code> for the given <code>TreeNode</code>.
     *
     * @param root   the root node used to build a TreeModel
     */
    public UIFTree(TreeNode root) {
        super(root);
    }



    // Creating and Accessing the Bold Font *********************************

    /**
     * Returns the bold font.
     *
     * @return this tree's bold font
     */
    public Font getBoldFont() {
        return boldFont;
    }

    /**
     * Updates the UI and resets the bold font.
     */
    @Override
    public void updateUI() {
        TreePath path = getSelectionPath();
        super.updateUI();
        setSelectionPath(path);

        // TODO: Check whether this is still required for the 1.4.2 final
        if (Modes.isLafAqua()) {
        	setFont(new JList().getFont());
        }
        boldFont = getFont().deriveFont(Font.BOLD);
    }


}