/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.laf;

import com.jgoodies.looks.Options;

/**
 * Provides predefined LookChoiceStrategy implementations.
 * The available behavior is:
 *
 * <table>
 * <tr>
 *      <td>&nbsp</td>
 *      <td colspan="4"><b>Strategy</b></td>
 * </tr>
 * <tr>
 *      <td><b>OS</b></td>
 *      <td>FIXED_3D</td>
 *      <td>FIXED_XP</td>
 *      <td>SYSTEM</td>
 * </tr>
 * <tr>
 *      <td>Windows</td>
 *      <td>Plastic3D</td>
 *      <td>PlasticXP</td>
 *      <td>JGoodies Windows</td>
 * </tr>
 * <tr>
 *      <td>Mac OS X</td>
 *      <td>Plastic3D</td>
 *      <td>PlasticXP</td>
 *      <td>Aqua</td>
 * </tr>
 * <tr>
 *      <td>Other</td>
 *      <td>Plastic3D</td>
 *      <td>PlasticXP</td>
 *      <td>PlasticXP</td>
 * </tr>
 * </table>
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.6 $
 *
 * @see     LookChoiceStrategy
 */

public final class LookChoiceStrategies {


    // Convenience Strategies for Choosing a Look ***************************

    /**
     * A strategy that always chooses the system look.
     */
    public static final LookChoiceStrategy SYSTEM   = new SystemStrategy();

    /**
     * A strategy that always chooses the Plastic3D look.
     */
    public static final LookChoiceStrategy FIXED_3D = new Fixed3DStrategy();

    /**
     * A strategy that always chooses the PlasticXP look.
     */
    public static final LookChoiceStrategy FIXED_XP = new FixedXPStrategy();


	private LookChoiceStrategies() {
        // Override default constructor; prevents instantation.
    }


    // LookChoiceStrategy Convenience Implementations ***********************

    /**
     * Chooses the cross-platform Plastic3D look.
     */
    private static class Fixed3DStrategy implements LookChoiceStrategy {

        public String getDefaultLookClassName() {
            return Options.PLASTIC3D_NAME;
        }
    }


    /**
     * Chooses the cross-platform PlasticXP look.
     */
    private static class FixedXPStrategy implements LookChoiceStrategy {

        public String getDefaultLookClassName() {
            return Options.PLASTICXP_NAME;
        }
    }


    /**
     * Chooses the system look.
     */
    private static class SystemStrategy implements LookChoiceStrategy {

        public String getDefaultLookClassName() {
            return Options.getSystemLookAndFeelClassName();
        }
    }


}