/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.splash;

import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * A {@link SplashProvider} implementation that logs progress and splash
 * messages to a <code>Logger</code>.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 *
 * @see Splash
 */

public final class LogSplash implements SplashProvider {

    private final Logger logger;
    private final Level  logLevel;


    /**
     * Constructs a <code>LogSplash</code> with a default <code>Logger</code>
     * logging on the <code>INFO</code> level.
     */
    public LogSplash() {
        this(Logger.getLogger("LogSplash"), Level.INFO);
    }


    /**
     * Constructs a <code>LogSplash</code> for the specified
     * <code>Logger</code> and <code>Level</code>.
     *
     * @param logger    the Logger used to log splash events
     * @param logLevel  the log level used to log the splash events
     */
    public LogSplash(Logger logger, Level logLevel) {
        this.logger = logger;
        this.logLevel = logLevel;
    }


    /**
     * Implements the open splash behavior; does nothing.
     */
    public void openSplash() {
        // Implements Splash; do nothing
    }


    /**
     * Implements the close splash behavior; does nothing.
     */
    public void closeSplash() {
        // Implements Splash; do nothing
    }


    /**
     * Logs the given splash progress.
     *
     * @param percent   the new progress in percent
     */
    public void setProgress(int percent) {
        logger.log(logLevel, Splash.elapsedTime() + " " + percent + "%");
    }


    /**
     * Logs the given splash message.
     *
     * @param message   the log message to be presented
     */
    public void setNote(String message) {
        logger.log(logLevel, Splash.elapsedTime() + " " + message);
    }
}