/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.splash;

/**
 * An interface that describes splash providers as used by the
 * {@link Splash} class. A typical implementation will open a window that
 * displays the progress messages and progress percent and will close and
 * dispose the window on <code>#closeSplash()</code>.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 *
 * @see	Splash
 */

public interface SplashProvider {


    /**
     * Indicates that the splash shall be opened.
     */
    void openSplash();


    /**
     * Indicates that the splash shall be closed.
     */
    void closeSplash();


    /**
     * Sets the splash text message.
     *
     * @param message   the message to be displayed
     */
    void setNote(String message);


    /**
     * Sets the splash progress.
     *
     * @param percent   the current progress in percent
     */
    void setProgress(int percent);

}