/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.util;

import java.awt.Component;
import java.awt.Container;
import java.awt.Frame;
import java.awt.Window;
import java.util.logging.Logger;

import javax.swing.JComponent;
import javax.swing.JMenu;
import javax.swing.JScrollPane;

/**
 * Consists only of static methods for operations on the Swing component tree.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.5 $
 *
 * @see javax.swing.SwingUtilities
 */
public final class ComponentTreeUtils {

    private ComponentTreeUtils() {
        // Overrides default constructor; prevents instantiation.
    }

	/**
	 * Updates all UIs of all frames and their owned windows.
	 */
	public static void updateAllUIs() {
        Logger.getLogger(ComponentTreeUtils.class.getName()).info("Updating all UIs.");

		// Tell all Frames to update their component UIs.
		Frame[] frames = Frame.getFrames();
		for (Frame element : frames) {
			updateComponentTreeUI(element);
            Window[] windows = element.getOwnedWindows();
            for (Window element2 : windows) {
                updateComponentTreeUI(element2);
            }
		}
	}


   /**
     * A simple minded look and feel change: ask each node in the tree
     * to updateUI() -- that is, to initialize its UI property with the
     * current look and feel.
     * Unlike SwingUtilities, we update a <code>JToolBar's</code> childs
     * <em>before</em> updating the toolbar.
     * Note, that the JScrollPane requires to be updated before its JTable
     * child (re-)configuresScrollPane.<p>
     *
     * TODO: Check if this workaround is still necessary in Java 5 or later.
     *
     * @param c   the root of the component tree to update
     */
    public static void updateComponentTreeUI(Component c) {
        updateComponentTreeUI0(c);
        c.invalidate();
        c.validate();
        c.repaint();
    }


    /**
     * TODO: Probably this method shall be removed in a UIF version
     * that requires Java 5 or later.
     */
    private static void updateComponentTreeUI0(Component c) {
        if (c instanceof JScrollPane) {
            ((JComponent) c).updateUI();
        }

        Component[] children = null;
        if (c instanceof JMenu) {
            children = ((JMenu) c).getMenuComponents();
        } else if (c instanceof Container) {
            children = ((Container) c).getComponents();
        }
        if (children != null) {
            for (Component element : children) {
                updateComponentTreeUI0(element);
            }
        }

        if (c instanceof JComponent && !(c instanceof JScrollPane)) {
            ((JComponent) c).updateUI();
        }

    }


}