/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.util;

import java.awt.event.KeyEvent;

import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.KeyStroke;


/**
 * Consists only of static convenience methods around components.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.4 $
 * @since 1.4
 */
public final class ComponentUtils {


	private ComponentUtils() {
		// Suppresses default constructor, ensuring non-instantiability.
	}


	/**
	 * Adds the given action to the input map of the given component
     * for the given key stroke. The key used to register the action
     * is the Action object itself.
     *
	 * @param component  the component that shall hold the action
	 * @param action     the action to add
	 * @param keyStroke  the key stroke that initiates the action
	 */
	public static void addAction(
            JComponent component,
            Action action,
			KeyStroke keyStroke) {
        addAction(component, action, keyStroke, JComponent.WHEN_FOCUSED);
	}


    /**
     * Adds the given action to the input map of the given component
     * for the given key stroke. The key used to register the action
     * is the Action object itself.
     *
     * @param component  the component that shall hold the action
     * @param action     the action to add
     * @param keyStroke  the key stroke that initiates the action
     * @param condition one of JComponent.WHEN_IN_FOCUSED_WINDOW,
     *     WHEN_FOCUSED, WHEN_ANCESTOR_OF_FOCUSED_COMPONENT
     */
    public static void addAction(
            JComponent component,
            Action action,
            KeyStroke keyStroke,
            int condition) {
        Object command = action;
        component.getInputMap(condition).put(keyStroke, command);
        component.getActionMap().put(command, action);
    }


	/**
	 * Adds the given action to the input map of the given component as a action
	 * on pressing the ENTER key.
	 *
	 * @param component  the component that shall hold the action
	 * @param action     the action to add
	 */
	public static void addEnterAction(JComponent component, Action action) {
		addAction(component,
                  action,
                  KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0));
	}


    /**
     * Removes the given action from the input map of the given component
     * for the given key stroke. The key used to register the action
     * is the Action object itself.
     *
     * @param component  the component that shall hold the action
     * @param action     the action to add
     * @param keyStroke  the key stroke that initiates the action
     * @param condition one of JComponent.WHEN_IN_FOCUSED_WINDOW,
     *     WHEN_FOCUSED, WHEN_ANCESTOR_OF_FOCUSED_COMPONENT
     */
    public static void removeAction(
            JComponent component,
            Action action,
            KeyStroke keyStroke,
            int condition) {
        Object actionMapKey = action;
        component.getInputMap(condition).put(keyStroke, actionMapKey);
        component.getActionMap().put(actionMapKey, action);
    }


}

