/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uif.util;

import java.awt.Component;
import java.awt.Dimension;
import java.awt.Graphics;

import javax.swing.Icon;

/**
 * An implementation of the <code>Icon</code> interface
 * that has a size but does not render any content.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.5 $
 */
public final class NullIcon implements Icon {

    private final int width;
    private final int height;

    // Instance Creation ******************************************************

    /**
	 * Constructs a <code>NullIcon</code> with the given size.
     *
     * @param size   the dimension of this NullIcon
	 */
    public NullIcon(Dimension size) {
        this(size.width, size.height);
    }


    /**
     * Constructs a <code>NullIcon</code> with the given size.
     *
     * @param width   the icon width
     * @param height  the icon height
     */
    public NullIcon(int width, int height) {
        this.width = width;
        this.height = height;
    }


    // Icon Implementation ****************************************************

    public int getIconHeight() {
        return height;
    }

    public int getIconWidth() {
        return width;
    }

    public void paintIcon(Component c, Graphics g, int x, int y) {
        // NullIcon doesn't paint.
    }

}
