/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uifextras.convenience;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.logging.Logger;

import javax.swing.JComponent;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.uif.util.Resizer;
import com.jgoodies.uifextras.util.UIFactory;

/**
 * Provides the default <em>tool</em> card in the default about dialog.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.12 $

 * @see DefaultAboutDialog
 */

public class DefaultAboutToolView extends AbstractView {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(DefaultAboutToolView.class);


    private JComponent  productLabel;
    private JComponent  versionLabel;
    private JComponent  copyrightText;


    /**
     * Creates and configures the UI components.
     */
    protected void initComponents() {
        String productText =
            RESOURCES.getString("application.name")
          + ' '
          + RESOURCES.getString("application.version");
        productLabel  = UIFactory.createBoldLabel(productText);
        versionLabel  = UIFactory.createMultilineLabel(getVersionText());
        copyrightText = UIFactory.createWrappedMultilineLabel(
                RESOURCES.getString(ResourceIDs.ABOUT_COPYRIGHT_TEXT));
    }


    /**
     * Builds the panel.
     */
    @Override
    protected JComponent buildPanel() {
        initComponents();

        FormLayout layout = new FormLayout(
                "left:pref:grow",
                "p, p, 14dlu, min, 14dlu, p");
        PanelBuilder builder = new PanelBuilder(layout);
        builder.setBorder(Borders.DLU14_BORDER);
        builder.setOpaque(false);
        builder.getPanel().setPreferredSize(Resizer.DEFAULT.fromWidth(410));

        CellConstraints cc = new CellConstraints();

        builder.add(productLabel,                  cc.xy(1, 1));
        builder.add(versionLabel,                  cc.xy(1, 2));
        builder.add(copyrightText,                 cc.xy(1, 4, "fill,  top"));
        builder.add(buildAcknowledgementsPanel(),  cc.xy(1, 6, "fill,  top"));
        return builder.getPanel();
    }


    /**
     * Builds and returns the acknowledgements panel.
     *
     * @return the acknowledgements subpanel
     */
    protected JComponent buildAcknowledgementsPanel() {
        return UIFactory.createPlainLabel(getAcknowledgementsText());
    }

    // Accessing Resources **************************************************

    protected String getAcknowledgementsText() {
        return RESOURCES.getString(ResourceIDs.ABOUT_ACKNOWLEDGEMENTS_TEXT);
    }

    private String getVersionText() {
        String webAddress = RESOURCES.getString("application.vendor.url");
        try {
            URL url = new URL(webAddress);
            webAddress = url.getHost();
        } catch (MalformedURLException e) {
            Logger.getLogger("About").warning(
                "Malformed vendor URL" + webAddress);
        }
        String copyright = RESOURCES.getString("application.copyright");
        return "Copyright " + copyright + ", " + webAddress;
    }


}
