/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uifextras.convenience;

import java.awt.Color;
import java.awt.Graphics;

import javax.swing.JComponent;
import javax.swing.JLabel;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.uifextras.panel.GradientBackgroundPanel;
import com.jgoodies.uifextras.util.UIFactory;

/**
 * Builds the default welcome panel for the setup dialog.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.12 $
 *
 * @see     DefaultSetupDialog
 * @see     GradientBackgroundPanel
 */

public class DefaultSetupWelcomePanel extends GradientBackgroundPanel
    implements SetupManager.WizardPanel {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(DefaultSetupWelcomePanel.class);


    private JLabel      welcome;
    private JLabel      logo;
    private JLabel      description;
    private JComponent  welcomeText;


    /**
     * Creates and configures the UI components.
     */
    private void initComponents() {
        Color foreground = Color.DARK_GRAY;
        welcome     = UIFactory.createBoldLabel("Welcome to", 0, foreground);
        logo        = new JLabel(RESOURCES.getIcon(ResourceIDs.LOGO_ICON));
        description = UIFactory.createBoldLabel(
                RESOURCES.getString("application.description"),
                0, foreground);
        String text = RESOURCES.getString(ResourceIDs.LICENSE_WELCOME_TEXT);
        welcomeText = UIFactory.createWrappedMultilineLabel(text);
        welcomeText.setForeground(Color.BLACK);
    }

    /**
     * Builds the panel using the specified button bar.
     */
    public void build(JComponent buttonBar) {
        initComponents();
        buttonBar.setBorder(Borders.createEmptyBorder("6dlu, 6dlu, 6dlu, 6dlu"));

        FormLayout layout = new FormLayout(
                "left:min, 7dlu, center:pref:grow",
                "p, p, p, 7dlu, top:p:grow, p");
        PanelBuilder builder = new PanelBuilder(layout, this);
        builder.setBorder(Borders.createEmptyBorder("20dlu, 20dlu, 0, 0"));
        CellConstraints cc = new CellConstraints();

        builder.add(welcome,        cc.xy (1, 1));
        builder.add(logo,           cc.xy (1, 2));
        builder.add(description,    cc.xy (1, 3));
        builder.add(welcomeText,    cc.xyw(1, 5, 3));
        builder.add(buttonBar,      cc.xyw(1, 6, 3));
    }

    /**
     * Paints the component's background; uses the <code>GradientBackgroundPanel</code>.
     */
    @Override
    public void paintComponent(Graphics g) {
        GradientBackgroundPanel.paintBackground(
            g,
            this,
            getWidth(),
            getHeight(),
            false);
    }

}
