/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uifextras.convenience;

import java.awt.Insets;
import java.awt.event.ActionListener;
import java.io.IOException;
import java.net.URL;

import javax.swing.*;

import com.jgoodies.forms.builder.PanelBuilder;
import com.jgoodies.forms.factories.Borders;
import com.jgoodies.forms.layout.CellConstraints;
import com.jgoodies.forms.layout.FormLayout;
import com.jgoodies.uif.application.Application;
import com.jgoodies.uif.application.ResourceMap;
import com.jgoodies.uifextras.panel.HeaderPanel;
import com.jgoodies.uifextras.util.HTMLUtils;
import com.jgoodies.uifextras.util.UIFactory;

/**
 * Builds the license acceptance page of the default setup dialog.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.14 $
 */
public final class SetupLicensePanel extends JPanel {

    private static final ResourceMap RESOURCES =
        Application.getResourceMap(SetupLicensePanel.class);


    private JEditorPane licensePane;
    private JRadioButton acceptRadio;
    private JRadioButton declineRadio;


    // Instance Creation ****************************************************

    /**
     * Constructs the license acceptance panel.
     */
    public SetupLicensePanel() {
        super(null);
        initComponents();
    }


    // Accessing State ******************************************************

    /**
     * Sets a new license page.
     */
    public void setPage(URL url) throws IOException {
        licensePane.setPage(url);
        HTMLUtils.addDefaultStyleSheet(licensePane);
    }

    public boolean licenseAccepted() {
        return acceptRadio.isSelected();
    }

    public boolean licenseDeclined() {
        return declineRadio.isSelected();
    }


    // Building *************************************************************

    /**
     * Creates and configures the UI components.
     */
    private void initComponents() {
        licensePane = UIFactory.createHTMLPane(false, true);
        licensePane.setMargin(new Insets(0, 10, 0, 5));
        acceptRadio =
            new JRadioButton("I accept the terms in the license agreement");
        acceptRadio.setMnemonic('a');
        declineRadio =
            new JRadioButton("I do not accept the terms in the license agreement");
        declineRadio.setMnemonic('n');
        ButtonGroup group = new ButtonGroup();
        group.add(acceptRadio);
        group.add(declineRadio);
    }

    /**
     * Builds the panel.
     */
    public void build(JComponent buttonBar) {
        buttonBar.setBorder(Borders.createEmptyBorder("6dlu, 6dlu, 6dlu, 6dlu"));

        FormLayout layout = new FormLayout(
                "15dlu, left:min:grow, 15dlu",
                "p, 17dlu, min:grow, $rg, p, $nlg, p, $nlg, p");
        PanelBuilder builder = new PanelBuilder(layout, this);
        CellConstraints cc = new CellConstraints();

        builder.add(buildHeader(),          cc.xyw(1, 1, 3));
        builder.add(buildLicensePanel(),    cc.xy (2, 3, "f, f"));
        builder.add(acceptRadio,            cc.xy (2, 5));
        builder.add(declineRadio,           cc.xy (2, 7));
        builder.add(buttonBar,              cc.xyw(1, 9, 3));
    }

    /**
     * Creates the panel's header.
     */
    private JComponent buildHeader() {
        return new HeaderPanel(
            "License Agreement",
            RESOURCES.getString(ResourceIDs.LICENSE_HEADER_TEXT),
            RESOURCES.getIcon(ResourceIDs.LICENSE_ICON));
    }

    /**
     * Builds and configures the license panel.
     */
    private JComponent buildLicensePanel() {
        JScrollPane scrollPane = new JScrollPane(licensePane);
        scrollPane.putClientProperty("jgoodies.isEtched", Boolean.TRUE);

        // Register license keyboard actions.
        KeyStroke[] registeredKeystrokes =
            scrollPane.getRegisteredKeyStrokes();
        for (KeyStroke keyStroke : registeredKeystrokes) {
            ActionListener keyboardAction =
                scrollPane.getActionForKeyStroke(keyStroke);
            scrollPane.unregisterKeyboardAction(keyStroke);
            scrollPane.registerKeyboardAction(
                keyboardAction,
                keyStroke,
                JComponent.WHEN_IN_FOCUSED_WINDOW);
        }
        return scrollPane;
    }

}