/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uifextras.help;

import java.net.URL;

import com.jgoodies.uif.application.Action;
import com.jgoodies.uifextras.history.History;


/**
 * A History subclass that holds URLs, creates short tooltips,
 * and overrides the action names.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
public final class HelpHistory extends History<URL> {

    // Action Resource Keys ***************************************************

    @SuppressWarnings("hiding")
    public static final String ACTION_GO_BACK = "com.jgoodies.help.goBack";

    @SuppressWarnings("hiding")
    public static final String ACTION_GO_NEXT = "com.jgoodies.help.goNext";

    @SuppressWarnings("hiding")
    public static final String ACTION_GO_HOME = "com.jgoodies.help.goHome";


    // Constants **************************************************************

    private static final char ZIP_SEPARATOR = '/';


    // Instance Creation ******************************************************

    HelpHistory(URL home) {
        super(10,
              ACTION_GO_BACK,
              ACTION_GO_NEXT,
              ACTION_GO_HOME);
        setHome(home);
    }


    // Overriding Superclass Behavior *****************************************

    @Action(name=ACTION_GO_BACK)
    @Override
    public void goBack() {
        super.goBack();
    }


    @Action(name=ACTION_GO_NEXT)
    @Override
    public void goNext() {
        super.goNext();
    }


    @Action(name=ACTION_GO_HOME)
    @Override
    public void goHome() {
        super.goHome();
    }


    @Override
    protected String createToolTip(URL url) {
        String filename = url.getFile();
        int lastSeparatorIndex = filename.lastIndexOf(ZIP_SEPARATOR);
        return filename.substring(lastSeparatorIndex + 1);
    }


}
