/*
 * Copyright (c) 2000-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * This software is the proprietary information of JGoodies Karsten Lentzsch.
 * Use is subject to license terms.
 *
 */

package com.jgoodies.uifextras.help;

import java.awt.Cursor;
import java.awt.Dimension;
import java.awt.Insets;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import java.io.IOException;
import java.net.URL;
import java.util.logging.Logger;

import javax.swing.JComponent;
import javax.swing.JEditorPane;
import javax.swing.JScrollPane;
import javax.swing.event.HyperlinkEvent;
import javax.swing.event.HyperlinkListener;

import com.jgoodies.uif.AbstractView;
import com.jgoodies.uif.util.ScreenUtils;
import com.jgoodies.uifextras.util.HTMLUtils;
import com.jgoodies.uifextras.util.UIFactory;

/**
 * Contains the editor pane for the help viewer.
 *
 * @author  Karsten Lentzsch
 * @version $Revision: 1.6 $
 */
final class PresentationView extends AbstractView {

    private static final int INITIAL_PRESENTATION_WIDTH = 420;


    private final HelpModel model;
    private JEditorPane editorPane;


    // Instance Creation ******************************************************

	PresentationView(HelpModel model) {
        this.model = model;
    }


    // Initialization *********************************************************

    private void initComponents() {
        editorPane = UIFactory.createInfoEditorPane();
        editorPane.setContentType("text/html");
        editorPane.setMargin(new Insets(0, 10, 0, 5));

		// Don't load asynchronously.
//		Document document = getDocument();
//		if (document instanceof AbstractDocument) {
//			((AbstractDocument) document).setAsynchronousLoadPriority(-1);
//			System.out.println("Asynchrones Laden abgeschaltet.");
//		}
	}


    private void initEventHandling() {
        editorPane.addHyperlinkListener(new HyperlinkHandler());
        editorPane.addMouseListener(model.getPopupListener());
        model.addPropertyChangeListener(
                HelpModel.PROPERTYNAME_SELECTION,
                new SelectedURLChangeHandler());
    }


    // Building ***************************************************************

    @Override
    protected JComponent buildPanel() {
        initComponents();
        initEventHandling();

        JComponent panel = new JScrollPane(editorPane);
        panel.putClientProperty("jgoodies.isEtched", Boolean.TRUE);
        panel.updateUI();
        int width = INITIAL_PRESENTATION_WIDTH;
        int height = ScreenUtils.has1024x768Screen()
            ? 600
            : (ScreenUtils.has800x600Screen() ? 550 : 410);
        panel.setPreferredSize(new Dimension(width, height));
        return panel;
    }


    // Event Handling *********************************************************

    private final class HyperlinkHandler implements HyperlinkListener {

    	public void hyperlinkUpdate(HyperlinkEvent e) {
    		HyperlinkEvent.EventType eventType = e.getEventType();
    		if (eventType == HyperlinkEvent.EventType.ENTERED)
    			editorPane.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
    		else if (eventType == HyperlinkEvent.EventType.EXITED)
    			editorPane.setCursor(Cursor.getDefaultCursor());
            else if (eventType == HyperlinkEvent.EventType.ACTIVATED)
                model.setSelection(e.getURL());
    	}

    }


    private final class SelectedURLChangeHandler implements PropertyChangeListener {

    	public void propertyChange(PropertyChangeEvent event) {
    		URL newURL = (URL) event.getNewValue();
            try {
                editorPane.setPage(newURL);
                HTMLUtils.addDefaultStyleSheet(editorPane);
            } catch (IOException e) {
                if (newURL != null)
                    Logger.getLogger("help.PresentationPanel").warning(
                        "Can't show help URL: " + newURL);
            }
    	}

    }


}