/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of JGoodies Karsten Lentzsch nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jgoodies.validation.tutorial.performance;

import com.jgoodies.validation.ValidationResult;
import com.jgoodies.validation.Validator;
import com.jgoodies.validation.util.PropertyValidationSupport;


/**
 * Validates containers.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.7 $
 */
class ContainerValidator implements Validator<Container> {

    /**
     * A prefix used to label different validation results.
     */
    protected final String prefix;


    // Instance Creation ******************************************************

    /**
     * Constructs a ContainerValidator.
     */
    ContainerValidator(String prefix) {
        this.prefix = prefix;
    }


    // Validation *************************************************************

    /**
     * Validates the given container and returns the validation result.
     *
     * @param container  the container to be validated
     * @return the ValidationResult of the container validation
     */
    public ValidationResult validate(Container container) {
        PropertyValidationSupport support =
            new PropertyValidationSupport(container, prefix);

        String containerNo = container.getContainerNo();
        System.out.println("Client validation: " + containerNo);
        if (!BackendService.isValidContainerNumber(containerNo))
            support.addError("Container No", "invalid");

        System.out.println();
        return support.getResult();
    }


    // Misc *******************************************************************

    String getPrefix() {
        return prefix;
    }



}
