/*
 * Copyright (c) 2003-2008 JGoodies Karsten Lentzsch. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of JGoodies Karsten Lentzsch nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package com.jgoodies.validation.tutorial.shared;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import com.jgoodies.binding.PresentationModel;
import com.jgoodies.validation.ValidationResult;
import com.jgoodies.validation.ValidationResultModel;
import com.jgoodies.validation.tutorial.validator.OrderValidator;
import com.jgoodies.validation.util.DefaultValidationResultModel;

/**
 * Provides all models to bind an order editor to its domain model,
 * an instance of {@link Order}.
 *
 * @author Karsten Lentzsch
 * @version $Revision: 1.14 $
 */
public class OrderModel extends PresentationModel<Order> {

    private final ValidationResultModel validationResultModel;


    // Instance Creation ******************************************************

    public OrderModel(Order order) {
        super(order);
        validationResultModel = new DefaultValidationResultModel();
        initEventHandling();
        updateValidationResult();
    }


    // Exposing Models ********************************************************

    public ValidationResultModel getValidationResultModel() {
        return validationResultModel;
    }


    // Initialization *********************************************************

    /**
     * Listens to changes in all properties of the current Order
     * and to Order changes.
     */
    private void initEventHandling() {
        PropertyChangeListener handler = new ValidationUpdateHandler();
        addBeanPropertyChangeListener(handler);
        getBeanChannel().addValueChangeListener(handler);
    }


    // Event Handling *********************************************************

    private void updateValidationResult() {
        Order order = getBean();
        ValidationResult result = new OrderValidator().validate(order);
        validationResultModel.setResult(result);
    }


    /**
     * Validates the order using an OrderValidator and
     * updates the validation result.
     */
    private final class ValidationUpdateHandler implements PropertyChangeListener {

        public void propertyChange(PropertyChangeEvent evt) {
            updateValidationResult();
        }

    }

}
